import React from 'react';
import { Card, Stack, Typography } from '@mui/material';
import ImageCrop, { ImageCropProps } from 'mui-image-crop';
import { ICroppedImage } from 'mui-image-crop/es/types';

type Props = {
    image: File | undefined,
    setImage: (image: File) => void;
};

const CustomImageCrop = ({ image, setImage }: Props) => {
    const imageCropProps: ImageCropProps = {
        value: image as ICroppedImage,
        onChange: (value) => setImage(value as File),
        locale: 'en',
        preview: true,
        accept: { 'image/*': ['.jpg', '.jpeg', '.png', '.bmp'] },
        qulity: 0.96,
        title: 'Image Crop', // Default title
        showAspectToolbar: true, // Show aspect ratio toolbar by default
        showRotateToolbar: true, // Show rotate toolbar by default
        showZoomToolbar: true, // Show zoom toolbar by default
        uploaderProps: {

            style: {
                border: 'none',
                width: 'auto',
                height: 'auto',
                maxHeight: 300,
                maxWidth: 500,
                background: 'transparent'
            },
        },
        imageCardProps: {
            showDownloadIcon: false,
            showPreviewIcon: true,
            showRemoveIcon: true,
            removeText: 'Delete',
            previewText: 'Preview',
            downloadText: 'Download',
        },
        defaultAspect: 4 / 3,
        aspectMarks: [
            { value: 0.25, label: '1:4' },
            { value: 0.33, label: '1:3' },
            { value: 0.5, label: '1:2' },
            { value: 0.75, label: '3:4' },
            { value: 1, label: '1:1' },
            { value: 1.33, label: '4:3' },
            { value: 2, label: '2:1' },
            { value: 3, label: '3:1' },
            { value: 4, label: '4:1' },
        ]
    };

    return (
        <Card sx={{ display: 'flex', p: 4, flexDirection: 'column', alignItems: 'center', justifyContent: 'center' }}>
            <ImageCrop {...imageCropProps} />
            <Stack spacing={1} sx={{ textAlign: 'center' }}>
                <Typography variant="h6">Déposer ou sélectionner une image</Typography>
            </Stack>
        </Card>
    );
};

export default CustomImageCrop;
