"use client";

import React, { createContext, useContext, ReactNode, useState, useEffect, useRef } from "react";
import Stomp from "stompjs";
import SockJS from "sockjs-client";
import { ILive, ILiveComment, LiveStatus } from "@/shared/types/live";
import { useGetCommentsLive } from "@/shared/api/live";



const useLiveComments = ({ id, status }: ILive): ILiveComment[] => {
    const [comments, setComments] = useState<ILiveComment[]>([]);
    const { commentsData, commentsLoading } = useGetCommentsLive(id);
    const socketRef = useRef<any>(null);
    const clientRef = useRef<any>(null);

    useEffect(() => {
        setComments(commentsData);
    }, [commentsLoading]);



    useEffect(() => {
        if (status === LiveStatus.ONGOING && !clientRef.current) {
            socketRef.current = new SockJS("http://localhost:8080/ws");
            clientRef.current = Stomp.over(socketRef.current);

            clientRef.current.connect({}, () => {
                console.log("Connected to LiveWebSocket");
                clientRef.current.subscribe(`/topic/messages/${id}`, (message: any) => {
                    const comment: ILiveComment = JSON.parse(message.body);
                    setComments((prev) => [...prev, comment]);
                });
            });
        }

        return () => {
            if (clientRef.current?.connected) {
                clientRef.current.disconnect(() => {
                    console.log("Disconnected from LiveWebSocket");
                });
                clientRef.current = null;
            }
        };
    }, [id, status]);

    return comments;
};

export default useLiveComments;