import { useEffect, useState } from 'react';

const usePolling = <T>(duration: number, callback: () => Promise<T>, enabled: boolean): [T | null, string | null] => {
  const [data, setData] = useState<T | null>(null);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    if (!enabled) {
      return;
    }

    const fetchData = async () => {
      try {
        const result = await callback();
        setData(result);
      } catch (err) {
        console.error(err);
        setData(null);
        setError((err as Error).message);
      }
    };

    fetchData(); 
    const interval = setInterval(() => {
      fetchData();
    }, duration);

    return () => clearInterval(interval);
  }, [duration, callback, enabled]);

  return [data, error];
};

export default usePolling;
