// ----------------------------------------------------------------------

export type IOrderTableFilterValue = string | Date | null;

export type IOrderTableFilters = {
  name: string;
  status: string;
  startDate: Date | null;
  endDate: Date | null;
};
export enum IOrderStatus {
  Ongoing = "En cours",
  Completed = "Terminée",
  Cancelled = "Annulée",
  Deleted = "Supprimée",
  Pending = "En attente",
  Refunded = "Remboursée",
}
// ----------------------------------------------------------------------

export type IOrderHistory = {
  orderTime: Date;
  paymentTime: Date;
  deliveryTime: Date;
  completionTime: Date;
  timeline: {
    title: string;
    time: Date;
  }[];
};

export type IOrderShippingAddress = {
  fullAddress: string;
  villeShip: string;
  codePostal: number;
  modeExpedition: string;
  trackingNumber: string;
};

export type IOrderPayment = {
  cardType: string;
  cardNumber: string;
};

export type IOrderDelivery = {
  shipAdress: string;
  ville: string;
  codePostal: number;
};
export type IOrderStatistic = {
  startDate: any;
  timestod: Date;
  timespre: Date;
};

export type IOrderCustomer = {
  id: string;
  name: string;
  email: string;
  avatarUrl: string;
  numberphone: string;
};

export type IOrderProductItem = {
  id: string;
  sku: string;
  name: string;
  price: number;
  coverUrl: string;
  quantity: number;
};

export type IOrderItem = {
  id: string;
  taxes: number;
  status: string;
  origine: string;
  shipping: number;
  discount: number;
  subTotal: number;
  orderNumber: string;
  totalAmount: number;
  totalQuantity: number;
  history: IOrderHistory;
  customer: IOrderCustomer;
  delivery: IOrderDelivery;
  items: IOrderProductItem[];
  createdAt: Date;
};

// ----------------------------------------------------------------------

import { _mock } from "./_mock";
import {} from "date-fns";
import { addDays, formatISO, sub } from "date-fns";

//----------------------------------------------------------------
export const OrderStatus = [
  IOrderStatus.Ongoing,
  IOrderStatus.Completed,
  IOrderStatus.Cancelled,
  IOrderStatus.Deleted,
  IOrderStatus.Pending,
  IOrderStatus.Refunded,
];

export const ORDER_STATUS_OPTIONS = [
  { value: IOrderStatus.Pending, label: "En attente" },
  { value: IOrderStatus.Ongoing, label: "En cours" },
  { value: IOrderStatus.Cancelled, label: "Annulée" },
  { value: IOrderStatus.Completed, label: "Terminée" },
  { value: IOrderStatus.Refunded, label: "Remboursée" },
  { value: IOrderStatus.Deleted, label: "Supprimée" },
];

const ITEMS = [...Array(3)].map((_, index) => ({
  id: _mock.id(index),
  sku: `16H9UR${index}`,
  quantity: index + 1,
  name: _mock.productName(index),
  coverUrl: _mock.image.product(index),
  price: _mock.number.price(index),
}));
export const ETAT_ORDER = [
  {
    group: "État",
    classify: [
      "En attente",
      "En cours",
      "Terminée",
      "Annulée",
      "Remboursée",
      "Supprimée",
    ],
  },
];

export const _orders = [...Array(20)].map((_, index) => {
  const shipping = 10;

  const discount = 10;

  const taxes = 10;

  const origine = _mock.origine(index);

  const items =
    (index % 2 && ITEMS.slice(0, 1)) ||
    (index % 3 && ITEMS.slice(1, 3)) ||
    ITEMS;

  const totalQuantity = items.reduce(
    (accumulator, item) => accumulator + item.quantity,
    0
  );

  const subTotal = items.reduce(
    (accumulator, item) => accumulator + item.price * item.quantity,
    0
  );

  const totalAmount = subTotal - shipping - discount + taxes;

  const customer = {
    id: _mock.id(index),
    name: _mock.fullName(index),
    email: _mock.email(index),
    avatarUrl: _mock.image.avatar(index),
    numberphone: "33082368629",
  };

  const delivery = {
    shipAdress: "19034 Verna Unions Apt. 164 - Honolulu, RI",
    ville: "SAINT-MARCELLIN-EN-FOREZ",
    codePostal: 87535,
  };

  const history = {
    orderTime: _mock.time(1),
    paymentTime: _mock.time(2),
    deliveryTime: _mock.time(3),
    completionTime: _mock.time(4),
    timeline: [
      { title: "Delivery successful", time: _mock.time(1) },
      { title: "Transporting to [2]", time: _mock.time(2) },
      { title: "Transporting to [1]", time: _mock.time(3) },
      {
        title: "The shipping unit has picked up the goods",
        time: _mock.time(4),
      },
      { title: "Order has been created", time: _mock.time(5) },
    ],
  };

  return {
    id: _mock.id(index),
    orderNumber: `#601${index}`,
    createdAt: _mock.time(index),
    taxes,
    origine,
    items,
    history,
    subTotal,
    shipping,
    discount,
    customer,
    delivery,
    totalAmount,
    totalQuantity,
    shippingAddress: {
      fullAddress: "19034 Verna Unions Apt. 164 - Honolulu, RI",
      villeShip: "SAINT-MARCELLIN-EN-FOREZ",
      codePostal: 87535,
      modeExpedition: "Mondial Relay",
      trackingNumber: "SPX037739199373",
    },
    payment: {
      cardType: "Virement bancaire",
      cardNumber: "**** **** **** 5678",
    },
    status: OrderStatus[index % OrderStatus.length],
  };
});
