import useSWR from 'swr';
import { useMemo } from 'react';

import { fetcher, endpoints } from '@/utils/axios';

import { activite } from '@/contexts/types/giftcard'; // Assuming this is the correct import path for the activite type

export function useGetGiftCardActivities(giftCardId: string) {
  const URL = `${endpoints.giftcard.list}/${giftCardId}/activities`;

  const { data, isLoading, error, isValidating } = useSWR(URL, fetcher);

  const memoizedValue = useMemo(
    () => ({
      activities: (data?.activities as activite[]) || [],
      activitiesLoading: isLoading,
      activitiesError: error,
      activitiesValidating: isValidating,
      activitiesEmpty: !isLoading && !data?.activities.length,
    }),
    [data?.activities, error, isLoading, isValidating]
  );

  return memoizedValue;
}
