import useSWR from 'swr';
import { useMemo } from 'react';

import { fetcher, endpoints } from '@/utils/axios';

import { Promocode } from '@/contexts/types/promo';

// ----------------------------------------------------------------------

export function useGetPromoCodes() {
  const URL = endpoints.promo.list;
  console.log("url: ", URL)

  const { data, error, isValidating } = useSWR(URL, fetcher);
  // console.log("data: ", data)
  const isLoading = !data && !error;

  const memoizedValue = useMemo(
    () => ({
      promoCodes: (data?.promoCodes as Promocode[]) || [],
      promoCodesLoading: isLoading,
      promoCodesError: error,
      promoCodesValidating: isValidating,
      promoCodesEmpty: !isLoading && !data?.promoCodes.length,
    }),
    [data?.promoCodes, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

export function useGetPromoCode(promoCodeId: string) {
  const URL = promoCodeId ? [endpoints.promo.details, { params: { promoCodeId } }] : '';

  const { data, error, isValidating } = useSWR(URL, fetcher);
  const isLoading = !data && !error;

  const memoizedValue = useMemo(
    () => ({
      promoCode: data?.promoCode as Promocode,
      promoCodeLoading: isLoading,
      promoCodeError: error,
      promoCodeValidating: isValidating,
    }),
    [data?.promoCode, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

export function useSearchPromoCodes(query: string) {
  const URL = query ? [endpoints.promo.search, { params: { query } }] : '';

  const { data, error, isValidating } = useSWR(URL, fetcher, {
    keepPreviousData: true,
  });
  const isLoading = !data && !error;

  const memoizedValue = useMemo(
    () => ({
      searchResults: (data?.results as Promocode[]) || [],
      searchLoading: isLoading,
      searchError: error,
      searchValidating: isValidating,
      searchEmpty: !isLoading && !data?.results.length,
    }),
    [data?.results, error, isLoading, isValidating]
  );

  return memoizedValue;
}
