import { ShippingClass, ShippingRules } from "@/contexts/types/Shipping";
import { useMemo } from "react";
import useSWR from "swr";
import { _orders } from "../_mock";
import axiosInstance, { fetcher, endpoints } from './server';
import { mutate, revalidateEvents } from "swr/_internal";
import { success } from "@/theme/palette";


const options = {
    revalidateIfStale: false,
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
}



///////////////////-----------ShippingClass----------///////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////
export function useGetShippingClasses() {
    const URL = [endpoints.shipping.shippingClass.getAll];
    const { data, error } = useSWR<ShippingClass[]>(URL, fetcher, options);

    const memoizedValue = useMemo(
        () => ({
            shippingClassData: (data as ShippingClass[]) || [],
            shippingClassError: error,
        }),
        [data, error]
    );

    return memoizedValue;
}

export function useGetShippingClass(shippingClassId: string) {
    const { data, error } = useSWR<ShippingClass>(
        shippingClassId ? endpoints.shipping.shippingClass.getById(shippingClassId) : null,
        fetcher
    );

    const memoizedValue = useMemo(
        () => ({
            shippingClass: data,
            shippingClassError: error,
        }),
        [data, error]
    );

    return memoizedValue;
}

export async function useAddShippingClass(data: ShippingClass) {

    const formData = {
        name: data.name,
        code: data.code,
        description: data.description,
    }
    const response = await axiosInstance.post(endpoints.shipping.shippingClass.add, formData);
    const newData: ShippingClass = response.data;
    mutate([endpoints.shipping.shippingClass.getAll], (shippingClasses: ShippingClass[] = []) => [...shippingClasses, newData], true);
    return newData;
}

export async function useUpdateShippingClass(id: string, updatedShippingClass: ShippingClass) {
    const response = await axiosInstance.put(endpoints.shipping.shippingClass.edit(id), updatedShippingClass);
    const updatedData: ShippingClass = response.data;
    mutate([endpoints.shipping.shippingClass.getAll], (shippingClasses: ShippingClass[] = []) => 
        shippingClasses.map((shippingClass) => 
            shippingClass.id === id ? updatedData : shippingClass
        ), 
        true
    );
    return response.data as ShippingClass;
}

export async function useDeleteShippingClass(id: string) {
    const response = await axiosInstance.delete(endpoints.shipping.shippingClass.delete(id));
    mutate(endpoints.shipping.shippingClass.getAll);
    return response.status;
}




///////////////////-----------ShippingRules----------///////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////
export function useGetShippingRules(shippingRulesId: string) {
    const { data, error } = useSWR<ShippingRules>(
        shippingRulesId ? endpoints.shipping.shippingRules.getById(shippingRulesId) : null,
        fetcher
    );

    const memoizedValue = useMemo(
        () => ({
            shippingRulesData: data,
            shippingRulesError: error,
        }),
        [data, error]
    );

    return memoizedValue;
}

export async function useUpdateShippingRules(id: string, updatedShippingRules: ShippingRules) {
    const response = await axiosInstance.put(endpoints.shipping.shippingRules.edit(id), updatedShippingRules);
    const updatedData: ShippingRules = response.data;
    mutate(endpoints.shipping.shippingRules.getById(id), updatedData, true);
    return response.data as ShippingRules;
}