import Paper from '@mui/material/Paper';
import Stack from '@mui/material/Stack';
import Button from '@mui/material/Button';
import Dialog from '@mui/material/Dialog';
import DialogTitle from '@mui/material/DialogTitle';
import DialogActions from '@mui/material/DialogActions';
import DialogContent from '@mui/material/DialogContent';
import FormHelperText from '@mui/material/FormHelperText';
import { DatePicker } from '@mui/x-date-pickers/DatePicker';
import { DateCalendar } from '@mui/x-date-pickers/DateCalendar';

import { useResponsive } from '@/hooks';

import { DateRangePickerProps } from './types';
import { useState } from 'react';

// ----------------------------------------------------------------------

export default function CustomDateRangePicker({
  variant = 'calendar',
  //
  startDate,
  endDate,
  //
  onChangeStartDate,
  onChangeEndDate,
  //
  open,
  onClose,
}: DateRangePickerProps) {
  const mdUp = useResponsive('up', 'md');
  const [localStartDate, setLocalStartDate] = useState(startDate);
  const [localEndDate, setLocalEndDate] = useState(startDate);
  const [error, setError] = useState(false);

  function handleChangeLocalStartDate(date: Date | null) {
    if (date && localEndDate && date > localEndDate) {
      setError(true);
    } else {
      setError(false);
      setLocalStartDate(date);
    }
  }

  function handleChangeLocalEndDate(date: Date | null) {
    if (date && localStartDate && date < localStartDate) {
      setError(true);
    } else {
      setError(false);
      setLocalEndDate(date);
    }
  }

  function onSubmit() {
    onChangeStartDate(localStartDate);
    onChangeEndDate(localEndDate);
    onClose();
  }


  const isCalendarView = variant === 'calendar';

  return (
    <Dialog
      fullWidth
      maxWidth={isCalendarView ? false : 'xs'}
      open={open}
      onClose={onClose}
      PaperProps={{
        sx: {
          ...(isCalendarView && {
            maxWidth: 720,
          }),
        },
      }}
    >
      <DialogContent
        sx={{
          marginTop: 4,
          ...(isCalendarView &&
            mdUp && {
            overflow: 'unset',
          }),
        }}
      >
        <Stack
          justifyContent="center"
          spacing={isCalendarView ? 3 : 2}
          direction={isCalendarView && mdUp ? 'row' : 'column'}
          sx={{ pt: 1 }}
        >
          {isCalendarView ? (
            <>
              <Paper
                variant="outlined"
                sx={{
                  borderRadius: 2,
                  borderColor: 'divider',
                  borderStyle: 'dashed',
                }}
              >
                <DateCalendar value={localStartDate} onChange={handleChangeLocalStartDate} />
              </Paper>

              <Paper
                variant="outlined"
                sx={{
                  borderRadius: 2,
                  borderColor: 'divider',
                  borderStyle: 'dashed',
                }}
              >
                <DateCalendar value={localEndDate} onChange={handleChangeLocalEndDate} />
              </Paper>
            </>
          ) : (
            <>
              <DatePicker label="Début" value={localStartDate} onChange={handleChangeLocalStartDate} />

              <DatePicker label="Fin" value={localEndDate} onChange={handleChangeLocalEndDate} />
            </>
          )}
        </Stack>

        {error && (
          <FormHelperText error sx={{ px: 2 }}>
            La date de début doit être antérieure à la date de fin
          </FormHelperText>
        )}
      </DialogContent>

      <DialogActions>
        <Button variant="outlined" color="inherit" onClick={onClose}>
          Annuler
        </Button>

        <Button disabled={error} variant="contained" onClick={onSubmit}>
          Appliquer
        </Button>
      </DialogActions>
    </Dialog>
  );
}
