import { Children, useMemo } from "react";
import { paths } from "@/routes/paths";
import SvgColor from "@/shared/components/svg-color";
// ----------------------------------------------------------------------
const icon = (name: string) => (
  <SvgColor
    src={`/assets/icons/navbar/${name}.svg`}
    sx={{ width: 1, height: 1 }}
  />
);
const ICONS = {
  job: icon("ic_job"),
  blog: icon("ic_blog"),
  chat: icon("ic_chat"),
  mail: icon("ic_mail"),
  user: icon("ic_user"),
  file: icon("ic_file"),
  lock: icon("ic_lock"),
  tour: icon("ic_tour"),
  order: icon("ic_order"),
  label: icon("ic_label"),
  blank: icon("ic_blank"),
  kanban: icon("ic_kanban"),
  folder: icon("ic_folder"),
  banking: icon("ic_banking"),
  booking: icon("ic_booking"),
  invoice: icon("ic_invoice"),
  product: icon("ic_product"),
  calendar: icon("ic_calendar"),
  disabled: icon("ic_disabled"),
  external: icon("ic_external"),
  menuItem: icon("ic_menu_item"),
  ecommerce: icon("ic_ecommerce"),
  analytics: icon("ic_analytics"),
  dashboard: icon("ic_dashboard"),
};

export function useNavData() {
  const data = useMemo(
    () => [
      {
        subheader: "MyDressin",
        items: [
          { title: "Home", path: paths.dashboard.root, icon: ICONS.dashboard },
          { title: "Chat", path: paths.dashboard.chat, icon: ICONS.chat },
        ],
      },
      {
        subheader: "Gestion",
        items: [
          {
            title: "Produits",
            path: paths.dashboard.product.root,
            icon: ICONS.product,
            children: [
              {
                title: "Tout les produits",
                path: paths.dashboard.product.root,
              },
              { title: "Ajouter", path: paths.dashboard.product.new },
              { title: "Catégorie", path: paths.dashboard.product.category },
              { title: "Étiquettes", path: paths.dashboard.product.tags },
              { title: "Attributs", path: paths.dashboard.product.attribut },
            ],
          },
          {
            title: "Lives",
            path: paths.dashboard.live.root,
            icon: ICONS.calendar,
            children: [
              { title: "Tout les lives", path: paths.dashboard.live.all_lives },
              { title: "Ajouter", path: paths.dashboard.live.new },
              {
                title: "Statistiques",
                path: paths.dashboard.live.statistics.all,
              },
              {
                title: "Session de Vente",
                path: paths.dashboard.live.saleSession,
              },
            ],
          },
          {
            title: "Promo",
            path: paths.promo.root,
            icon: ICONS.label,
            children: [
              { title: "Tout les codes promo", path: paths.promo.all_promo },
              { title: "Ajouter", path: paths.promo.new },
            ],
          },
          {
            title: "commandes",
            path: paths.dashboard.order.root,
            icon: ICONS.order,
            children: [
              {
                title: "Tout les commandes",
                path: paths.dashboard.order.all_orders,
              },
              { title: "Ajouter", path: paths.dashboard.order.create },
              { title: "Corbeille", path: paths.dashboard.order.trash },
              { title: "Statistiques", path: paths.dashboard.order.statistics },
            ],
          },
          {
            title: "Commentaires",
            path: paths.dashboard.review.root,
            icon: ICONS.chat,
            children: [
              
              {
                title: "Tout les commentaires",
                path: paths.dashboard.review.all_reviews,
              },
              {
                title: " configuration",
                path: paths.dashboard.review.config,
              },
            
            ],
          },
          {
            title: "Cartes cadeaux",
            path: paths.giftcard.root,
            icon: ICONS.label,
          },
          {
            title: "Fournisseur",
            path: paths.dashboard.supplier.root,
            icon: ICONS.order,
            children: [
              {
                title: "Tout les fournisseurs",
                path: paths.dashboard.supplier.list,
              },
              { title: "Ajouter", path: paths.dashboard.supplier.new },
              {
                title: "Commande Fournisseur",
                path: paths.dashboard.supplier.SupplierOrder.root,
                children: [
                  {
                    title: "Ajouter",
                    path: paths.dashboard.supplier.SupplierOrder.new,
                  },
                  {
                    title: "tout les Commandes",
                    path: paths.dashboard.supplier.SupplierOrder.root,
                  },
                  {
                    title: "Écart",
                    path: paths.dashboard.supplier.SupplierOrder.deviation,
                  },
                ],
              },
            ],
          },
          {
            title: "Utilisateur",
            path: paths.dashboard.user.root,
            icon: ICONS.user,
            children: [
              {
                title: "Tout les utilisateurs",
                path: paths.dashboard.user.all_users,
              },
              {
                title: "Ajouter",
                path: paths.dashboard.user.new,
              },
              { title: "Compte", path: paths.dashboard.user.account },
              { title: "Editeur de role", path: paths.dashboard.user.role },
            ],
          },

          {
            title: "bon d'achat",
            path: paths.purchase.root,
            icon: ICONS.order,
            children: [
              {
                title: "les bons d'achats",
                path: paths.purchase.root,
              },

              { title: "Ajouter un nouveau modéle", path: paths.purchase.new },
            ],
          },
          {
            title: "Médiathèque",
            path: paths.dashboard.media.root,
            icon: ICONS.file,
          },
        ],
      },
      {
        subheader: "Configuration",
        items: [
          {
            title: "Livraison",
            path: paths.dashboard.shipping.general.root,
            icon: ICONS.external,
            children: [
              { title: "Général", path: paths.dashboard.shipping.general.root },
              { title: "Colissimo", path: paths.dashboard.shipping.colissimo },
              { title: "Mondial Relay - InPost", path: paths.dashboard.shipping.mondialRelayInPost.root },
            ],
          },
          {
            title: "Paiement",
            path: paths.dashboard.payment.root,
            icon: ICONS.banking,
          },
          {
            title: "parrainage",
            path: paths.Referral.root,
            icon: ICONS.menuItem,
          },
          {
            title: "Panier",
            path: paths.dashboard.cart.root,
            icon: ICONS.ecommerce,
            children: [
              {
                title: "Panier",
                path: paths.dashboard.cart.root,
              },
              {
                title: "Panier Utilisateur",
                path: paths.dashboard.cart.UserCart,
              },
              {
                title: "Statistique",
                path: paths.dashboard.cart.statistics,
              },
            ],
          },
        ],
      },
    ],
    []
  );
  return data;
}
