import Tooltip from "@mui/material/Tooltip";
import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import Iconify from "@/components/iconify";
import { IUserItem, _User } from "@/shared/_mock/_cartLive";
import {
  Autocomplete,
  Box,
  Button,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle,
  ListItemText,
  TextField,
} from "@mui/material";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import { useState } from "react";
import { fDate, fTime } from "../../../../utils/format-time";

// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  row: IUserItem;
};

export default function UserTableRow({ row, selected }: Props) {
  const { name, CreatedAt } = row;
  const [openDialog, setOpenDialog] = useState(false);
  const [selectedAccount, setSelectedAccount] = useState(null);

  const handleOpenDialog = () => {
    setOpenDialog(true);
  };

  const handleCloseDialog = () => {
    setOpenDialog(false);
  };

  const handleAccountSelect = (account: any) => {
    setSelectedAccount(account);
  };

  const handleAssociateButtonClick = () => {
    handleCloseDialog();
  };
  return (
    <TableRow>
      <TableCell>
        <Tooltip title="Ajouter au panier">
          <IconButton sx={{ color: "#00e676" }}>
            <ShoppingCartIcon />
          </IconButton>
        </Tooltip>
      </TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{name}</TableCell>
      <TableCell>
        <ListItemText
          primary={fDate(CreatedAt)}
          secondary={fTime(CreatedAt)}
          primaryTypographyProps={{ typography: "body2", noWrap: true }}
          secondaryTypographyProps={{
            mt: 0.5,
            component: "span",
            typography: "caption",
          }}
        />
      </TableCell>
      <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
        <Tooltip title="Associer au Compte" placement="top" arrow>
          <IconButton color="default" onClick={handleOpenDialog}>
            <Iconify icon="solar:pen-bold" />
          </IconButton>
        </Tooltip>
      </TableCell>

      <Dialog
        open={openDialog}
        onClose={handleCloseDialog}
        fullWidth
        maxWidth="sm"
      >
        <DialogTitle>Sélectionnez un Compte Utilisateur</DialogTitle>
        <DialogContent>
          <Autocomplete
            options={_User}
            getOptionLabel={(option) => option.name || option.id}
            isOptionEqualToValue={(option, value) =>
              option.name === value.name || option.id === value.id
            }
            renderOption={(props, option) => (
              <Box
                component="li"
                {...props}
                sx={{
                  display: "flex",
                  alignItems: "center",
                  "& > img": { mr: 2, flexShrink: 0 },
                }}
              >
                <img
                  loading="lazy"
                  width="40"
                  src={option.image}
                  alt={option.name}
                />
                <span>
                  {option.name} ({option.id})
                </span>
              </Box>
            )}
            onChange={(event, newValue) => handleAccountSelect(newValue)}
            renderInput={(params) => (
              <TextField
                {...params}
                label="Compte Utilisateur"
                variant="outlined"
                margin="normal"
              />
            )}
          />
        </DialogContent>
        <DialogActions>
          <Button onClick={handleCloseDialog} color="secondary">
            Annuler
          </Button>
          <Button
            onClick={handleAssociateButtonClick}
            color="primary"
            variant="contained"
          >
            Associer
          </Button>
        </DialogActions>
      </Dialog>
    </TableRow>
  );
}
