import Tooltip from "@mui/material/Tooltip";
import TableRow from "@mui/material/TableRow";
import DeleteIcon from "@mui/icons-material/Delete";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";
import Label from "../../../components/label";
import { IOrder } from "@/shared/_mock/_cartLive";
import { Checkbox } from "@mui/material";
import { fDate, fTime } from "@/utils/format-time";

// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  row: IOrder;
};

export default function UserTableRow({ row, selected }: Props) {
  const {
    name,
    statutPanier,
    email,
    price,
    id,
    CreatedAt,
    statutOrder,
    UGS,
    title,
    quantity,
    EditDate,
  } = row;

  return (
    <>
      <TableRow hover selected={selected}>
        <TableCell padding="checkbox">
          <Checkbox checked={selected} />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{id}</TableCell>
        <TableCell sx={{ display: "flex", alignItems: "center" }}>
          <ListItemText
            primary={name}
            secondary={email}
            primaryTypographyProps={{ typography: "body2" }}
            secondaryTypographyProps={{
              component: "span",
              color: "text.disabled",
            }}
          />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{title}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{UGS}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{quantity}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(CreatedAt)}
            secondary={fTime(CreatedAt)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{price}</TableCell>

        <TableCell>
          <Label
            variant="soft"
            color={
              (statutPanier === "payer" && "success") ||
              (statutPanier === "consulter" && "warning") ||
              (statutPanier === "supprimer" && "error") ||
              "default"
            }
          >
            {statutPanier}
          </Label>
        </TableCell>
        <TableCell>
          <Label
            variant="soft"
            color={
              (statutOrder === "Terminée" && "success") ||
              (statutOrder === "En cours" && "warning") ||
              (statutOrder === "En attente" && "error") ||
              "default"
            }
          >
            {statutOrder}
          </Label>
        </TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(EditDate)}
            secondary={fTime(EditDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
          <Tooltip title="Supprimer" placement="top" arrow>
            <IconButton color="error">
              <DeleteIcon />
            </IconButton>
          </Tooltip>
        </TableCell>
      </TableRow>
    </>
  );
}
