import * as Yup from "yup";
import { useMemo } from "react";
import { useForm } from "react-hook-form";
import { yupResolver } from "@hookform/resolvers/yup";

import Box from "@mui/material/Box";
import Alert from "@mui/material/Alert";
import Button from "@mui/material/Button";
import Dialog from "@mui/material/Dialog";
import MenuItem from "@mui/material/MenuItem";
import LoadingButton from "@mui/lab/LoadingButton";
import DialogTitle from "@mui/material/DialogTitle";
import DialogActions from "@mui/material/DialogActions";
import DialogContent from "@mui/material/DialogContent";
import { USER_STATUS_OPTIONS } from "@/shared/_mock/_cartLive";

import { useSnackbar } from "@/components/snackbar";
import FormProvider, { RHFSelect, RHFTextField } from "@/components/hook-form";

import { IUserItem } from "@/shared/_mock/_cartLive";
import Typography from "@mui/material/Typography";
import TextField from "@mui/material/TextField";

// ----------------------------------------------------------------------

type Props = {
  open: boolean;
  onClose: VoidFunction;
  currentUser?: IUserItem;
};

export default function UserQuickEditForm({
  currentUser,
  open,
  onClose,
}: Props) {
  const { enqueueSnackbar } = useSnackbar();

  const NewUserSchema = Yup.object().shape({
    name: Yup.string().required("Le nom est requis"),
    phone: Yup.string().required("Phone number is required"),
    pseudo: Yup.string().required("Le pseudo est requis"),
  });

  const defaultValues = useMemo(
    () => ({
      name: currentUser?.name || "",
      phone: currentUser?.phone || "",
      pseudo: currentUser?.pseudo || "",
      status: currentUser?.status,
    }),
    [currentUser]
  );

  const methods = useForm({
    resolver: yupResolver(NewUserSchema),
    defaultValues,
  });

  const {
    reset,
    handleSubmit,
    formState: { isSubmitting },
  } = methods;

  const onSubmit = handleSubmit(async (data) => {
    try {
      await new Promise((resolve) => setTimeout(resolve, 500));
      reset();
      onClose();
      enqueueSnackbar("Mise à jour réussie !");
      console.info("DONNÉES", data);
    } catch (error) {
      console.error(error);
    }
  });

  return (
    <Dialog
      fullWidth
      maxWidth={false}
      open={open}
      onClose={onClose}
      PaperProps={{
        sx: { maxWidth: 720 },
      }}
    >
      <FormProvider methods={methods} onSubmit={onSubmit}>
        <DialogTitle>Modifier</DialogTitle>

        <DialogContent>
          <Typography variant="subtitle2" component="h2">
            Nom d'utilisateur : {currentUser?.id}
          </Typography>
          <Box
            rowGap={3}
            columnGap={3}
            display="grid"
            gridTemplateColumns={{
              xs: "repeat(1, 1fr)",
              sm: "repeat(2, 1fr)",
            }}
            sx={{ mt: defaultValues.status === "pending" ? 0 : 3 }}
          >
            <RHFSelect name="status" label="Statut">
              {USER_STATUS_OPTIONS.map((status) => (
                <MenuItem key={status.value} value={status.value}>
                  {status.label}
                </MenuItem>
              ))}
            </RHFSelect>

            <RHFTextField name="name" label="Nom complet" />
            <RHFTextField name="phone" label="Numéro du téléphone " />
            <RHFTextField name="pseudo" label="Pseudo" />
          </Box>
        </DialogContent>

        <DialogActions>
          <Button variant="outlined" onClick={onClose}>
            Annuler
          </Button>

          <LoadingButton
            type="submit"
            variant="contained"
            loading={isSubmitting}
          >
            Mettre à jour
          </LoadingButton>
        </DialogActions>
      </FormProvider>
    </Dialog>
  );
}
