import Tooltip from "@mui/material/Tooltip";
import TableRow from "@mui/material/TableRow";

import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";
import { useBoolean } from "@/hooks/use-boolean";

import Label from "../../../components/label";
import Iconify from "@/components/iconify";

import { IUserItem } from "@/shared/_mock/_cartLive";

import UserQuickEditForm from "./user-quick-edit-form";

import { Avatar } from "@mui/material";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import BlockIcon from "@mui/icons-material/Block";

// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  row: IUserItem;
};

export default function UserTableRow({ row, selected }: Props) {
  const { name, status, email, pseudo, image, id, CreatedAt } = row;

  const quickEdit = useBoolean();

  const handleBanUser = (userId: any) => {};

  return (
    <TableRow
      sx={{ backgroundColor: status === "banned" ? "#FFEBEE" : "inherit" }}
    >
      <TableCell>
        <Tooltip title="Ajouter au panier">
          <IconButton sx={{ color: "#00e676" }}>
            <ShoppingCartIcon />
          </IconButton>
        </Tooltip>
      </TableCell>

      <TableCell sx={{ display: "flex", alignItems: "center" }}>
        <Avatar alt={name} src={image} sx={{ mr: 2 }} />
        <ListItemText
          primary={name}
          secondary={email}
          primaryTypographyProps={{ typography: "body2" }}
          secondaryTypographyProps={{
            component: "span",
            color: "text.disabled",
          }}
        />
      </TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{id}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{pseudo}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>
        {CreatedAt.toString()}
      </TableCell>

      <TableCell>
        <Label
          variant="soft"
          color={
            (status === "active" && "success") ||
            (status === "banned" && "error") ||
            "default"
          }
        >
          {status}
        </Label>
      </TableCell>

      <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
        <Tooltip title="Modifier" placement="top" arrow>
          <IconButton
            color={quickEdit.value ? "inherit" : "default"}
            onClick={quickEdit.onTrue}
          >
            <Iconify icon="solar:pen-bold" />
          </IconButton>
        </Tooltip>
        <Tooltip title="Bannir" placement="top" arrow>
          <IconButton onClick={() => handleBanUser(row.id)} color={"error"}>
            <BlockIcon />
          </IconButton>
        </Tooltip>
      </TableCell>

      <UserQuickEditForm
        currentUser={row}
        open={quickEdit.value}
        onClose={quickEdit.onFalse}
      />
    </TableRow>
  );
}
