import Stack from '@mui/material/Stack';
import Badge from '@mui/material/Badge';
import Avatar from '@mui/material/Avatar';
import IconButton from '@mui/material/IconButton';
import ListItemText from '@mui/material/ListItemText';
import AvatarGroup, { avatarGroupClasses } from '@mui/material/AvatarGroup';

import { fToNow } from '@/utils/format-time';
import {useGetNavItem, useMockedUser, useResponsive, useSearchParams } from '@/hooks';
import { IChatConversation, IChatParticipant } from '@/shared/types/chat';
import { useTheme } from '@mui/material/styles';
import { usePopover } from '@/shared/components/custom-popover';
import { Typography } from '@mui/material';

// ----------------------------------------------------------------------

type Props = {
  participants: IChatParticipant[];
  selectedId:string;
  children:React.ReactNode;
  conversation: IChatConversation;

};

export default function ChatHeaderDetail({ participants,children,conversation }: Props) {
  
  const { user } = useMockedUser();
  
  const group = participants.length > 1;

  const singleParticipant = participants[0];

  const mdUp = useResponsive('up', 'md');
  
  const theme = useTheme();

  const searchParams = useSearchParams();

  const conversationId = searchParams.get('id') || '';

  const {displayName, displayText,lastActivity, hasOnlineInGroup} =
  useGetNavItem({
    conversation,
    currentUserId: `${user?.id}`,
  });

  const popover = usePopover();  

  const renderGroup = (
    <>
    {mdUp && <AvatarGroup
      max={3}
      sx={{
        [`& .${avatarGroupClasses.avatar}`]: {
          width: 32,
          height: 32,
        },
      }}
    >
      {participants.map((participant) => (
        <Avatar key={participant.id} alt={participant.name} src={participant.avatarUrl} />
      ))}
     
    </AvatarGroup>}
    <Stack direction="column" alignItems="flex-start" sx={{width:1}} spacing={0} >
      <Typography variant='subtitle1'>{conversation.name} </Typography>
      {mdUp && <ListItemText
            sx={{width:'300px'}}
            primary={displayName}
            primaryTypographyProps={{
              noWrap: true,
              variant: conversation.unreadCount ? 'subtitle2' : 'body2',
              color: conversation.unreadCount ? 'text.primary' : 'text.secondary',
            }}
          />}
    </Stack>
    </>
  );

  const renderSingle = (
    <Stack flexGrow={1} direction="row" alignItems="center" spacing={2}>
      <Badge
        variant={singleParticipant.status}
        anchorOrigin={{ vertical: 'bottom', horizontal: 'right' }}
      >
        <Avatar src={singleParticipant.avatarUrl} alt={singleParticipant.name} />
      </Badge>

      <ListItemText
        primary={singleParticipant.name}
        secondary={
          singleParticipant.status === 'offline'
            ? fToNow(singleParticipant.lastActivity)
            : singleParticipant.status
        }
        secondaryTypographyProps={{
          component: 'span',
          ...(singleParticipant.status !== 'offline' && {
            textTransform: 'capitalize',
          }),
        }}
      />
    </Stack>
  );



  return (
    <>
    <Stack direction='row' alignContent={'flex-start'} alignItems={'center'} spacing={1} >
      {group ? renderGroup : renderSingle}
      </Stack>

      <Stack flexGrow={1} />
       
       {children}
      
      
    </>
  );
}
