
import Iconify from '@/components/iconify';
import Scrollbar from '@/components/scrollbar';
import { Height } from '@mui/icons-material';
import { Box, Card, Typography, Paper, Button, InputBase, TextField } from '@mui/material';
import { useState } from 'react';

// ----------------------------------------------------------------------

type Props = {
    onClose: () => void;
    value: string;
    setValue: (value: string) => void;
};

const linksTypes = [
    {
        id: 1,
        title: 'produit',
    },
    {
        id: 2,
        title: 'commande',
    },
    {
        id: 3,
        title: 'live',
    },
    {
        id: 4,
        title: 'ticket',
    }
];

export default function Shortlink({
    onClose,
    value,
    setValue
}: Props) {

    const [linkType, setLinkType] = useState<null | string>(null);
    const [id, setId] = useState<string>('');

    const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setId(e.target.value)
    }

    const onSubmit = () => {
        setValue(`${value}${linkType}/${id} `);
        onClose();
    }
    return (
        <>
            <Card
                variant='outlined'
                sx={{ padding: 1, borderRadius: 1, display: 'flex', flexDirection: 'column', alignItems: 'start', zIndex: 1000, position: 'absolute', bottom: 60, left: 4, right: 4, margin: 'auto' }}
            >


                {
                    !linkType ? (
                        <>
                            <Button onClick={onClose}sx={{ position: "absolute", zIndex:1000, top: 20, right: 20 }}><Iconify  icon="material-symbols:cancel"  color='#000' width={20} height={20} /></Button>
                            {linksTypes.map((link) => (
                                <Button onClick={() => setLinkType(link.title)} variant='contained' key={link.id} sx={{ width: 150, justifyContent: 'space-between', mb: 1 }}>
                                    <Typography sx={{ fontSize: 14 }}>{`/ ${link.title}`}</Typography>
                                </Button>

                            ))}
                        </>
                    ) : (
                        <Box sx={{ display: 'flex', gap: 2, alignItems: "center", width:"100%", justifyContent: "space-between" }}>
                            <Paper style={{
                                padding:4,
                                zIndex: 2,
                                flexShrink: 0,
                                gap:10,
                                display: 'flex',
                                alignItems: 'center',
                                justifyContent: 'center',
                                background: 'transparent',
                                borderRadius: 2,
                            }}>
                                <Button variant='contained' sx={{borderRadius: 20, height: 30}} >{linkType}</Button>
                                <input value={id} onChange={handleChange} style={{ borderRadius: 20, height: 30, paddingLeft:4 }} name='id' placeholder='id' />
                                <Button onClick={onSubmit}><Iconify style={{ height: 20, width: 20, color: 'gray', marginBottom: 2 }}  icon="iconamoon:send-fill" /></Button>
                            </Paper>
                            <Button onClick={onClose}><Iconify icon="material-symbols:cancel"  color='#000' width={20} height={20} /></Button>
                        </Box>
                    )
                }
            </Card>
        </>
    );
}
