import { Box, IconButton, Stack, Typography, useTheme } from "@mui/material";
import Iconify from "@/shared/components/iconify";
import ChatHeaderCompose from "./chat-header-compose";
import { useGetContacts, useGetConversation, useGetConversations } from "@/shared/api/chat";
import { useCollapseNav, useMockedUser, useResponsive, useSearchParams } from "@/hooks";
import React, { useCallback, useEffect, useState } from "react";
import { IChatParticipant } from "@/shared/types/chat";
import ChatMessageList from "./chat-message-list";
import ChatMessageInput from "./chat-message-input";


type Props = {
    children:React.ReactNode;
};
export default function ChatNewMessage(children:Props){


 ////////////////////////////////
  const {
    collapseDesktop,
    onCloseDesktop,
    onCollapseDesktop,
    //
    openMobile,
    onOpenMobile,
    onCloseMobile,
  } = useCollapseNav();

  const mdUp = useResponsive('up', 'md');

  useEffect(() => {
    if (!mdUp) {
      onCloseMobile();
    }else{
      onCloseDesktop();
      onOpenMobile();
    }
  }, [onCloseDesktop, mdUp]);

  ///////////////////////////////////////

    const { user } = useMockedUser();

    const searchParams = useSearchParams();

    const { contacts } = useGetContacts();

    const selectedConversationId = searchParams.get('id') || '';

    const [recipients, setRecipients] = useState<IChatParticipant[]>([]);

    const { conversation, conversationError } = useGetConversation(`${selectedConversationId}`);

    const participants: IChatParticipant[] = conversation
    ? conversation.participants.filter(
        (participant: IChatParticipant) => participant.id !== `${user?.id}`
      )
    : [];


    const handleAddRecipients = useCallback((selected: IChatParticipant[]) => {
        setRecipients(selected);
      }, []);


    const renderHead = ({ children }:Props) =>(
        <Stack
      direction="row"
      alignItems="center"
      flexShrink={0}
      sx={{ pl: 2, py: 1, minHeight: 72 }}
    >
        {children}
        <ChatHeaderCompose contacts={contacts} onAddRecipients={handleAddRecipients} >
          <Typography variant="subtitle2" sx={{ color: 'text.primary', mr: 2 }}>
            To :
          </Typography>
        </ChatHeaderCompose>
    </Stack>
    );

    const renderMessages = (
        <>
            <Stack
            sx={{
                width: 1,
                height: 1,
                overflow: 'hidden',
            }}
            >
            <ChatMessageList messages={conversation?.messages} participants={participants} />
            
            <ChatMessageInput
                recipients={recipients}
                onAddRecipients={handleAddRecipients}
                //
                selectedConversationId={selectedConversationId}
                disabled={!recipients.length && !selectedConversationId}
            />
            </Stack>
        </>
      );

    
    return (
        <>
            <Stack
            sx={{
              width: 1,
              height: 'calc(100vh - 270px)',
              overflow: 'hidden',
            }}
            
            
          >
            {renderHead(children)}
  
            <Stack
              direction="row"
              sx={{
                width: 1,
                height: 1,
                overflow: 'hidden',
                borderTop: (theme) => `solid 1px ${theme.palette.divider}`,
              }}
            >
              {renderMessages}
  
            </Stack>
            </Stack>

        </>
    );
}