import uniq from 'lodash/uniq';
import flatten from 'lodash/flatten';
import { useEffect, useCallback } from 'react';

import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import { useTheme } from '@mui/material/styles';
import IconButton from '@mui/material/IconButton';

import { useResponsive } from '@/hooks/use-responsive';

import Iconify from '@/shared/components/iconify';

import { IChatParticipant, IChatConversation } from '@/shared/types/chat';

import { useCollapseNav } from '@/hooks';
import ChatRoomGroup from './chat-room-group';
import ChatRoomSingle from './chat-room-single';
import ChatRoomAttachments from './chat-room-attachments';
import Scrollbar from '@/components/scrollbar';
import { Typography } from '@mui/material';


const NAV_WIDTH = 340;

type Props = {
  participants: IChatParticipant[];
  conversation: IChatConversation;
  children:React.ReactNode;
};

export default function ChatRoom({ participants, conversation,children }: Props) {
  const theme = useTheme();

  const lgUp = useResponsive('up', 'lg');
  const mdUp = useResponsive('up', 'md');

  const {
    collapseDesktop,
    onCloseDesktop,
    onCollapseDesktop,
    //
    openMobile,
    onOpenMobile,
    onCloseMobile,
  } = useCollapseNav();

  const handleToggleNav = useCallback(() => {
    if (lgUp) {
      onCollapseDesktop();
    } else {
      onOpenMobile();
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [lgUp]);

  const group = participants.length > 1;

  const attachments = uniq(flatten(conversation?.messages.map((messages) => messages.attachments)));

  const renderContent = (
    <>
      {group ? (
        <ChatRoomGroup participants={participants} />
      ) : (
        <ChatRoomSingle participant={participants[0]} />
      )}
        <Scrollbar>
        <ChatRoomAttachments attachments={attachments} />
        </Scrollbar>
    </>
  );

  return (
    <Box sx={{ position: 'relative' ,width:mdUp?NAV_WIDTH:1}}>
      <Stack direction='row' alignItems='center' 
        sx={{ position: 'absolute' ,
              mt:0,left:0,width:1,
              zIndex:111,
              backgroundColor:theme.palette.background.paper,
              borderLeft: mdUp?`solid 1px ${theme.palette.divider}`:'',
              }}>
        {children}
      <Typography variant='subtitle1'> Contacts Infos </Typography>
      </Stack>
        <Stack
          sx={{
            height: 1,
            flexShrink: 0,
            width:1,
            borderLeft: mdUp?`solid 1px ${theme.palette.divider}`:'',
            transition: theme.transitions.create(['width'], {
              duration: theme.transitions.duration.shorter,
            }),
            ...(collapseDesktop && {
              width: 0,
            }),
          }}
        >
          <Scrollbar>
          {renderContent}
          </Scrollbar>
        </Stack>
    </Box>
  );
}
