'use client';

import { useState, useEffect, useCallback } from 'react';

import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import Container from '@mui/material/Container';

import { paths } from '@/routes/paths';
import { useBoolean, useCollapseNav, useResponsive, useRouter, useSearchParams } from '@/hooks';

import { useMockedUser } from '@/hooks/use-mocked-user';

import { useGetContacts, useGetConversation, useGetConversations } from '@/shared/api/chat';

import { useSettingsContext } from '@/shared/components/settings';

import { IChatParticipant } from '@/shared/types/chat';

import ChatRoom from '../chat-room';
import ChatMessageList from '../chat-message-list';
import ChatMessageInput from '../chat-message-input';
import ChatHeaderDetail from '../chat-header-detail';
import ChatHeaderCompose from '../chat-header-compose';
import {Button, IconButton,MenuItem,Popover,Typography,useTheme } from '@mui/material';

import Iconify from '@/shared/components/iconify';
import ChatNavGlobal from '../chat-nav-global';
import ChatNav from '../chat-nav';
import { bgBlur } from '@/shared/theme/css';
import { alpha } from '@mui/material/styles';
import React from 'react';
import { updateConversationParticipants, updateConversationsWithParticipants } from '@/utils/chatUtils';
import ChatAddToChannel from '../chat-add-to-channel';
import { ConfirmDialog } from '@/shared/components/custom-dialog';

// ----------------------------------------------------------------------

export default function MainView() {


  ////////////////////////////////
  const {
    collapseDesktop,
    onCloseDesktop,
    onCollapseDesktop,
    //
    openMobile,
    onOpenMobile,
    onCloseMobile,
  } = useCollapseNav();

  const mdUp = useResponsive('up', 'md');

  useEffect(() => {
    if (!mdUp) {
      onCloseMobile();
    }else{
      onCloseDesktop();
      onOpenMobile();
    }
  }, [onCloseDesktop, mdUp]);

  ///////////////////////////////////////

  const router = useRouter();

  const { user } = useMockedUser();

  const settings = useSettingsContext();

  const searchParams = useSearchParams();

  const [showChatRoom, setShowChatRoom] = useState(false);


  const [closeConversation,setCloseConversation] = useState(false);

  const selectedConversationId = searchParams.get('id') || '';

  const [selectedId,setSelectedId] = useState(`${selectedConversationId}`);

  const theme = useTheme();


  const confirmDelete = useBoolean();

  const confirmLeave = useBoolean();

  const confirmBlock = useBoolean();
  const [showAddToChannel, setShowAddToChannel] = useState(false);

  const [recipients, setRecipients] = useState<IChatParticipant[]>([]);

  const { contacts } = useGetContacts();

  const { conversations, conversationsLoading } = useGetConversations();

  // État pour stocker l'état des notifications pour chaque conversation
  const [notificationsState, setNotificationsState] = useState<{ [key: string]: boolean }>(() => {

    const initialNotificationsState: { [key: string]: boolean } = {};
    conversations.allIds.forEach((conversationId) => {
      initialNotificationsState[conversationId] = true;
    });

    return initialNotificationsState;
  });

  const { conversation, conversationError } = useGetConversation(`${selectedConversationId}`);

  // Popover management for conversation actions

  const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };
  const [anchorEl, setAnchorEl] = React.useState<HTMLButtonElement | null>(null);
  const open = Boolean(anchorEl);
  const id = open ? 'simple-popover' : undefined;

  ///


  /// Notif ///

  const [AnonymousState, setAnonymousState] = useState<{ [key: string]: boolean }>(() => {

    const initialState: { [key: string]: boolean } = {};
    conversations.allIds.forEach((conversationId) => {
      initialState[conversationId] = true;
    });

    return initialState;
  });
  
  const handleCloseConversationClick = ()=>{
    handleClose();
    setCloseConversation(!closeConversation);
  }

 
  ///
 
  ///
  // Activer ou désactiver les notifications pour une conversation
  const toggleAnonymous = (conversationId: string) => {
    setAnonymousState((prevAnonymousState) => ({
      ...prevAnonymousState,
      [conversationId]: !prevAnonymousState[conversationId], // Inverse l'état des notifications pour cette conversation
    }));
  };

  /////////
  /// Notif ///

  const handleNotificationClick = ()=>{
    toggleNotifications(selectedConversationId);
  }
  ///
  // Activer ou désactiver les notifications pour une conversation
  const toggleNotifications = (conversationId: string) => {
    setNotificationsState((prevNotificationsState) => ({
      ...prevNotificationsState,
      [conversationId]: !prevNotificationsState[conversationId], // Inverse l'état des notifications pour cette conversation
    }));
  };

  /////////

  const participants: IChatParticipant[] = conversation
    ? conversation.participants.filter(
        (participant: IChatParticipant) => participant.id !== `${user?.id}`
      )
    : [];

  useEffect(() => {
    if (conversationError || !selectedConversationId) {
      router.push(paths.dashboard.chat);
    }
  }, [conversationError, router, selectedConversationId]);

  useEffect(() => {
    // Cette fonction s'exécute à chaque fois que l'URL change.
    const newSelectedId = searchParams.get('id') || '';
    setSelectedId(newSelectedId);
  }, [searchParams]); //

  const handleAddRecipients = useCallback((selected: IChatParticipant[]) => {
    setRecipients(selected);
  }, []);

  const handleToggleChatRoom = ()=>{
    setShowChatRoom(!showChatRoom);
    handleClose();
  }
  const handleReturnButtonClick = () => {
     
    //Ce code permet de supprimer le 'id' de conversation selectionnee de l'URL pour retourner à la vue d'ensemble des conversations
      const url = new URL(window.location.href);
      url.searchParams.delete('id');
      window.history.pushState({}, '', url);
      setSelectedId('');
  };
  
  const details = !!conversation;
  const renderconversationActions = (
      <Popover
        id={id}
        open={open}
        anchorEl={anchorEl}
        onClose={handleClose}
        anchorOrigin={{
          vertical: 'bottom',
          horizontal: 'right',
        }}
        transformOrigin={{
          vertical: 'top',
          horizontal: 'right',
        }}
        PaperProps={{
          sx:{border:(theme) => `solid 2px ${theme.palette.divider}`,
            marginTop:3,
             width:250},
        }}
        
      >
        <Typography sx={{px:1,py:1,display:'flex',cursor: 'pointer',
          alignItems:'center',
          '&:hover': {
            color: 'primary.main',
            backgroundColor:(theme) => alpha(theme.palette.primary.main, 0.1),
          },
          }}
          onClick={handleToggleChatRoom}
          
          >
            <Iconify icon={'octicon:info-24'} sx={{mr:1}}/>
          Infos
        </Typography>
        {!mdUp && <Typography sx={{ px:1,py:1,display:'flex',cursor: 'pointer',
          alignItems:'center',
          '&:hover': {
            color: 'primary.main',
            backgroundColor:(theme) => alpha(theme.palette.primary.main, 0.1),
          },}} 
          onClick={()=>{handleClose()}}
          >
            <Iconify icon={'eva:search-fill'} sx={{mr:1}}/>
          Rechercher 
          </Typography>}
          {selectedId!='' && conversations.byId[selectedConversationId]?.type!='GROUP'?
          <Typography sx={{ px:1,py:1,display:'flex',cursor: 'pointer',
            alignItems:'center',
            '&:hover': {
              color: 'primary.main', 
              backgroundColor:(theme) => alpha(theme.palette.primary.main, 0.1),
            },}} 
          >
              <Iconify icon={'gg:add'} sx={{mr:1}}/>
            Ajouter au canal
          </Typography>:<></>
          }
        {selectedId!='' && conversations.byId[selectedConversationId]?.type==='GROUP'?
          <Typography sx={{ px:1,py:1,display:'flex',cursor: 'pointer',
            alignItems:'center',
            '&:hover': {
              color: 'primary.main', 
              backgroundColor:(theme) => alpha(theme.palette.primary.main, 0.1),
            },}} 
          >
              <Iconify icon={'gg:add'} sx={{mr:1}}/>
            Ajouter des membres
          </Typography>:<></>
          }
        <Typography sx={{ px:1,py:1,display:'flex',cursor: 'pointer',
          alignItems:'center',
          '&:hover': {
            color: 'primary.main',
            backgroundColor:(theme) => alpha(theme.palette.primary.main, 0.1),
          },}} 
          onClick={()=>{confirmDelete.onTrue();handleClose()}}
          >
            <Iconify icon={'fluent:delete-32-regular'} sx={{mr:1}}/>
          Suppprimer canal
        </Typography>
        {conversations.byId[selectedConversationId]?.type!='GROUP'&&
          <Typography sx={{ px:1,py:1,display:'flex',cursor: 'pointer',
            alignItems:'center',
            color:(theme) => alpha(theme.palette.error.main, 0.9),
            '&:hover': {
              backgroundColor:(theme) => alpha(theme.palette.error.main, 0.1),
            },}} 
            onClick={()=>{confirmBlock.onTrue();handleClose()}}
          
            >
              <Iconify icon={'gg:block'} sx={{mr:1}}/>
            Bloquer utilisateur
          </Typography>
        }
      </Popover>
  );
  const renderHead = (
    <Stack
      direction="row"
      alignItems="center"
      flexShrink={0}
      sx={{ pr: 1, pl: !mdUp?0.5:2.5, py: 1, minHeight: 72 }}
    >
      {!mdUp?
        <IconButton  
            size="small"
            sx={{zIndex:1,
              mr:0.5,
            ...bgBlur({ opacity: 0.48, color: theme.palette.background.default }),
          }}
          onClick={handleReturnButtonClick}
          >
          <Iconify
            icon='eva:arrow-ios-back-fill'
            width={25}
          />
        </IconButton> : <></>}
      {selectedConversationId ? (
        <>{details && <ChatHeaderDetail participants={participants} selectedId={selectedConversationId} conversation={(conversation.type==='GROUP')? updateConversationParticipants(conversations.byId[selectedConversationId]):conversations.byId[selectedConversationId]}>
            { !mdUp && 
            <>
              <IconButton onClick={handleNotificationClick}>
                <Iconify icon={notificationsState[selectedConversationId]?"mdi:notifications":"mdi:notifications-off"} />
              </IconButton>
              <IconButton>
                <Iconify icon="solar:phone-bold" />
              </IconButton>
              <IconButton>
                <Iconify icon="solar:videocamera-record-bold" />
              </IconButton>
          </>}
            {
              mdUp && 
              <>
                <IconButton>
                  <Iconify icon="ic:round-search" />
                </IconButton>
                <IconButton onClick={handleNotificationClick}>
                  <Iconify icon={notificationsState[selectedConversationId]?"mdi:notifications":"mdi:notifications-off"} />
                </IconButton>
              </>
            }
            
            <IconButton onClick={handleClick} aria-describedby={id}>
              <Iconify icon="eva:more-vertical-fill" />
            </IconButton>
          </ChatHeaderDetail>}</>
      ) : (
        <ChatHeaderCompose contacts={contacts} onAddRecipients={handleAddRecipients} >
           <Typography variant="subtitle2" sx={{ color: 'text.primary', mr: 2 }}>
            To :
          </Typography>
        </ChatHeaderCompose>
      )}
    </Stack>
  );
  
  const renderNav = (
    <ChatNav
      contacts={contacts}
      conversations={updateConversationsWithParticipants(conversations)}
      loading={conversationsLoading}
      selectedConversationId={selectedConversationId} 
      />
  );

  const renderAddToChannel = (
    <ChatAddToChannel onClose={()=>setShowAddToChannel(false)} open={showAddToChannel} type={conversations.byId[selectedConversationId]?.type}/>
  );
  
  const renderDeleteConversation = (
    <ConfirmDialog
          open={confirmDelete.value}
          onClose={confirmDelete.onFalse}
          title="Supprimer Canal"
          content="vous étes sure de supprimer ce canal?"
          action={
            <Button variant="contained" color="error" onClick={confirmDelete.onFalse}>
              Delete
            </Button>
          }
     />
  );
  const renderLeaveChannel = (
    <ConfirmDialog
          open={confirmLeave.value}
          onClose={confirmLeave.onFalse}
          title="Leave channel"
          content="Are you sure want to leave this channel ?"
          action={
            <Button variant="contained" color="error" onClick={confirmDelete.onFalse}>
              Leave
            </Button>
          }
     />
  );
  const renderBlocksUsers = (
    <ConfirmDialog
          open={confirmBlock.value}
          onClose={confirmBlock.onFalse}
          title={`Block User`}
          content="Are you sure want to block this user ?"
          action={
            <Button variant="contained" color="error" onClick={confirmDelete.onFalse}>
              Block
            </Button>
          }
     />
  );
  const renderMessages = (
    
    <Stack
      sx={{
        width: 1,
        height: 1,
        overflow: 'hidden',
      }}
    >
      <ChatMessageList messages={conversation?.messages} participants={participants} />
      
      <ChatMessageInput
        recipients={recipients}
        onAddRecipients={handleAddRecipients}
        selectedConversationId={selectedConversationId}
        disabled={!recipients.length && !selectedConversationId}
      />
    </Stack>
  );
  {console.log("selectId : "+selectedId);}

  return !mdUp && !collapseDesktop? (
      <Container sx={{ width: '100%', maxWidth: '100%', p: 0,position:'fixed'}}>
        <ChatNavGlobal 
          contacts={contacts}
          conversations={conversations}
          loading={conversationsLoading}
          selectedConversationId={selectedConversationId}
        />
  
        <Stack direction="row" sx={{ height: 'calc(100vh - 150px)' }}>   
          {selectedId!==''?
              <Stack sx={{ width: 1, height: 1, overflow: 'hidden' }}>
              {!showChatRoom && renderHead}
    
              <Stack
                direction="row"
                sx={{
                  width: 1,
                  height: 1,
                  overflow: 'hidden',
                  borderTop: (theme) => `solid 1px ${theme.palette.divider}`,
                }}
              >
                {renderconversationActions}

                {showChatRoom ?
                  (
                    showChatRoom && 
                    <ChatRoom conversation={conversation} participants={participants} >
                        <IconButton onClick={handleToggleChatRoom} sx={{ ml: 1.5, my: 1.5,mr:2 }}><Iconify width={16} icon="mingcute:close-fill" /></IconButton>
                    </ChatRoom>

                  ):
                  renderMessages
                }
              </Stack>
            </Stack> :
            renderNav
          }
        </Stack>
        {renderLeaveChannel}
        {renderDeleteConversation}
        {renderBlocksUsers}
        {renderAddToChannel}
        
      </Container>
    
  ) : (

    <Container maxWidth={settings.themeStretch ? false : 'xl'} >
  
        <ChatNavGlobal 
          contacts={contacts}
          conversations={conversations}
          loading={conversationsLoading}
          selectedConversationId={selectedConversationId}
        />
  
        <Stack component={Card} direction="row" sx={{ height: '72vh' }}>
          {renderNav}
          {(openMobile ?<Stack
            sx={{
              width: 1,
              height: 1,
              overflow: 'hidden',
            }}
            
            
          >
            {renderHead}
  
            <Stack
              direction="row"
              sx={{
                width: 1,
                height: 1,
                overflow: 'hidden',
                borderTop: (theme) => `solid 1px ${theme.palette.divider}`,
              }}
            >
              {renderconversationActions}
              {renderDeleteConversation}
              {renderLeaveChannel}
              {renderBlocksUsers}
              
              {renderMessages}
              {renderAddToChannel}
              {renderAddToChannel}
              {showChatRoom && 
              <ChatRoom conversation={conversation} participants={participants} >
                  <IconButton onClick={handleToggleChatRoom} sx={{ ml: 1.5, my: 1.5,mr:2 }}><Iconify width={16} icon="mingcute:close-fill" /></IconButton>  
              </ChatRoom>}
            </Stack>
          </Stack> : <>          
          </>)}
          
        </Stack>
      </Container>
  );
}
