"use client";


import { useState, useCallback } from "react";

import Stack from "@mui/material/Stack";
import Button from "@mui/material/Button";
import Container from "@mui/material/Container";
import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarExport,
  GridActionsCellItem,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
  GridToolbarFilterButton,
  GridToolbarColumnsButton,
  GridColumnVisibilityModel,

} from "@mui/x-data-grid";


import { useBoolean } from "@/hooks/use-boolean";
import Iconify from "@/shared/components/iconify";
import { useSnackbar } from "@/shared/components/snackbar";
import EmptyContent from "@/shared/components/empty-content";
import { ConfirmDialog } from "@/shared/components/custom-dialog";
import { useSettingsContext } from "@/shared/components/settings";
import { Giftcard, IGiftCardvalue, IGiftcardFilter } from "@/contexts/types/giftcard";
import mockGiftcards from "@/shared/_mock/_giftcard";
import { RenderCellActivite, RenderCellCarteCadeauemail, RenderCellDateexpiration, RenderCellEmaildestinataire, RenderCellPdf, RenderCellSolde } from "./Giftedcard-table-row";
import { Card, Typography } from "@mui/material";
import CardContent from '@mui/material/CardContent';
import isEqual from "lodash/isEqual";
import GiftcardTableToolbar from "./Giftedcard-table-toolbar";
import GiftcardTableFiltersResult from "./Giftedcard-table-filters-result";






const defaultFilters: IGiftcardFilter = {

  dateexpiration: null,

};





const HIDE_COLUMNS = {
  category: false,

};

const HIDE_COLUMNS_TOGGLABLE = ["category", "actions"];

// ----------------------------------------------------------------------

export default function GiftcardListView() {
  const { enqueueSnackbar } = useSnackbar();

  const confirmRows = useBoolean();

  const settings = useSettingsContext();

  const [tableData, setTableData] = useState<Giftcard[]>(mockGiftcards);

  const [filters, setFilters] = useState(defaultFilters);

  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );
  const [columnVisibilityModel, setColumnVisibilityModel] =
    useState<GridColumnVisibilityModel>(HIDE_COLUMNS);





  const dateError = filters.dateexpiration === null;

  const dataFiltered = applyFilter({
    inputData: tableData,
    filters,
    dateError,
  });

  const canReset = !isEqual(defaultFilters, filters);

  const handleFilters = useCallback(
    (name: string, value: IGiftCardvalue) => {
      setFilters((prevState) => ({
        ...prevState,
        [name]: value,
      }));
    },
    []
  );

  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);

  const handleDeleteRow = useCallback(
    (id: string) => {
      const deleteRow = tableData.filter((row) => row.id !== id);

      enqueueSnackbar("Delete success!");

      setTableData(deleteRow);
    },
    [enqueueSnackbar, tableData]
  );

  const handleDeleteRows = useCallback(() => {
    const deleteRows = tableData.filter(
      (row) => !selectedRowIds.includes(row.id)
    );

    enqueueSnackbar("Delete success!");

    setTableData(deleteRows);
  }, [enqueueSnackbar, selectedRowIds, tableData]);



  const columns: GridColDef[] = [

    { field: "Numecarte", headerName: "Numero de carte", width: 200 },
    {
      field: "solde", headerName: "Solde", width: 200
      , renderCell: (params) => <RenderCellSolde params={params} />
    },
    {
      field: "dateexpiration", headerName: "Date d'expiration", width: 200
      , type: "date"
      , renderCell: (params) => <RenderCellDateexpiration params={params} />
    },
    {
      field: "Emaildestinataire", headerName: " Destinataire", width: 200,
      renderCell: (params) => <RenderCellEmaildestinataire params={params} />
    },
    {
      field: "activite", headerName: "Activité", width: 180
      , filterable: false
      , renderCell: (params) => <RenderCellActivite params={params} />
    },



    {
      field: "Carte cadeau d'email ", headerName: "Carte cadeau d'email", width: 200
      , filterable: false
      , renderCell: (params) => <RenderCellCarteCadeauemail params={params} />
    },
    {
      field: "Pdf", headerName: "Pdf", width: 200
      , filterable: false
      , renderCell: (params) => <RenderCellPdf params={params} />
    },





    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [





        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Supprimer"
          onClick={() => {
            handleDeleteRow(params.row.id);
          }}
          sx={{ color: "error.main" }}
        />,
      ],
    },
  ];

  const getTogglableColumns = () =>
    columns
      .filter((column) => !HIDE_COLUMNS_TOGGLABLE.includes(column.field))
      .map((column) => column.field);







  return (
    <>
      <div style={{ display: 'flex', marginBottom: '30px' }}>
        <Card sx={{ width: 290, border: '2px solid black', marginRight: '100px', marginLeft: '50px' }}>
          <CardContent style={{ display: 'flex', flexDirection: 'column' }}>
            <Typography variant="body2" sx={{ marginBottom: '20px' }}>
              Nombre de Cartes Cadeaux actives :
            </Typography>
            <Typography variant="h5" component="div" textAlign="center">
              7
            </Typography>

          </CardContent>
        </Card>

        <Card sx={{ width: 290, border: '2px solid black' }}>
          <CardContent>
            <Typography variant="body2" sx={{ marginBottom: '20px' }}>
              Soldes impayés :
            </Typography>
            <Typography variant="h5" component="div" textAlign="center">
              754.00 €
            </Typography>

          </CardContent>
        </Card>
      </div>
      <div style={{ display: 'flex', marginTop: '20px', marginBottom: '40px' }}>
        <Container
          maxWidth={settings.themeStretch ? false : "lg"}
          sx={{
            flexGrow: 1,
            display: "flex",
            flexDirection: "column",
          }}
        >
          <Box
            sx={{
              height: 700,
              width: "100%",
              flexGrow: { md: 1 },
              display: { md: "flex" },
              flexDirection: { md: "column" },
            }}
          >
            <DataGrid
              checkboxSelection
              disableRowSelectionOnClick
              rows={dataFiltered}
              columns={columns}

              getRowHeight={() => "auto"}
              pageSizeOptions={[5, 10, 25]}
              initialState={{
                pagination: {
                  paginationModel: { pageSize: 10 },
                },
              }}
              onRowSelectionModelChange={(newSelectionModel) => {
                setSelectedRowIds(newSelectionModel);
              }}
              columnVisibilityModel={columnVisibilityModel}
              onColumnVisibilityModelChange={(newModel) =>
                setColumnVisibilityModel(newModel)
              }
              slots={{
                toolbar: () => (
                  <>
                    <GridToolbarContainer>
                      <GiftcardTableToolbar
                        filters={filters}
                        onFilters={handleFilters}




                        dateError={dateError}
                      />
                      <GridToolbarQuickFilter />
                      <Stack
                        spacing={1}
                        flexGrow={1}
                        direction="row"
                        alignItems="center"
                        justifyContent="flex-end"
                      >
                        {!!selectedRowIds.length && (
                          <Stack>
                            <Button
                              size="small"
                              color="error"
                              startIcon={<Iconify icon="solar:trash-bin-trash-bold" />}
                              onClick={confirmRows.onTrue}
                            >
                              Delete ({selectedRowIds.length})
                            </Button>
                            <Button
                              size="small"
                              variant="outlined"
                              color="primary"
                              startIcon={<Iconify icon="heroicons-outline:pencil-alt" />}
                            //onClick={() => handleModifyRows(selectedRowIds)}
                            >
                              Modifier ({selectedRowIds.length})
                            </Button>
                          </Stack>
                        )}
                        <GridToolbarColumnsButton />
                        <GridToolbarFilterButton />
                        <GridToolbarExport />
                      </Stack>
                    </GridToolbarContainer>

                    {canReset && (
                      <GiftcardTableFiltersResult
                        filters={filters}
                        onFilters={handleFilters}
                        onResetFilters={handleResetFilters}
                        results={dataFiltered.length}
                        sx={{ p: 2.5, pt: 0 }}
                      />
                    )}
                  </>
                ),
                noRowsOverlay: () => <EmptyContent title="No Data" />,
                noResultsOverlay: () => <EmptyContent title="No results found" />,
              }}
              slotProps={{
                columnsPanel: {
                  getTogglableColumns,
                },
              }}
            />
          </Box>
        </Container>
        <ConfirmDialog
          open={confirmRows.value}
          onClose={confirmRows.onFalse}
          title="Supprimer"
          content={
            <>
              Êtes-vous sûr de vouloir supprimer{" "}
              <strong> {selectedRowIds.length} </strong> items?
            </>
          }
          action={
            <Button
              variant="contained"
              color="error"
              onClick={() => {
                handleDeleteRows();
                confirmRows.onFalse();
              }}
            >
              Supprimer
            </Button>
          }
        />
      </div>
    </>
  );

}



// ----------------------------------------------------------------------



function applyFilter({
  inputData,
  filters,
  

}: {
  inputData: Giftcard[];
  filters: IGiftcardFilter;
  dateError: boolean;
}) {
  const { dateexpiration } = filters;


  if (dateexpiration) {
    inputData = inputData.filter((row) => {
      if (dateexpiration) {
        const dateexpirationDate = new Date(row.dateexpiration);
        return (
          dateexpirationDate.getDate() === dateexpiration.getDate() &&
          dateexpirationDate.getMonth() === dateexpiration.getMonth() &&
          dateexpirationDate.getFullYear() === dateexpiration.getFullYear()
        );
      }
      return true;
    });
  }

  return inputData;
}
