import { useCallback } from 'react';
import Link from "@mui/material/Link";
import Stack from "@mui/material/Stack";
import { GridCellParams } from "@mui/x-data-grid";
import ListItemText from "@mui/material/ListItemText";
import { fCurrency } from "@/utils/format-number";
import { fTime, fDate } from "@/utils/format-time";
import { Button } from "@mui/material";
import IconButton from "@mui/material/IconButton";
import VisibilityIcon from "@mui/icons-material/Visibility";
import { Dialog, DialogTitle, DialogContent } from "@mui/material";
import React from 'react';
import { paths } from "@/routes/paths";
import RouterLink from "@/routes/router-link";
import { useRouter } from '@/hooks';
import DialogActions from '@mui/material/DialogActions';
import TextField from '@mui/material/TextField';
import DialogContentText from '@mui/material/DialogContentText';
import { useState } from 'react';





// ----------------------------------------------------------------------

type ParamsProps = {
  params: GridCellParams;
};






export function RenderCellNumecarte({ params }: ParamsProps) {

  return (
    <Link
      color="inherit"
      underline="hover"
      onClick={params.row.onViewRow}
      sx={{ cursor: "pointer" }}
    >
      {params.row.Numecarte}
    </Link>
  );
}

export function RenderCellSolde({ params }: ParamsProps) {
  return (
    <Stack direction="row" alignItems="center" spacing={1}>
      <ListItemText
        primary={params.row.solde+ ' €'} 
        
      />
    </Stack>
  );
}

export function RenderCellEmaildestinataire({ params }: ParamsProps) {
  return (
    <ListItemText
      primary={params.row.Emaildestinataire}

    />
  );
}


export function RenderCellDateexpiration({ params }: ParamsProps) {
  return (
    <ListItemText
      primary={fDate(params.row.dateexpiration)}
      secondary={fTime(params.row.dateexpiration)}
    />
  );
}

export function RenderCellActivite({ params }: ParamsProps) {
  const router = useRouter();
  const handleEditRow = useCallback(
    () => {
      router.push(paths.giftcard.giftcardActivity(params.row.id));
      localStorage.setItem('id', params.row.id);
    },
    [router, params.row.id]
  );
  return (
    <Stack direction="row" alignItems="center" spacing={1}>

      <IconButton onClick={handleEditRow} >
        <VisibilityIcon />
      </IconButton>

    </Stack>
  );
}



export function RenderCellCarteCadeauemail({ params }: ParamsProps) {
  return (
    <Button sx={{
      width: '230px',
      borderWidth: '0.5px',
      whiteSpace: 'nowrap',
    }} variant="outlined" color="primary" component={RouterLink} href={paths.giftcard.giftcardMail}>
      carte cadeau d'email
    </Button>
  );
}

export function RenderCellPdf({ params }: ParamsProps) {
  const handlePrint = () => {
    const printContent = `
    
   
    <html>
    <head>
      <title>Carte Cadeau</title>
     
      <style>
        @media print {
          body * {
            visibility: hidden;
          }
          .print-content, .print-content * {
            visibility: visible;
          }
          .print-content {
            position: absolute;
            left: 0;
            top: 0;
          }
        }
        .card-container {
          width: 45%;
          padding: 20px;
          border: 1px solid #ccc;
          border-radius: 8px;
          background-color: #f9f9f9;
          margin: 0 auto;
        }
        .card-container p {
          margin: 0;
          margin-bottom: 20px;
        }
        .card-content {
          background-color: #CD5C5C; /* Utilisation de la couleur sélectionnée */
          color: white;
          padding: 10px;
          border-radius: 4px;
          margin-bottom: 20px;
}
       .titre {
        color: #CD5C5C; /* Utilisation de la couleur sélectionnée */
        }
      </style>
    </head>
    <body>
      <div class="print-content">
        <div class="card-container">
          <h2  class="titre" ; style="margin-top: 0; text-align: center;">Carte Cadeau</h2>
          <Typography variant="subtitle2" gutterBottom>
         
          <div  style="text-align: center;">Destinataire: ${params.row.destinataire}</div>
          <div  style="text-align: center;">Numéro de la carte cadeau: ${params.row.Numecarte}</div>
          <div  style="text-align: center;">Montant: ${params.row.solde} €</div>
           
           
            <p> happy birthday </p>
          </Typography>

          <div class="card-content">
            <Typography variant="body2" gutterBottom>
              Vous venez de recevoir une carte cadeau Mydress-In 🥰
            </Typography>
            <Typography variant="body2" gutterBottom>
              Pour utiliser votre carte, venez nous retrouver en live sur notre page Facebook pour vivre une expérience shopping innovante et fun, ou consultez notre site web www.mydressin.fr
            </Typography>
            <Typography variant="body2" gutterBottom>
              Nous sommes en live :
              Les vendredis de 18h à 22h
              Les samedis de 12h à 22h
              Les mardis et mercredis de 18h à 22h
            </Typography>
            <Typography variant="body2" gutterBottom>
              Vous n'êtes pas encore cliente Mydress-In ? Afin de pouvoir commander, n'hésitez pas à créer votre compte client ici :<a href= https://mydress-in.shop/connexion/ > https://mydress-in.shop/connexion/</a>
            </Typography>
            <Typography variant="body2" gutterBottom>
              Une fois votre compte créé nous pourrons mettre vos articles commandés en live dans vos paniers !
              A très vite sur nos live ! Et bon shopping !!
              L'équipe Mydress-In
            </Typography>
          </div>

          <Typography variant="subtitle2" gutterBottom>
            <p style="margin-top: 20px;">Valide jusqu'au 31 décembre 2024</p>
          </Typography>
        </div>
      </div>
    </body>
  </html>

`;


    const printWindow = window.open('', '', 'width=600,height=400');
    if (printWindow) {
      printWindow.document.write(printContent);
      printWindow.document.close();
      printWindow.print();
    }
  };
  return (
    <Button
      variant="outlined" color="primary"
      onClick={() => handlePrint()}
      sx={{ minWidth: '150px', borderWidth: '0.5px', whiteSpace: 'nowrap', textTransform: 'none' }}
    >
      PDF
    </Button>
  );
}
export function RenderCellActions({ params }: ParamsProps) {
  return (
    <Stack direction="row">
      <Button variant="outlined" color="primary" style={{ marginRight: '5px' }}>Modifier</Button>
      <Button variant="outlined" color="error">Supprimer</Button>
      <Button variant="outlined" color="primary" style={{ marginLeft: '5px' }}>Dupliquer</Button>
    </Stack>
  );
}