"use client";


import { useState, useEffect, useCallback, use } from "react";
import Stack from "@mui/material/Stack";
import Button from "@mui/material/Button";
import Container from "@mui/material/Container";
import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarExport,
  GridActionsCellItem,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
  GridToolbarFilterButton,
  GridToolbarColumnsButton,
  GridColumnVisibilityModel,
} from "@mui/x-data-grid";
import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";
import { useBoolean } from "@/hooks/use-boolean";
import Iconify from "@/shared/components/iconify";
import { useSnackbar } from "@/shared/components/snackbar";
import EmptyContent from "@/shared/components/empty-content";
import { ConfirmDialog } from "@/shared/components/custom-dialog";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import { Giftcard, activite } from "@/contexts/types/giftcard";
import mockGiftcards from "@/shared/_mock/_giftcard";
import { Dialog, DialogTitle, DialogContent, Grid, Card, FormControl, CardHeader } from "@mui/material";
import React from 'react';
import DialogActions from '@mui/material/DialogActions';
import TextField from '@mui/material/TextField';
import DialogContentText from '@mui/material/DialogContentText';
import { RenderCellDatecreation, RenderCellEmaildestinataire, RenderCellMontant, RenderCellSolde } from "./Activity-table-row";




type Props = {
  giftCardId?: string;
};



// ----------------------------------------------------------------------


const HIDE_COLUMNS = {
  category: false,
};

const HIDE_COLUMNS_TOGGLABLE = ["category", "actions"];

// ----------------------------------------------------------------------

export default function ActivityListView({ giftCardId }: Props) {
  const { enqueueSnackbar } = useSnackbar();

  const confirmRows = useBoolean();

  const router = useRouter();

  const settings = useSettingsContext();

  // const { activities , activitiesLoading } = useGetGiftCardActivities(giftCardId);

  const [tableData, setTableData] = useState<Giftcard[]>(mockGiftcards);

  const [tabledataActivity, setTableDataActivity] = useState<activite[]>([]);


  const [] = useState<Giftcard[]>(mockGiftcards);

  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );

  const [columnVisibilityModel, setColumnVisibilityModel] =
    useState<GridColumnVisibilityModel>(HIDE_COLUMNS);

  // useEffect(() => {
  //   if (giftcards.length) {
  //     setTableData(giftcards);
  //   }
  // }, [giftcards]);


  useEffect(() => {
    const nouvellesActivitesFiltrees: activite[] = [];

    tableData.forEach(giftcard => {
      if (giftcard.id === giftCardId) {
        // Vérifie si l'activité existe déjà dans la liste

        nouvellesActivitesFiltrees.push(...giftcard.activite);
      }

    });

    setTableDataActivity(nouvellesActivitesFiltrees);
    console.log(nouvellesActivitesFiltrees);
    console.log(tableData);
    console.log(giftCardId);
  }, [tableData, giftCardId]);






  const handleDeleteRow = useCallback(
    (id: string) => {
      const deleteRow = tabledataActivity.filter((row) => row.id !== id);

      enqueueSnackbar("Delete success!");

      setTableDataActivity(deleteRow);
    },
    [enqueueSnackbar, tabledataActivity]
  );

  const handleDeleteRows = useCallback(() => {
    const deleteRows = tabledataActivity.filter(
      (row) => !selectedRowIds.includes(row.id)
    );

    enqueueSnackbar("Delete success!");

    setTableDataActivity(deleteRows);
  }, [enqueueSnackbar, selectedRowIds, tabledataActivity]);



  const [openAmount, setOpenAmount] = useState(false);
  const [amountToAdd, setAmountToAdd] = useState('');


  const [nomdestinataire, setNomdestinataire] = useState<string>('');
  const [emailbeneficiaire, setEmailbeneficiaire] = useState<string>('');
  const [message, setMessage] = useState<string>('');
  const [emailBeneficiaire, setEmailBeneficiaire] = useState<string>('');


  useEffect(() => {
    const giftCard = tableData.find((giftcard) => giftcard.id === giftCardId);
    if (giftCard) {
      setEmailBeneficiaire(giftCard.Emailbeneficiaire);
    } else {
      setEmailBeneficiaire('');
    }
  }, [tableData, giftCardId]);


  useEffect(() => {
    const giftCard = tableData.find((giftcard) => giftcard.id === giftCardId);
    if (giftCard) {
      setMessage(giftCard.message);
    } else {
      setMessage('');
    }
  }, [tableData, giftCardId]);





  useEffect(() => {
    if (tabledataActivity.length > 0) {
      const firstActivity = tabledataActivity[0];
      setNomdestinataire(firstActivity.Emaildestinataire);
    } else {
      setNomdestinataire('');
    }
  }, [tabledataActivity]);

  const handleClickOpenAmount = () => {
    setOpenAmount(true);
  };

  const handleCloseAmount = () => {
    setOpenAmount(false);
  };

  const [openRemark, setOpenRemark] = useState(false);
  const [remarkToAdd, setRemarkToAdd] = useState('');

  const handleClickAddRemark = () => {
    setOpenRemark(true);
  };

  const handleCloseRemark = () => {
    setOpenRemark(false);
  };

  const columns: GridColDef[] = [

    {
      field: "datecreation",
      headerName: "Date de Création",
      width: 200,
      renderCell: (params) => (<RenderCellDatecreation params={params} />),
    },
    {
      field: "action",
      headerName: "Action",
      width: 200,
    },
    {
      field: "Emaildestinataire",
      headerName: "Destinataire",
      width: 200,
      renderCell: (params) => (<RenderCellEmaildestinataire params={params} />),
    },
    {
      field: "Remarque",
      headerName: "Remarque",
      width: 350,
    },
    {
      field: "Montant",
      headerName: "Montant",
      width: 200,
      renderCell: (params) => (<RenderCellMontant params={params} />),
    },
    {
      field: "solde",
      headerName: "Solde",
      width: 200,
      renderCell: (params) => (<RenderCellSolde params={params} />),
    },




    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [

        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Supprimer"
          onClick={() => {
            handleDeleteRow(params.row.id);
          }}
          sx={{ color: "error.main" }}
        />,
      ],
    },
  ];

  const getTogglableColumns = () =>
    columns
      .filter((column) => !HIDE_COLUMNS_TOGGLABLE.includes(column.field))
      .map((column) => column.field);

  return (
    <>
      <CustomBreadcrumbs
        heading="Details de l'activité"
        links={[
          {
            name: 'dashboard',
            href: paths.dashboard.root,
          },

          {
            name: 'liste des cartes cadeaux',
            href: paths.giftcard.all_giftcard,
          },

          {
            name: 'details de l\'activité',
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />


      <Stack direction="row" spacing={2} sx={{ ml: 'auto' }}>
        <Button
          size="small"
          variant="outlined"
          color="primary"
          startIcon={<Iconify icon="heroicons-outline:pencil-alt" />}
          onClick={handleClickAddRemark}
        >
          Ajouter une remarque
        </Button>

        <Dialog open={openRemark} onClose={handleCloseRemark} aria-labelledby="form-dialog-title">
          <DialogTitle id="form-dialog-title">Ajouter une remarque</DialogTitle>
          <DialogContent>
            <DialogContentText>
              Saisissez votre remarque ici :
            </DialogContentText>
            <TextField
              autoFocus
              margin="dense"
              id="remark"
              label="Remarque"
              type="text"
              fullWidth
              value={remarkToAdd}
              onChange={(e) => setRemarkToAdd(e.target.value)}
            />
          </DialogContent>
          <DialogActions>
            <Button onClick={handleCloseRemark} color="primary">
              Annuler
            </Button>
            <Button onClick={() => {
              // Ajoutez ici la logique pour traiter la remarque, puis fermez la boîte de dialogue
              handleCloseRemark();
            }} color="primary">
              Valider
            </Button>
          </DialogActions>
        </Dialog>




        <Button size="small" // Taille du bouton (small pour petit)
          variant="outlined"
          color="primary"
          startIcon={<Iconify icon="heroicons-outline:pencil-alt" />}
          sx={{ ml: 1, }} onClick={handleClickOpenAmount}>
          Ajuster le montant
        </Button>
      </Stack>
      <Dialog open={openAmount} onClose={handleCloseAmount} aria-labelledby="form-dialog-title">
        <DialogTitle id="form-dialog-title">Ajuster le montant</DialogTitle>
        <DialogContent>
          <DialogContentText>
            Saisir le montant à ajouter
          </DialogContentText>
          <TextField
            autoFocus
            margin="dense"
            id="name"
            label="Montant"
            type="number"
            fullWidth
            value={amountToAdd}
            onChange={(e) => setAmountToAdd(e.target.value)}
          />
        </DialogContent>
        <DialogActions>
          <Button onClick={handleCloseAmount} color="primary">
            Annuler
          </Button>
          <Button onClick={handleCloseAmount} color="primary">
            Valider
          </Button>
        </DialogActions>
      </Dialog>
      <Container
        maxWidth={settings.themeStretch ? false : "lg"}
        sx={{
          flexGrow: 1,
          display: "flex",
          flexDirection: "column",
        }}
      >
        <Box
          sx={{
            height: 500,
            width: "100%",
            flexGrow: { md: 1 },
            display: { md: "flex" },
            flexDirection: { md: "column" },
          }}
        >
          <DataGrid
            checkboxSelection
            disableRowSelectionOnClick
            rows={tabledataActivity}

            columns={columns}

            getRowHeight={() => "auto"}
            pageSizeOptions={[5, 10, 25]}
            initialState={{
              pagination: {
                paginationModel: { pageSize: 10 },
              },
            }}
            onRowSelectionModelChange={(newSelectionModel) => {
              setSelectedRowIds(newSelectionModel);
            }}
            columnVisibilityModel={columnVisibilityModel}
            onColumnVisibilityModelChange={(newModel) =>
              setColumnVisibilityModel(newModel)
            }
            slots={{
              toolbar: () => (
                <>
                  <GridToolbarContainer>


                    <GridToolbarQuickFilter />

                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >
                      {!!selectedRowIds.length && (
                        <Stack>
                          <Button
                            size="small"
                            color="error"
                            startIcon={
                              <Iconify icon="solar:trash-bin-trash-bold" />
                            }
                            onClick={confirmRows.onTrue}
                          >
                            Delete ({selectedRowIds.length})
                          </Button>
                          <Button
                            size="small"
                            variant="outlined"
                            color="primary"
                            startIcon={
                              <Iconify icon="heroicons-outline:pencil-alt" />
                            }
                          //onClick={() => handleModifyRows(selectedRowIds)}
                          >
                            Modifier ({selectedRowIds.length})
                          </Button>
                        </Stack>
                      )}

                      <GridToolbarColumnsButton />
                      <GridToolbarFilterButton />
                      <GridToolbarExport />
                    </Stack>
                  </GridToolbarContainer>


                </>
              ),
              noRowsOverlay: () => <EmptyContent title="No Data" />,
              noResultsOverlay: () => <EmptyContent title="No results found" />,
            }}
            slotProps={{
              columnsPanel: {
                getTogglableColumns,
              },
            }}
          />
        </Box>
      </Container>

      <ConfirmDialog
        open={confirmRows.value}
        onClose={confirmRows.onFalse}
        title="Supprimer"
        content={
          <>
            Êtes-vous sûr de vouloir supprimer{" "}
            <strong> {selectedRowIds.length} </strong> items?
          </>
        }
        action={
          <Button
            variant="contained"
            color="error"
            onClick={() => {
              handleDeleteRows();
              confirmRows.onFalse();
            }}
          >
            Supprimer
          </Button>
        }
      />
      <Grid xs={12} md={12}>
        <Card>


          <Stack spacing={4} sx={{ p: 2, marginLeft: 'auto' }}>

            <FormControl>
              <CardHeader title="details" style={{ marginBottom: '20px' }} />



              <p id="destinataire-label" style={{ marginBottom: '20px' }}>Destinataire : {nomdestinataire}</p>
              <p id="montant-label" style={{ marginBottom: '20px' }}>Bénéficiaire : {emailBeneficiaire}</p>

              <p id="message-label" style={{ marginBottom: '20px' }}>Message : {message}</p>






            </FormControl>

          </Stack>
        </Card>

      </Grid>
    </>



  );
}

// ----------------------------------------------------------------------


