import Box from '@mui/material/Box';
import TableRow from '@mui/material/TableRow';
import Checkbox from '@mui/material/Checkbox';
import TableHeadMui from '@mui/material/TableHead';
import TableCell from '@mui/material/TableCell';
import { Theme, SxProps } from '@mui/material/styles';
import TableSortLabel from '@mui/material/TableSortLabel';

// ----------------------------------------------------------------------

const visuallyHidden = {
    border: 0,
    margin: -1,
    padding: 0,
    width: '1px',
    height: '1px',
    overflow: 'hidden',
    position: 'absolute',
    whiteSpace: 'nowrap',
    clip: 'rect(0 0 0 0)',
} as const;

const TABLE_HEAD = [
    { id: 'image', label: 'image', align: 'left' },
    { id: 'title', label: 'titre', align: 'left' },
    { id: 'startDate', label: 'Date de début', align: 'left' },
    { id: 'startTime', label: 'Heure de début', align: 'left' },
    { id: 'description', label: 'Description', align: 'left' },
    { id: 'status', label: 'Status', align: 'left' },
    { id: 'actions', label: '', align: 'right' },

];

type Props = {
    order?: 'asc' | 'desc';
    orderBy?: string;
    onSort?: (id: string) => void;
    sx?: SxProps<Theme>;
};

export default function TableHead({
    order,
    orderBy,
    onSort,
    sx,
}: Props) {
    return (
        <TableHeadMui sx={sx}>
            <TableRow>


                {TABLE_HEAD.map((headCell) => (
                    <TableCell
                        key={headCell.id}
                        align={headCell.align as ("left" | "center") || 'left'}
                        sortDirection={orderBy === headCell.id ? order : false}
                    // sx={{ width: headCell.width, minWidth: headCell.minWidth }}
                    >
                        {onSort ? (
                            <TableSortLabel
                                hideSortIcon
                                active={orderBy === headCell.id}
                                direction={orderBy === headCell.id ? order : 'asc'}
                                onClick={() => onSort(headCell.id)}
                            >
                                {headCell.label}

                                {orderBy === headCell.id ? (
                                    <Box sx={{ ...visuallyHidden }}>
                                        {order === 'desc' ? 'sorted descending' : 'sorted ascending'}
                                    </Box>
                                ) : null}
                            </TableSortLabel>
                        ) : (
                            headCell.label
                        )}
                    </TableCell>
                ))}
            </TableRow>
        </TableHeadMui>
    );
}
