
import Button from '@mui/material/Button';
import Avatar from '@mui/material/Avatar';
import Divider from '@mui/material/Divider';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import Checkbox from '@mui/material/Checkbox';
import TableCell from '@mui/material/TableCell';
import IconButton from '@mui/material/IconButton';
import ListItemText from '@mui/material/ListItemText';

import { useBoolean } from '@/hooks';
import { fDate, fTime } from '@/utils/format-time';

import Label from '@/shared/components/label';
import Iconify from '@/shared/components/iconify';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { ILiveItem, LiveStatus } from '@/shared/types/live';


type Props = {
  row: ILiveItem;
  selected: boolean;
  onViewRow: VoidFunction;
  onEditRow: VoidFunction;
  onViewStats: VoidFunction
};

export default function LiveTableRow({
  row,
  onViewRow,
  onEditRow,
  onViewStats
}: Props) {
  const { title, description, startDate, status ,image} = row;
  const popover = usePopover();
  const openDetails = useBoolean();




  return (
    <>

      <TableRow hover  >
        <TableCell >
          <Avatar
            alt={title}
            src={image}
            variant="rounded"
            sx={{ width: 64, height: 64, mr: 2 }}
          />
        </TableCell>

        <TableCell >
          {title}
        </TableCell>

        <TableCell>
          <ListItemText
            primary={fDate(startDate)}
            primaryTypographyProps={{ typography: 'body2', noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: 'span',
              typography: 'caption',
            }}
          />
        </TableCell>

        <TableCell>
          <ListItemText
            primary={fTime(startDate)}
            primaryTypographyProps={{ typography: 'body2', noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: 'span',
              typography: 'caption',
            }}
          />
        </TableCell>

        <TableCell >{description}</TableCell>
        <TableCell>
          <Label
            variant="soft"
            color={
              (status == LiveStatus.REPLAY && 'success') ||
              (status == LiveStatus.ONGOING && 'warning') ||
              (status == LiveStatus.COMING && 'error') ||
              'default'
            }
          >
            {status}
          </Label>
        </TableCell>

        <TableCell align="right" sx={{ px: 1 }}>
          <IconButton color={popover.open ? 'inherit' : 'default'} onClick={popover.onOpen}>
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>

      </TableRow>

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        arrow="right-top"
        sx={{ width: 160 }}
      >
        <MenuItem
          onClick={() => {
            onViewRow();
            openDetails.onTrue()
            popover.onClose();

          }}

        >

          <Iconify icon="solar:eye-bold" />
          Details
        </MenuItem>
        <MenuItem
          onClick={() => {
            onEditRow();
            popover.onClose();
          }}
          style={{ outline: 'none' }}
        >

          <Iconify icon="solar:pen-bold" />
          Modifier
        </MenuItem>
        <MenuItem
          onClick={() => {
            onViewStats();
            popover.onClose();
          }}
          style={{ outline: 'none' }}
        >
          <Iconify icon="icomoon-free:stats-bars" />
          Stats
        </MenuItem>
      </CustomPopover>
    </>
  );
}
