import { useState } from 'react';

import { useResponsive } from '@/hooks';
import InputEmoji from 'react-input-emoji'
import Iconify from '@/components/iconify';
import { addCommentLive } from '@/shared/api/live';
import { Card, IconButton, Paper, Typography, useTheme } from '@mui/material';
import { ILiveComment } from '@/shared/types/live';


type Props = {
    liveId: string;
    parentComment: ILiveComment | null;
    changeParentComment: (comment: ILiveComment | null) => void
};

export default function CommentsInput({
    liveId, parentComment, changeParentComment
}: Props) {
    const [comment, setComment] = useState('');

    const theme = useTheme();

    const inputStyle = parentComment ? {
        background: theme.palette.background.default,
    } : {};


    const handleSendComment = async () => {
        try {
            if (comment !== '') {
                await addCommentLive({
                    content: comment,
                    type: "CHAT",
                    sender: "1",
                    senderName: "oussama",
                    parent: parentComment ? parentComment : undefined,
                    liveStream: liveId
                });
                setComment('');
                changeParentComment(null);
            }

        } catch (error) {
            console.error(error);
        }
    };

    return (
        <Paper style={{

            zIndex: 2,
            flexShrink: 0,
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
            justifyContent: 'center',
            width: '98%',
            left: '50%',
            borderRadius: '20px',
            ...inputStyle,
            position: 'absolute',
            transform: 'translateX(-50%)',
            bottom: 1,
            paddingRight: 4,
        }}>
            
            {parentComment && <Paper style={{
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'start',
                gap: 4,
                width: '100%',
                padding: 10,
                marginTop: 2,
                borderRadius: 2,
                background: 'transparent',
            }}>
                <Card sx={{ position: "relative", width: "100%", display: "flex", alignItems: "center",wordWrap: 'break-word',  borderRadius: "40px", gap: 2, paddingX: 1, }}>
                    <Typography variant="body2" sx={{ color: 'gray' }}>
                        {parentComment?.senderName}:
                    </Typography>
                    <Typography variant="body1" >
                        {parentComment?.content}
                    </Typography>
                    <IconButton onClick={() => changeParentComment(null)} sx={{ position: "absolute", right: 0, padding: 1 }} size="small">
                        <Iconify style={{ color: 'gray', marginBottom: 2 }} width={20} icon="ic:sharp-cancel" />
                    </IconButton>
                </Card>

            </Paper>}

            <Paper style={{
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                width: '100%',
                padding: 0,
                background: 'transparent',
            }}>
                <InputEmoji
                    value={comment}
                    cleanOnEnter
                    onEnter={handleSendComment}
                    onChange={(value) => setComment(value)}
                    placeholder="Type a message"
                    height={20}
                />

                <Iconify onClick={handleSendComment} style={{ height: 30, width: 30, color: 'gray', marginBottom: 2 }} icon="iconamoon:send-fill" />
            </Paper>
        </Paper>
    );
}
