import { formatDistanceToNowStrict } from 'date-fns';

import Stack from '@mui/material/Stack';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';


import Iconify from '@/components/iconify';

import { ILiveComment } from '@/shared/types/live';
import { Card, useTheme, alpha } from '@mui/material';
import { bgGradient } from '@/shared/theme/css';
import { useResponsive } from '@/hooks';



type Props = {
  comment: ILiveComment;
  changeParentComment: (comment: ILiveComment) => void;

};

export default function LiveCommentItem({ comment, changeParentComment }: Props) {

  const { content, senderName, parent } = comment;
  const theme = useTheme();
  const mdUp = useResponsive('up', 'md');
  const bgStyle = mdUp ? {
    ...bgGradient({

      direction: '135deg',
      startColor: alpha(theme.palette['primary'].light, 0.2),
      endColor: alpha(theme.palette['primary'].main, 0.2),
    }),
    width: "100%",
    p: .5,
    fontSize: theme.typography.pxToRem(12),
  } : {
    fontSize: theme.typography.pxToRem(12),
    backgroundColor: 'rgb(0 0 0 / 50%)',
    color: 'white',
    borderColor: 'gray',
    textDecorationColor: 'gray',
    width: 200,
    p: .5,
  };

  const renderInfo = (
    <Typography
      noWrap
      variant="caption"
      sx={{
        mr: 'auto',
        color: 'grey'
      }}
    >
      {`${senderName},`} &nbsp;
      {mdUp && formatDistanceToNowStrict(new Date(), {
        addSuffix: true,
      })}
    </Typography>
  );

  const renderBody = (
    <Card
      sx={{
        borderRadius: 1,
        ...bgStyle,
        height: 'auto',
        maxWidth: '100%',
        wordWrap: 'break-word'
      }}
    >
      {parent && (
        <Stack
          direction="row"
          alignItems="center"
          sx={{
            borderLeft: '2px solid',
            borderRight: '2px solid',
            borderColor: 'primary.main',
            borderRadius: 1,
            pl: 1,
            mb: 1,
            width: '100%',
            flexWrap: 'wrap', 
          }}
        >
          <Typography
            variant="caption"
            sx={{ color: 'primary.main', flexShrink: 0 }} 
          >
            {parent.senderName}
          </Typography>
          <Typography
            variant="caption"
            sx={{
              color: 'text.secondary',
              marginLeft: 1,
              overflow: 'hidden',
              textOverflow: 'ellipsis',
              whiteSpace: 'normal', 
              flexGrow: 1,
              wordBreak: 'break-word', 
            }}
          >
            {parent.content}
          </Typography>
        </Stack>
      )}
      <Typography variant="body2">
        {content}
      </Typography>
    </Card>
  );


  const renderActions = (
    <Stack
      direction="row"
      className="message-actions"
      sx={{
        pt: 0.5,
        opacity: 0,
        bottom: '100%',
        right: 1,
        position: 'absolute',
        transition: (theme) =>
          theme.transitions.create(['opacity'], {
            duration: theme.transitions.duration.shorter,
          }),
      }}
    >
      <IconButton onClick={() => changeParentComment(comment)} size="small">
        <Iconify icon="solar:reply-bold" width={16} />
      </IconButton>
      <IconButton size="small">
        <Iconify icon="material-symbols:delete" width={16} />
      </IconButton>
      <IconButton size="small">
        <Iconify icon="mdi:pin" width={16} />
      </IconButton>
    </Stack>
  );

  return (
    <Stack direction="column" justifyContent={'unset'} sx={{ mb: 2 }}>
      <Stack alignItems="flex-end">
        {renderInfo}


      </Stack>
      <Stack
        direction="row"
        alignItems="flex-end"
        sx={{
          position: 'relative',
          '&:hover': {
            '& .message-actions': {
              opacity: 1,
            },
          },
        }}
      >
        {renderBody}
        {renderActions}
      </Stack>
    </Stack>
  );
}
