"use client";

import React, { useEffect, useRef } from 'react';
import { Box } from '@mui/material';
import Scrollbar from '@/shared/components/scrollbar';
import LiveCommentItem from './details-comments-item';
import { ILiveComment } from '@/shared/types/live';
import useLiveComments from '@/hooks/use-live-comments';
import { useLiveData } from '@/contexts/live-stats';

export default function CommentsList({ changeParentComment }: { changeParentComment: (comment: ILiveComment | null) => void }){
  const liveData = useLiveData();
  const comments = useLiveComments(liveData);
  const latestCommentRef = useRef<HTMLDivElement | null>(null);
  const scrollbarRef = useRef<HTMLDivElement>();

  useEffect(() => {
    if (latestCommentRef.current && scrollbarRef.current) {
      latestCommentRef.current.scrollIntoView({ behavior: 'smooth' });
    }
  }, [comments]);

  return (
    <Scrollbar sx={{ px: 2, py: 5, height: 1, color: 'transparent' }}>
      <Box>
        {comments.map((comment, index) => (
          <LiveCommentItem
            changeParentComment={changeParentComment}
            key={comment.id}
            comment={comment}
            
          />
        ))}
        <div ref={latestCommentRef} />
      </Box>
    </Scrollbar>
  );
}
