import { useState, useEffect } from 'react';
import { Card, SelectChangeEvent, Select, Checkbox, MenuItem, FormControl, InputLabel, OutlinedInput, ListItemText, Box } from '@mui/material';
import CustomDateRangePicker from '@/shared/components/custom-date-range-picker/custom-date-range-picker';

import { _lives } from '@/shared/_mock';
import Iconify from '@/components/iconify';
import { fDate } from '@/utils/format-time';

type Props = {
    startDate: Date,
    endDate: Date,
    setSelectedLives: (selectedLives: string[]) => void,
    selectedLives: string[],
    onChangeStartDate: (startDate: Date) => void,
    onChangeEndDate: (endDate: Date) => void,
}

export default function LiveFilters({ startDate, endDate, onChangeEndDate, onChangeStartDate, setSelectedLives,selectedLives }: Props) {
    
    const [isDateRangeOpen, setIsDateRangeOpen] = useState(false)
    const [selectAll, setSelectAll] = useState(true);
    const liveTitles = _lives.map((live) => live.title);


    useEffect(() => {
        setSelectAll(selectedLives.length === liveTitles.length);
    }, [selectedLives]);

    useEffect(() => {
        setSelectedLives(liveTitles);
    }, []);

    const closeDateRange = () => {
        setIsDateRangeOpen(false);
    }

    const openDateRange = () => {
        setIsDateRangeOpen(true);
    }

    const handleChangeLives = (event: SelectChangeEvent<typeof selectedLives>) => {
        const { target: { value } } = event;
        if (value.includes('all')) {
            if (selectAll) {
                setSelectedLives([]);
                setSelectAll(false);
            } else {
                setSelectedLives(liveTitles);
                setSelectAll(true);
            }
        } else {
            setSelectedLives(typeof value === 'string' ? value.split(',') : value);
        }
    };

    return (

        <Card sx={{ minHeight: 'auto', display: 'flex', alignItems: 'center', px: 2 }}>
            <Card onClick={openDateRange} variant='outlined' sx={{ height: 50, cursor: 'pointer', borderRadius: 1, p: 3, display: 'flex', boxShadow: 'none', justifyContent: 'space-between', alignItems: 'center' }}>
                <Iconify sx={{ mr: 3 }} icon="solar:calendar-date-bold" />
                <ListItemText
                    secondary={`${fDate(startDate)} - ${fDate(endDate)}`}
                    primaryTypographyProps={{
                        typography: 'body2',
                        color: 'text.primary',
                        mb: 0.5,
                    }}
                />
            </Card>
            <CustomDateRangePicker open={isDateRangeOpen} onClose={closeDateRange} startDate={startDate} endDate={endDate} onChangeEndDate={(newValue: Date | null) => onChangeEndDate(newValue!)} onChangeStartDate={(newValue: Date | null) => onChangeStartDate(newValue!)} />
            <FormControl sx={{ m: 1, width: 300 }}>
                <InputLabel>Lives</InputLabel>
                <Select
                    multiple
                    value={selectedLives}
                    onChange={handleChangeLives}
                    input={<OutlinedInput sx={{ height: 50 }} label="Live Titles" />}
                    renderValue={(selected) => selected.join(', ')}
                >
                    <MenuItem value="all">
                        <Checkbox checked={selectAll} />
                        Select All
                    </MenuItem>
                    {liveTitles.map((title) => (
                        <MenuItem key={title} value={title}>
                            <Checkbox checked={selectedLives.includes(title)} />
                            {title}
                        </MenuItem>
                    ))}
                </Select>
            </FormControl>

        </Card>
    );
}
