"use client";

import React, { useMemo } from 'react';
import Chart, { useChart } from '@/components/chart';
import Container from '@mui/material/Container';
import { paths } from '@/routes/paths';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { Card, Grid } from "@mui/material";
import AnalyticsWidgetSummary from "./statistics-widget-summary";
import { useLiveData, useLiveStatistics } from '@/contexts/live-stats';

const SingleLiveStatisticsView: React.FC = () => {
  const { id } = useLiveData();
  const { statistics, totalMessages, totalViewers, totalPurchases } = useLiveStatistics();
  const settings = useSettingsContext();

  const series = useMemo(() => {
    return [{
      name: 'Spectateurs',
      data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.numberOfViewers })),
    }, {
      name: 'Messages',
      data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.numberOfMessages })),
    }, {
      name: 'Ajouts au panier',
      data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.purchases })),
    }];
  }, [statistics]);

  const chartOptions = useChart({
    xaxis: {
      type: 'datetime',
    },
    yaxis: {
      title: {
        text: 'Count',
      },
    },
    tooltip: {
      x: {
        format: 'dd/MM/yy HH:mm',
      },
    },
  });

  return (
    <Container sx={{ gap: 4 }} maxWidth={settings.themeStretch ? false : 'lg'}>
      <CustomBreadcrumbs
        heading={`Statistiques du live : ${id}`}
        links={[
          {
            name: 'dashboard',
            href: paths.dashboard.root,
          },
          {
            name: 'lives',
            href: paths.dashboard.live.all_lives,
          },
          {
            name: 'Statistiques',
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />
      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            key={"messages"}
            title="Messages"
            total={totalMessages}
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_message.png" />}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
           key={"viewers"}
            title="Spectateurs"
            total={totalViewers}
            color="info"
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_users.png" />}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            key={"purchases"}
            title="Ajouts au panier"
            total={totalPurchases}
            color="warning"
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_buy.png" />}
          />
        </Grid>
      </Grid>

      <Card sx={{ p: 4, marginTop: 4 }}>
        <Chart options={chartOptions} series={series} type="line" height={350} />
      </Card>
    </Container>
  );
};

export default SingleLiveStatisticsView;
