import Box from '@mui/material/Box';
import Card from '@mui/material/Card';
import Typography from '@mui/material/Typography';
import { alpha, useTheme } from '@mui/material/styles';

import { fShortenNumber } from '@/utils/format-number';

import { bgGradient } from '@/shared/theme/css';
import { ColorSchema } from '@/shared//theme/palette';
import { number } from 'yup';
import { useMemo } from 'react';

// ----------------------------------------------------------------------

interface Props  {
  title: string;
  total: number | string;
  icon: React.ReactNode;
  color?: ColorSchema;
}

export default function AnalyticsWidgetSummary({
  title,
  total,
  icon,
  color = 'primary',
  ...other
}: Props) {
  const theme = useTheme();
  const totalShorten = useMemo(() =>{ return typeof total == 'string' ? total :  fShortenNumber(total);}, [total]);
  return (
    <Card
      
      sx={{


        ...bgGradient({
          direction: '135deg',
          startColor: alpha(theme.palette[color].light, 0.2),
          endColor: alpha(theme.palette[color].main, 0.2),
        }),
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'space-around',
        maxHeight: 100,
        py: 5,
        borderRadius: 2,
        textAlign: 'center',
        color: `${color}.darker`,
        backgroundColor: 'common.white',
      }}
      {...other}
    >
      <Box sx={{ width: 64, height: 64, mb: 1 }}>{icon}</Box>
      <div>
        <Typography variant="h4">{totalShorten}</Typography>

        <Typography variant="subtitle1" sx={{ opacity: 0.64 }}>
          {title}
        </Typography>
      </div>
    </Card>
  );
}
