import { useState, useCallback } from 'react';
import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import Button from '@mui/material/Button';
import Divider from '@mui/material/Divider';
import Checkbox from '@mui/material/Checkbox';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import Drawer, { DrawerProps } from '@mui/material/Drawer';
import { useRouter } from '@/hooks';
import { paths } from '@/routes/paths';
import { useBoolean } from '@/hooks/use-boolean';
import { fData } from '@/utils/format-number';
import { fDateTime } from '@/utils/format-time';
import Iconify from '@/components/iconify';
import Scrollbar from '@/components/scrollbar';
import FileThumbnail, { fileFormat } from '@/shared/components/file-thumbnail';

import { IMedia } from '@/shared/types/media';

// ----------------------------------------------------------------------

type Props = DrawerProps & {
  item: IMedia;
  onClose: VoidFunction;
  onEdit: VoidFunction;
  onDelete: VoidFunction;
};

export default function MediaManagerFileDetails({
  item,
  open,
  onClose,
  onEdit,
  onDelete,
  ...other
}: Props) {

  const { title, name, size, url, type, modifiedAt, createdAt, author, description } = item;

  const properties = useBoolean(true);

  const renderProperties = (
    <Stack spacing={1.5}>

      {properties.value && (
        <>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Téléversé le :
            </Box>
            {fDateTime(createdAt)}
          </Stack>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Téléversé par :
            </Box>
            {author}
          </Stack>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Modifié le:
            </Box>
            {fDateTime(modifiedAt)}
          </Stack>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Nom :
            </Box>
            {name}
          </Stack>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Taille :
            </Box>
            {fData(size)}
          </Stack>
          <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
            <Box component="span" sx={{ width: 90, color: 'text.secondary', mr: 2 }}>
              Type :
            </Box>
            {fileFormat(type)}
          </Stack>
        </>
      )}
    </Stack>
  );

  return (
    <>
      <Drawer
        open={open}
        onClose={onClose}
        anchor="right"
        slotProps={{
          backdrop: { invisible: true },
        }}
        PaperProps={{
          sx: { width: 320 },
        }}
        {...other}
      >
        <Scrollbar sx={{ height: 1 }}>
          <Stack direction="row" alignItems="center" justifyContent="space-between" sx={{ p: 2.5 }}>
            <Typography variant="h6"> Details </Typography>
          </Stack>

          <Stack
            spacing={2.5}
            justifyContent="center"
            sx={{
              p: 2.5,
              bgcolor: 'background.neutral',
            }}
          >
            <FileThumbnail
              imageView
              file={type === 'folder' ? type : url}
              sx={{ width: 64, height: 64 }}
              imgSx={{ borderRadius: 1 }}
            />

            <Typography variant="subtitle2" sx={{ wordBreak: 'break-all' }}>
              {title}
            </Typography>

            <Divider sx={{ borderStyle: 'dashed' }} />

            {renderProperties}
          </Stack>

        </Scrollbar>

        <Box sx={{ p: 2.5 }}>
          <Button
            fullWidth
            variant="soft"
            color="info"
            size="large"
            sx={{ mb: 1 }}
            startIcon={<Iconify icon="eva:download-outline" />}
          >
            Télécharger
          </Button>
          <Button
            fullWidth
            variant="soft"
            color="primary"
            size="large"
            sx={{ width: '49%', mr: '2%' }}
            onClick={onEdit}
            startIcon={<Iconify icon="eva:edit-outline" />}
          >
            Modifier
          </Button>
          <Button
            fullWidth
            variant="soft"
            color="error"
            size="large"
            sx={{ width: '49%' }}
            startIcon={<Iconify icon="solar:trash-bin-trash-bold" />}
            onClick={onDelete}
          >
            Delete
          </Button>

        </Box>
      </Drawer>
    </>
  );
}
