import {  useCallback } from 'react';
import Box from '@mui/material/Box';
import { CardProps } from '@mui/material/Card';
import IconButton from '@mui/material/IconButton';
import Card from '@mui/material/Card';
import CardMedia from '@mui/material/CardMedia';
import Tooltip from '@mui/material/Tooltip';
import { CardActionArea } from '@mui/material';
import { useBoolean } from '@/hooks/use-boolean';
import Iconify from '@/components/iconify';
import { usePopover } from '@/shared/components/custom-popover';
import { IMedia } from '@/shared/types/media';

// ----------------------------------------------------------------------

interface Props extends CardProps {
  file: IMedia;
  selected?: boolean;
  onSelect?: VoidFunction;
  onDelete: VoidFunction;
}

export default function MultiMediaItem({
  file,
  selected,
  onSelect,
  onDelete,
  sx,
  ...other
}: Props) {

  const confirm = useBoolean();

  const details = useBoolean();

  const popover = usePopover();

  const handleItemClick = useCallback(() => {
    if (onSelect) {
      onSelect();
    }
  }, [onSelect]);

  return (
    <>
      <Tooltip title={file.name}>
        <Box>
          <Card sx={{ maxWidth: '100%', position: 'relative', border: selected ? '6px solid #228B22' : 'none' }}>
            <CardActionArea onClick={handleItemClick}>
              <CardMedia
                component="img"
                height="100%"
                image={file.url}
                style={{
                  objectFit: 'cover',
                  objectPosition: 'center',
                }}
              />
              {selected && (
                <IconButton
                  sx={{
                    position: 'absolute',
                    top: '50%',
                    left: '50%',
                    transform: 'translate(-50%, -50%)',
                    backgroundColor: 'rgba(255, 255, 255, 0.5)',
                  }}
                >
                  <Iconify icon="eva:checkmark-circle-fill" sx={{ color: '#228B22' }} />
                </IconButton>
              )}
            </CardActionArea>
          </Card>
        </Box>
      </Tooltip>
    </>
  );
}
