import { useState } from 'react';
import { useRef } from 'react';
import Box from '@mui/material/Box';
import Button from '@mui/material/Button';
import Typography from '@mui/material/Typography';
import Stack from '@mui/material/Stack';
import Pagination from '@mui/material/Pagination';
import { TableProps } from '@/shared/components/table';
import { IMedia } from '@/shared/types/media';
import MultiMediaItem from './Multi-Media-item';
import AddIcon from '@mui/icons-material/Add';

// ----------------------------------------------------------------------

type Props = {
  table: TableProps;
  dataFiltered: IMedia[];
  onOpenConfirm: VoidFunction;
  onDeleteItem: (id: string) => void;
};

export default function MultiMediaGridView({
  table,
  dataFiltered,
  onDeleteItem,
}: Props) {
  const { selected, onSelectRow: onSelectItem, onSelectAllRows: onSelectAllItems } = table;

  const containerRef = useRef(null);

  const [currentPage, setCurrentPage] = useState<number>(1);
  const itemsPerPage = 20;

  const indexOfLastItem = currentPage * itemsPerPage;
  const indexOfFirstItem = indexOfLastItem - itemsPerPage;
  const currentItems = dataFiltered.slice(indexOfFirstItem, indexOfLastItem);





  return (
      <Box ref={containerRef}>
        <Stack direction="row" alignItems="center" sx={{ mb: 3 }}>
          <Stack flexGrow={1}>
            <Stack direction="row" alignItems="center" spacing={1} flexGrow={1}>
              <Typography variant="h6"> Images </Typography>
            </Stack>
            <Box sx={{ typography: 'body2', color: 'text.disabled', mt: 0.5 }}>{`${dataFiltered.filter((item) => item.type !== 'folder').length} images`}</Box>
          </Stack>
          {!!selected?.length && (
            <>
              <Box sx={{ typography: 'body2', color: 'text.disabled', mt: 0.5 }}>{selected.length} images sélectionnées</Box>
              <Button variant="contained" color="success" size="small" sx={{ ml: '1%' }}><AddIcon />Ajouter</Button>
            </>
          )}
        </Stack>
        <Box
          display="grid"
          gridTemplateColumns={{
            xs: 'repeat(1, 1fr)',
            sm: 'repeat(2, 1fr)',
            md: 'repeat(3, 1fr)',
            lg: 'repeat(4, 1fr)',
          }}
          gap={3}
        >
          {currentItems.map((file) => (
            <MultiMediaItem
              key={file.id}
              file={file}
              selected={selected.includes(file.id)}
              onSelect={() => onSelectItem(file.id)}
              onDelete={() => onDeleteItem(file.id)}
              sx={{ maxWidth: 'auto' }}
            />
          ))}
        </Box>
        <Box mt={3} display="flex" justifyContent="center">
          <Pagination
            count={Math.ceil(dataFiltered.length / itemsPerPage)}
            page={currentPage}
            onChange={(event, value) => setCurrentPage(value)}
            variant="outlined"
            shape="rounded"
          />
        </Box>
      </Box>
  );
}
