import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import Button from '@mui/material/Button';
import Divider from '@mui/material/Divider';
import Dialog, { DialogProps } from '@mui/material/Dialog';
import Typography from '@mui/material/Typography';
import AddIcon from '@mui/icons-material/Add';
import { useBoolean } from '@/hooks/use-boolean';
import { fData } from '@/utils/format-number';
import { fDateTime } from '@/utils/format-time';
import Scrollbar from '@/components/scrollbar';
import FileThumbnail, { fileFormat } from '@/shared/components/file-thumbnail';
import { IMedia } from '@/shared/types/media';

// ----------------------------------------------------------------------

interface Props extends DialogProps {
    item: IMedia;
    mediaName?: string;
    onChangeMediaName?: (event: React.ChangeEvent<HTMLInputElement>) => void;
    open: boolean;
    onClose: VoidFunction;
    onAddMedia?: VoidFunction;
}

export default function SingleMediaConfirmDialog({
    item,
    mediaName,
    onChangeMediaName,
    open,
    onClose,
    onAddMedia,
    ...other
}: Props) {

    const { title, name, size, url, type, modifiedAt, createdAt, author, description } = item;

    const properties = useBoolean(true);

    const renderPropertiesTop = (
        <Stack spacing={1.5}>

            {properties.value && (
                <>

                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize', mt: 2 }}>
                        {title}
                    </Stack>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        {description}
                    </Stack>
                </>
            )}
        </Stack>
    );

    const renderPropertiesBottomRight = (
        <Stack spacing={1.5}>

            {properties.value && (
                <>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Téléversé le :
                        </Box>
                        {fDateTime(createdAt)}
                    </Stack>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Téléversé par :
                        </Box>
                        {author}
                    </Stack>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Modifié le:
                        </Box>
                        {fDateTime(modifiedAt)}
                    </Stack>
                </>
            )}
        </Stack>
    );

    const renderPropertiesBottomLeft = (
        <Stack spacing={1.5}>

            {properties.value && (
                <>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Nom :
                        </Box>
                        {name}
                    </Stack>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Taille :
                        </Box>
                        {fData(size)}
                    </Stack>
                    <Stack direction="row" sx={{ typography: 'caption', textTransform: 'capitalize' }}>
                        <Box component="span" sx={{ width: 82, color: 'text.secondary', mr: 2 }}>
                            Type :
                        </Box>
                        {fileFormat(type)}
                    </Stack>
                </>
            )}
        </Stack>
    );

    return (
        <>
            <Dialog
                open={open}
                onClose={onClose}
                slotProps={{
                    backdrop: { invisible: true },
                }}
                PaperProps={{
                    sx: { width: 820 },
                }}
                {...other}
            >
                <Scrollbar sx={{ height: 1 }}>
                    <Stack>
                        <Stack
                            spacing={2.5}
                            sx={{
                                p: 2.5,
                                bgcolor: 'background.neutral',
                            }}
                        >
                            <Stack direction={'row'}>
                                <Box height={'250px'} width={'250px'}>
                                    <FileThumbnail
                                        imageView
                                        file={type === 'folder' ? type : url}
                                        imgSx={{ borderRadius: 1 }}
                                    />
                                </Box>
                                <Box width={'50%'} sx={{ marginLeft: "20px" }}>
                                    {renderPropertiesTop}
                                </Box>
                            </Stack>

                            <Stack>
                                <Typography variant="subtitle1" sx={{ wordBreak: 'break-all' }}>
                                    {name}
                                </Typography>
                                <Divider sx={{ borderStyle: 'dashed', mb: 1 }} />
                                <Stack direction={'row'}>
                                    <Box width={'60%'}>
                                        {renderPropertiesBottomLeft}
                                    </Box>
                                    <Box width={'60%'}>
                                        {renderPropertiesBottomRight}
                                    </Box>
                                </Stack>

                            </Stack>

                        </Stack>
                    </Stack>


                </Scrollbar>

                <Box sx={{ p: 2.5 }}>
                    <Button
                        fullWidth
                        variant="soft"
                        color="info"
                        size="large"
                        sx={{ mb: 1 }}
                        onClick={onAddMedia}
                    >
                        <AddIcon /> Ajouter
                    </Button>
                </Box>
            </Dialog>
        </>
    );
}
