import { useRef, useState } from 'react';
import Box from '@mui/material/Box';
import { useBoolean } from '@/hooks/use-boolean';
import { TableProps } from '@/shared/components/table';
import { IMedia } from '@/shared/types/media';
import MediaManagerPanel from '../../media-manager-panel';
import SingleMediaItem from './Single-media-item';
import Pagination from '@mui/material/Pagination';

// ----------------------------------------------------------------------

type Props = {
  table: TableProps;
  dataFiltered: IMedia[];
  onOpenConfirm: VoidFunction;
  onAddMedia: (id: string) => void;
};

export default function SingleMediaGrid({
  table,
  dataFiltered,
  onAddMedia,
}: Props) {
  const { selected, onSelectRow: onSelectItem, onSelectAllRows: onSelectAllItems } = table;

  const containerRef = useRef(null);

  const [currentPage, setCurrentPage] = useState<number>(1);
  const itemsPerPage = 20;

  // Logique pour déterminer quels éléments doivent être affichés sur la page actuelle
  const indexOfLastItem = currentPage * itemsPerPage;
  const indexOfFirstItem = indexOfLastItem - itemsPerPage;
  const currentItems = dataFiltered.slice(indexOfFirstItem, indexOfLastItem);

  return (
    <>
      <Box ref={containerRef}>
        <MediaManagerPanel
          title="Images"
          subTitle={`${dataFiltered.filter((item) => item.type !== 'folder').length} images`}
        />

        <Box
          display="grid"
          gridTemplateColumns={{
            xs: 'repeat(1, 1fr)',
            sm: 'repeat(2, 1fr)',
            md: 'repeat(3, 1fr)',
            lg: 'repeat(4, 1fr)',
          }}
          gap={3}
        >
          {currentItems.map((file) => (
            <SingleMediaItem
              key={file.id}
              file={file}
              selected={selected.includes(file.id)}
              onSelect={() => onSelectItem(file.id)}
              onAddMedia={() => onAddMedia(file.id)}
              sx={{ maxWidth: 'auto' }}
            />
          ))}
        </Box>
        <Box mt={3} display="flex" justifyContent="center">
          <Pagination
            count={Math.ceil(dataFiltered.length / itemsPerPage)}
            page={currentPage}
            onChange={(event, value) => setCurrentPage(value)}
            variant="outlined"
            shape="rounded"
          />
        </Box>
      </Box>
    </>
  );
}
