import { useState, useCallback } from 'react';

import Box from '@mui/material/Box';
import Paper from '@mui/material/Paper';
import Stack from '@mui/material/Stack';
import Tooltip from '@mui/material/Tooltip';
import Grid from '@mui/material/Grid';
import Divider from '@mui/material/Divider';
import MenuItem from '@mui/material/MenuItem';
import Checkbox from '@mui/material/Checkbox';
import { CardProps } from '@mui/material/Card';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import AvatarGroup, { avatarGroupClasses } from '@mui/material/AvatarGroup';
import Card from '@mui/material/Card';
import CardContent from '@mui/material/CardContent';
import CardMedia from '@mui/material/CardMedia';
import { CardActionArea } from '@mui/material';
import { useBoolean } from '@/hooks/use-boolean';
import { useCopyToClipboard } from '@/hooks/use-copy-to-clipboard';

import { fData } from '@/utils/format-number';
import { fDateTime } from '@/utils/format-time';

import Iconify from '@/components/iconify';
import { useSnackbar } from '@/components/snackbar';
import TextMaxLine from '@/components/text-max-line';
import FileThumbnail from '@/shared/components/file-thumbnail';
import { ConfirmDialog } from '@/shared/components/custom-dialog';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';

import { IMedia } from '@/shared/types/media';

import FileManagerFileDetails from '../../media-manager-file-details';
import { Download, Edit } from '@mui/icons-material';
import MediaDialogDetails from './New-single-media-confirm-dialog';

// ----------------------------------------------------------------------

interface Props extends CardProps {
  file: IMedia;
  selected?: boolean;
  onSelect?: VoidFunction;
  onAddMedia: VoidFunction;
}

export default function SingleMediaItem({
  file,
  selected,
  onSelect,
  onAddMedia,
  sx,
  ...other
}: Props) {

  const confirm = useBoolean();

  const details = useBoolean();

  const popover = usePopover();


  return (
    <>
      <Tooltip title={file.name}>
        <Box>
          <Card sx={{ maxWidth: 345 }}>
            <CardActionArea>
              <CardMedia
                onClick={details.onTrue}
                component="img"
                height="140"
                image={file.url}
              />
            </CardActionArea>
          </Card>
        </Box>
      </Tooltip>

      <MediaDialogDetails
        item={file}
        open={details.value}
        onClose={details.onFalse}
        onAddMedia={() => {
          details.onFalse();
          onAddMedia();
        }}
      />
    </>
  );
}
