"use client";
import React, { useState } from "react";
import {
  Grid,
  Card,
  CardHeader,
  Stack,
  InputAdornment,
  FormControlLabel,
  Switch,
  Chip,
  Divider,
  Typography,
  TextField,
  Select,
  MenuItem,
  Autocomplete,
  IconButton,
  TableContainer,
  Table,
  TableHead,
  TableRow,
  TableCell,
  Paper,
  Button,
  styled,
  Dialog,
  DialogTitle,
  DialogContent,
  DialogContentText,
  FormControl,
  InputLabel,
} from "@mui/material";
import LoadingButton from "@mui/lab/LoadingButton";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs/custom-breadcrumbs";
import { paths } from "@/routes/paths";
import { LocalizationProvider } from "@mui/x-date-pickers";
import DialogActions from "@mui/material/DialogActions";
import ProductForm from "../productForm";
import { useForm, SubmitHandler, Controller } from "react-hook-form";
import { yupResolver } from "@hookform/resolvers/yup";
import * as Yup from "yup";

interface FormValues {}

export default function ProductNewEditForm() {
  const options = [
    "En attente",
    "En cours",
    "Terminée",
    "Annulée",
    "Remboursée",
    "Supprimée",
  ];
  const note = ["privée", "au client"];
  const clients = ["client 1"];
  function createData(
    Article: string,
    Coût: number,
    Qte: number,
    Total: number
  ) {
    return { Article, Coût, Qte, Total };
  }
  const [open, setOpen] = React.useState(false);

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };
  const validationSchema = Yup.object().shape({
    etat: Yup.string().required("État est requis"),
    client: Yup.string().required("Client est requis"),
  });
  const {
    handleSubmit,
    control,
    formState: { errors },
  } = useForm({ resolver: yupResolver(validationSchema) });
  const onSubmit: SubmitHandler<FormValues> = (data) => {
    console.log(data);
  };
  return (
    <>
      <LocalizationProvider>
        <CustomBreadcrumbs
          heading="Nouvelle commande"
          links={[
            {
              name: "dashboard",
              href: paths.dashboard.root,
            },
            {
              name: "commandes",
              href: paths.dashboard.order.all_orders,
            },
            {
              name: "ajouter une commande",
            },
          ]}
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />
        <form onSubmit={handleSubmit(onSubmit)}>
          <Grid container spacing={3}>
            <Grid item xs={12} md={8}>
              <Card>
                <CardHeader title={`Details - N°`} />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TextField
                    name="creationDateTime"
                    label="Date de création"
                    type="datetime-local"
                    fullWidth
                    InputLabelProps={{
                      shrink: true,
                    }}
                  />
                  <Controller
                    name="etat"
                    control={control}
                    render={({ field }) => (
                      <Autocomplete
                        {...field}
                        id="combo-box-demo"
                        options={options}
                        disableClearable
                        fullWidth
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Etat"
                            error={!!errors.etat}
                            helperText={errors.etat?.message}
                          />
                        )}
                      />
                    )}
                  />
                  <Controller
                    name="client"
                    control={control}
                    render={({ field }) => (
                      <Autocomplete
                        {...field}
                        id="client-autocomplete"
                        options={clients}
                        fullWidth
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Client"
                            error={!!errors.client}
                            helperText={errors.client?.message}
                          />
                        )}
                      />
                    )}
                  />
                  <Grid container spacing={2} alignItems="center">
                    <Grid item xs={6}>
                      <Typography variant="h6" gutterBottom>
                        Facturation
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Nom Complet:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Adresse:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Ville:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        E-mail:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Téléphone:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Moyen de paiement:
                      </Typography>
                    </Grid>
                    <Grid item xs={6}>
                      <Typography variant="h6" gutterBottom>
                        Expédition
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Nom Complet:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Adresse:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Code postal:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Ville:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Téléphone:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Note fournie par le client:
                      </Typography>
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
            </Grid>
            <Grid item xs={12} md={4}>
              <Card sx={{ marginBottom: 2 }}>
                <CardHeader title="Notes de commandes" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TextField
                    name="subDescription"
                    label="Ajouter une note"
                    multiline
                    rows={4}
                    fullWidth
                  />
                  <Grid container spacing={2} alignItems="center">
                    <Grid item xs={8}>
                      <Autocomplete
                        id="combo-box-demo"
                        options={note}
                        fullWidth
                        renderInput={(params) => (
                          <TextField {...params} label="Note" />
                        )}
                      />
                    </Grid>
                    <Grid item xs={4}>
                      <LoadingButton
                        type="submit"
                        variant="contained"
                        fullWidth
                        sx={{ height: 50 }}
                      >
                        Soumettre
                      </LoadingButton>
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
              <Grid container>
                <Grid item xs={12} md={12}>
                  <Card>
                    <CardHeader title="Attribution de la commande" />
                    <Stack spacing={3} sx={{ p: 3 }}>
                      <Grid container spacing={2} alignItems="center">
                        <Grid item xs={6}>
                          <TextField
                            name="weight"
                            label="Poids (g)"
                            type="number"
                            fullWidth
                            InputLabelProps={{
                              shrink: true,
                            }}
                          />
                        </Grid>
                        <Grid item xs={6}>
                          <FormControl fullWidth>
                            <InputLabel id="order-origin-label">
                              Origine
                            </InputLabel>
                            <Select
                              labelId="order-origin-label"
                              id="order-origin"
                              label="Origine"
                              defaultValue=""
                            >
                              <MenuItem value="site">Site</MenuItem>
                              <MenuItem value="live">Live</MenuItem>
                            </Select>
                          </FormControl>
                        </Grid>
                      </Grid>
                      <Grid container spacing={2} alignItems="center">
                        <Grid item xs={4}>
                          <TextField
                            name="width"
                            label="Largeur (cm)"
                            type="number"
                            fullWidth
                            InputLabelProps={{
                              shrink: true,
                            }}
                          />
                        </Grid>
                        <Grid item xs={4}>
                          <TextField
                            name="length"
                            label="Longueur (cm)"
                            type="number"
                            fullWidth
                            InputLabelProps={{
                              shrink: true,
                            }}
                          />
                        </Grid>
                        <Grid item xs={4}>
                          <TextField
                            name="height"
                            label="Hauteur (cm)"
                            type="number"
                            fullWidth
                            InputLabelProps={{
                              shrink: true,
                            }}
                          />
                        </Grid>
                      </Grid>
                    </Stack>
                  </Card>
                </Grid>
              </Grid>
            </Grid>

            <Grid item xs={12} md={8}>
              <Card sx={{ marginTop: -5 }}>
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TableContainer component={Paper}>
                    <Table sx={{ minWidth: 650 }} aria-label="simple table">
                      <TableHead>
                        <TableRow>
                          <TableCell>Article</TableCell>
                          <TableCell align="right">&nbsp;&nbsp;Coût</TableCell>
                          <TableCell align="right">Qte</TableCell>
                          <TableCell align="right">Total</TableCell>
                        </TableRow>
                      </TableHead>
                    </Table>
                  </TableContainer>
                  <Typography variant="subtitle2" align="right">
                    Sous-total des articles: 0,00€
                  </Typography>
                  <Typography variant="subtitle2" align="right">
                    Total de la commande : 0,00€
                  </Typography>
                  <Grid
                    item
                    xs={12}
                    sx={{ display: "flex", justifyContent: "flex-end" }}
                  >
                    <Stack direction="row" spacing={2}>
                      <React.Fragment>
                        <Button variant="contained" onClick={handleClickOpen}>
                          Ajouter des produits
                        </Button>
                        <Dialog
                          open={open}
                          onClose={handleClose}
                          PaperProps={{
                            component: "form",
                            onSubmit: (
                              event: React.FormEvent<HTMLFormElement>
                            ) => {
                              event.preventDefault();
                              const formData = new FormData(
                                event.currentTarget
                              );
                              const formJson = Object.fromEntries(
                                (formData as any).entries()
                              );
                              const email = formJson.email;
                              console.log(email);
                              handleClose();
                            },
                          }}
                        >
                          <DialogTitle>Ajouter des produits</DialogTitle>
                          <DialogContent>
                            <ProductForm />
                          </DialogContent>
                          <DialogActions>
                            <Button onClick={handleClose}>Annuler</Button>
                          </DialogActions>
                        </Dialog>
                      </React.Fragment>

                      <LoadingButton type="submit" variant="contained">
                        Recalculer le total
                      </LoadingButton>
                    </Stack>
                  </Grid>
                </Stack>
              </Card>
            </Grid>

            <Grid
              item
              xs={12}
              md={8}
              sx={{ display: "flex", alignItems: "center" }}
            >
              <Grid container justifyContent="flex-end">
                <LoadingButton type="submit" variant="contained">
                  Enregistrer la commande
                </LoadingButton>
              </Grid>
            </Grid>
          </Grid>
        </form>
      </LocalizationProvider>
    </>
  );
}
