import React, { useState } from "react";
import {
  Card,
  Grid,
  Stack,
  TextField,
  IconButton,
  InputAdornment,
  Checkbox,
  FormControlLabel,
} from "@mui/material";
import Autocomplete from '@mui/material/Autocomplete';
import AddIcon from '@mui/icons-material/Add';
import DeleteIcon from '@mui/icons-material/Delete';
import LoadingButton from "@mui/lab/LoadingButton";

interface Entry {
  product: string;
  quantity: string;
}

export default function ProductForm() {
  const [entries, setEntries] = useState<Entry[]>([{ product: "", quantity: "" }]);
  const [expedition, setExpedition] = useState<string>("");
  const [expeditionPrice, setExpeditionPrice] = useState<string>("");
  const [taxe, setTaxe] = useState<string>("");
  const [frais, setFrais] = useState<string>("");
  const [coupon, setCoupon] = useState<string>("");


  const handleAddEntry = () => {
    setEntries([...entries, { product: "", quantity: "" }]);
  };

  const handleRemoveEntry = (index: number) => {
    const newEntries = [...entries];
    newEntries.splice(index, 1);
    setEntries(newEntries);
  };

  const handleInputChange = (index: number, field: keyof Entry, value: string) => {
    const newEntries = [...entries];
    newEntries[index][field] = value;
    setEntries(newEntries);
  };
  const handleSubmit = (event: React.FormEvent<HTMLFormElement>) => {
    event.preventDefault();
    console.log("Formulaire soumis !");
  };


  return (
    <form onSubmit={handleSubmit}>
      <Card>
        <Stack spacing={3} sx={{ p: 3 }}>
          {entries.map((entry, index) => (
            <Grid container spacing={2} alignItems="center" key={index}>
              <Grid item xs={7} md={7}>
                <Autocomplete
                  value={entry.product}
                  onChange={(event, newValue) =>
                    handleInputChange(index, "product", newValue !== null ? newValue : "")
                  }
                  options={["Produit 1", "Produit 2", "Produit 3"]}
                  fullWidth
                  renderInput={(params) => <TextField {...params} label="Produit" />}
                />
              </Grid>
              <Grid item xs={3} md={3}>
                <TextField
                  value={entry.quantity}
                  onChange={(event) =>
                    handleInputChange(index, "quantity", event.target.value)
                  }
                  fullWidth
                  label="Qte"
                  type="number"
                />
              </Grid>
              <Grid item xs={1} md={1} container justifyContent="flex-end">
                <IconButton onClick={handleAddEntry}>
                  <AddIcon fontSize="small" />
                </IconButton>
              </Grid>
              {index > 0 && (
                <Grid item xs={1} md={1} container justifyContent="flex-end">
                  <IconButton onClick={() => handleRemoveEntry(index)}>
                    <DeleteIcon fontSize="small" />
                  </IconButton>
                </Grid>
              )}
            </Grid>

          ))}
          <Grid container spacing={2} alignItems="center">
            <Grid item xs={7} md={7}>
              <Autocomplete
                value={expedition}
                onChange={(event, newValue) =>
                  setExpedition(newValue !== null ? newValue : "")
                }
                options={["Livraison gratuite", "Colissimo", "Mondial relay"]}
                fullWidth
                renderInput={(params) => <TextField {...params} label="Expédition" />}
              />
            </Grid>
            <Grid item xs={3} md={3}>
              <TextField
                value={expeditionPrice}
                onChange={(event) => setExpeditionPrice(event.target.value)}
                fullWidth
                label="Prix"
                type="number"
                InputProps={{
                  endAdornment: <InputAdornment position="end">€</InputAdornment>,
                }}
              />
            </Grid>
          </Grid>
          <Grid container spacing={3} alignItems="center">
           
            <Grid item xs={3} md={3}>
              <TextField
                value={frais}
                onChange={(event) => setFrais(event.target.value)}
                fullWidth
                label="Frais"
              />
            </Grid>
            <Grid item xs={4} md={4}>
              <TextField
                value={coupon}
                onChange={(event) => setCoupon(event.target.value)}
                fullWidth
                label="Appliquer un coupon"
              />
            </Grid>
            <Grid item xs={3} md={3}>
              <FormControlLabel
                value="end"
                control={<Checkbox />}
                label="TVA 20%"
                labelPlacement="end"
              />
            </Grid>
          </Grid>
        </Stack>
        <LoadingButton type="submit" variant="contained" fullWidth>
        Soumettre
      </LoadingButton>
      </Card>
      
    </form>
  );
}