'use client';

import { useState, useCallback } from 'react';

import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableHead from '@mui/material/TableHead';
import TableContainer from '@mui/material/TableContainer';
import { paths } from '@/routes/paths';
import { useRouter } from '@/hooks';
import Scrollbar from '@/shared/components/scrollbar';
import { useSettingsContext } from '@/shared/components/settings';
import { useTable, emptyRows, TableNoData, TableEmptyRows, } from '@/shared/components/table';
import { Reorder } from 'framer-motion';
import { IPaymentMethod } from '@/shared/types/payment';
import { useGetPaymentMethods } from '@/shared/api/payment';
import AccountTableRow from './account-table-row';
import { Card } from '@mui/material';


const mockBankAccounts = [
    {
        name: 'Compte Exemple A',
        number: '000123456A',
        bank: 'Banque de A',
        code: '123456',
        IBAN: 'FR14 2004 1010 0505 0001 3M02 606',
        bic_swift: 'BICA123'
    },
    {
        name: 'Compte Exemple B',
        number: '000654321B',
        bank: 'Banque de B',
        code: '654321',
        IBAN: 'FR76 3000 6000 0112 3456 7890 189',
        bic_swift: 'BICB456'
    },
];



export default function AccounTabme() {
    const table = useTable({ defaultOrderBy: 'title' });
    const [tableData, setTableData] = useState(mockBankAccounts);




    const denseHeight = table.dense ? 56 : 56 + 20;


    const notFound = (!tableData.length) || !tableData.length;




    const handleReorder = (newOrder: number[]) => {
        const reorderedData = newOrder.map(index => tableData[index]);
        setTableData(reorderedData);
    };

    return (
        <Card sx={{ padding: 0 }}>
            <TableContainer sx={{ position: 'relative', overflow: 'unset', maxWidth: '1420px' }}>
                <TableHead  >
                    <TableCell sx={{ minwidth: 400 }} align='left'>Nom du compte</TableCell>
                    <TableCell sx={{ minwidth: 400 }} align='left'>Nom du compte</TableCell>
                    <TableCell sx={{ minwidth: 400 }} align='left'>Nom de la banque	</TableCell>
                    <TableCell sx={{ minwidth: 400 }} align='left'>Code guichet</TableCell>
                    <TableCell sx={{ minwidth: 400 }} align='left'>IBAN</TableCell>
                    <TableCell sx={{ minwidth: 400 }} align='left'>BIC/Swift</TableCell>
                </TableHead>

                <Scrollbar>
                    <Table sx={{ position: 'relative', overflow: 'unset', minWidth: 1000 }} >
                        <TableBody>
                            <Reorder.Group
                                axis="y" // Vertical reordering
                                values={tableData.map((_, index) => index)}
                                onReorder={handleReorder}
                            >
                                {tableData
                                    .slice(
                                        table.page * table.rowsPerPage,
                                        table.page * table.rowsPerPage + table.rowsPerPage
                                    )
                                    .map((row, index) => (
                                        <Reorder.Item key={row.number} value={index}> {/* Use index as value for Reorder.Item */}
                                            <AccountTableRow
                                                key={row.number}
                                                row={row}
                                            />
                                        </Reorder.Item>
                                    ))}
                            </Reorder.Group>
                            <TableEmptyRows
                                height={denseHeight}
                                emptyRows={emptyRows(table.page, table.rowsPerPage, tableData.length)}
                            />

                            <TableNoData notFound={notFound} />
                        </TableBody>
                    </Table>
                </Scrollbar>
            </TableContainer>
        </Card>
    );
}
