"use client"

import React from 'react';
import {
    Card,
    CardHeader,
    Chip,
    Grid,
    MenuItem,
    Select,
    Stack,
    Typography
} from '@mui/material';
import { useResponsive } from '@/hooks';
import * as Yup from 'yup';
import { yupResolver } from '@hookform/resolvers/yup';
import { useForm } from 'react-hook-form';
import FormProvider, { RHFSwitch, RHFTextField } from '@/components/hook-form';
import { _tags } from '@/shared/_mock';
import LoadingButton from '@mui/lab/LoadingButton';
import AccounTabme from './account-table';
import { updatePaymentMethodConf, useGetPaymentMethodConf } from '@/shared/api/payment';





export default function BankTransferConfView() {
    const lgUp = useResponsive('up', 'lg');
    const creditCardConfSchema = Yup.object().shape({
        enabled: Yup.boolean().required(),
        title: Yup.string().required(),
        description: Yup.string().required(),
        instructions: Yup.string().required(),
        bankAccounts: Yup.array()

    });

    const {paymentMethodConfData:defaultValues}=useGetPaymentMethodConf('bank_transfer')

    const methods = useForm({
        resolver: yupResolver(creditCardConfSchema),
        defaultValues
    })

    const { handleSubmit, formState: { isSubmitting } } = methods;
    const onSubmit = handleSubmit(async (data) => {
        console.log(data)
        try {
            await updatePaymentMethodConf('bank_transfer', data);
        } catch (error) {
            console.log(error);
        }
    })

    const renderForm = (
        <>
            {lgUp && (
                <Grid md={4} paddingY={2}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        le mode virement bancaire
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Acceptez les paiements en personne avec BACS. Aussi connu sous le nom de virement/bancaire.
                    </Typography>
                </Grid>
            )}
            <Grid xs={12} lg={8} paddingY={2}>
                <Card >
                    {!lgUp && <CardHeader title="le mode live" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Grid container spacing={3}>
                            <Grid item xs={12} sm={6}>
                                <Card sx={{ p: 2, minHeight: { lg: 170 } }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Activer/Désactiver
                                    </Typography>
                                    <Typography variant="body2" gutterBottom sx={{ color: 'text.secondary' }}>
                                        Activer le mode de paiement par carte bancaire
                                    </Typography>
                                    <RHFSwitch label={undefined} name="enabled" />
                                </Card>
                            </Grid>
                            <Grid item xs={12} sm={6}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Titre
                                    </Typography>
                                    <Typography variant="body2" gutterBottom sx={{ color: 'text.secondary' }}>
                                        Contrôler le titre que l'utilisateur voit lors du paiement
                                    </Typography>
                                    <RHFTextField label={undefined} name="title" placeholder='titre' />
                                </Card>
                            </Grid>
                            <Grid item xs={12}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Description
                                    </Typography>
                                    <Typography variant="body2" gutterBottom sx={{ color: 'text.secondary' }}>
                                        méthode de paiement que le client verra lors du passage de la commande
                                    </Typography>
                                    <RHFTextField label={undefined} name="description" placeholder='description' />
                                </Card>
                            </Grid>
                            <Grid item xs={12}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Instructions
                                    </Typography>
                                    <Typography variant="body2" gutterBottom>
                                        les instructions qui seront ajoutées à la page de remerciement et aux emails
                                    </Typography>
                                    <RHFTextField label={undefined} name="instructions" placeholder='instructions' />
                                </Card>
                            </Grid>
                            <Grid item xs={12}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Détails du compte
                                    </Typography>
                                    {/* <Typography variant="body2" gutterBottom>
                                        les instructions qui seront ajoutées à la page de remerciement et aux emails
                                    </Typography> */}
                                    <AccounTabme />
                                </Card>
                            </Grid>


                        </Grid>
                    </Stack>
                </Card>
            </Grid>
        </>
    );

    const renderActions = (
        <>
            {lgUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 2 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );
    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderForm}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
