"use client"

import React from 'react';
import {
  Card,
  CardHeader,
  Chip,
  Grid,
  MenuItem,
  Select,
  Stack,
  Typography
} from '@mui/material';
import { useResponsive } from '@/hooks';
import * as Yup from 'yup';
import { yupResolver } from '@hookform/resolvers/yup';
import { useForm } from 'react-hook-form';
import FormProvider, { RHFAutocomplete, RHFSwitch, RHFTextField } from '@/components/hook-form';
import { _tags } from '@/shared/_mock';
import LoadingButton from '@mui/lab/LoadingButton';
import { useGetCreditCardConfig } from '@/shared/api/payment';
import { ICreditCardConfig } from '@/shared/types/payment';




export default function AdvancedCardProcessingForm() {
  const mdUp = useResponsive('up', 'md');
  const creditCardConfSchema = Yup.object<ICreditCardConfig>().shape({
    enabled: Yup.boolean().required(),
    title: Yup.string().required(),
    logos: Yup.array().of(Yup.string()).required(),
    disabledCreditCards: Yup.array().of(Yup.string()).required(),
    vaulting: Yup.boolean().required(),
    contingencyFor3DSecure: Yup.string().required()
  });

  const { config: defaultValues } = useGetCreditCardConfig();

  const methods = useForm({
    resolver: yupResolver(creditCardConfSchema),
    defaultValues
  })

  const { handleSubmit, formState: { isSubmitting } } = methods;
  const onSubmit = handleSubmit(async (data) => {
    console.log(data)
    try{
      console.log(data)
    }catch(error){
      console.log(error);
    }
  })

  const renderForm = (
    <>
      {mdUp && (
        <Grid md={4} paddingY={2}>
          <Typography variant="h6" sx={{ mb: 0.5 }}>
            le mode carte bancaire
          </Typography>
          <Typography variant="body2" sx={{ color: 'text.secondary' }}>
            Acceptez les cartes de débit et de crédit, ainsi que les méthodes de paiement locales avec la dernière solution de PayPal
          </Typography>
        </Grid>
      )}
      <Grid xs={12} md={8} paddingY={2}>
        <Card >
          {!mdUp && <CardHeader title="le mode live" />}

          <Stack spacing={3} sx={{ p: 3 }}>
            <Grid container spacing={3}>
              <Grid item xs={12} sm={6}>
                <Card sx={{ p: 2, minHeight: { sm: 170 } }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    Activer/Désactiver
                  </Typography>
                  <Typography variant="body2" gutterBottom>
                    Activer le mode de paiement par carte bancaire
                  </Typography>
                  <RHFSwitch label={undefined} name="enabled" />
                </Card>
              </Grid>
              <Grid item xs={12} sm={6}>
                <Card sx={{ p: 2, }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    Titre
                  </Typography>
                  <Typography variant="body2" gutterBottom>
                    Contrôler le titre que l'utilisateur voit lors du paiement
                  </Typography>
                  <RHFTextField label={undefined} name="titre" placeholder='titre' />
                </Card>
              </Grid>
              <Grid item xs={12}>
                <Card sx={{ p: 2, }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    Désactiver des cartes de crédit spécifiques
                  </Typography>
                  <RHFAutocomplete
                    name="disabledCreditCards"
                    label="cartes de crédit"
                    placeholder="+ carte de crédit"
                    multiple
                    freeSolo
                    disableCloseOnSelect
                    options={_tags.map((option) => option)}
                    getOptionLabel={(option) => option}
                    renderOption={(props, option) => (
                      <li {...props} key={option}>
                        {option}
                      </li>
                    )}
                    renderTags={(selected, getTagProps) =>
                      selected.map((option, index) => (
                        <Chip
                          {...getTagProps({ index })}
                          key={option}
                          label={option}
                          size="small"
                          color="info"
                          variant="soft"
                        />
                      ))
                    }
                  />
                </Card>
              </Grid>
              <Grid item xs={12}>
                <Card sx={{ p: 2, }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    Afficher le logo des cartes de crédit suivantes
                  </Typography>
                  <RHFAutocomplete
                    name="logos"
                    label="logos"
                    placeholder="+logo"
                    multiple
                    freeSolo
                    disableCloseOnSelect
                    options={_tags.map((option) => option)}
                    getOptionLabel={(option) => option}
                    renderOption={(props, option) => (
                      <li {...props} key={option}>
                        {option}
                      </li>
                    )}
                    renderTags={(selected, getTagProps) =>
                      selected.map((option, index) => (
                        <Chip
                          {...getTagProps({ index })}
                          key={option}
                          label={option}
                          size="small"
                          color="info"
                          variant="soft"
                        />
                      ))
                    }
                  />
                </Card>
              </Grid>
              <Grid item xs={12} sm={6}>
                <Card sx={{ p: 2, minHeight: { sm: 170 } }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    Vaulting
                  </Typography>
                  <Typography variant="body2" gutterBottom>
                    Stocker en toute sécurité les cartes de crédit de vos clients pour une expérience fluide
                  </Typography>
                  <RHFSwitch label={undefined} name="vaulting" />
                </Card>
              </Grid>
              <Grid item xs={12} sm={6}>
                <Card sx={{ p: 2, }} variant='outlined'>
                  <Typography variant="subtitle1" gutterBottom>
                    3D secure
                  </Typography>
                  <Typography variant="body2" gutterBottom>
                    Le 3D Secure offre une vérification renforcée pour plus de sécurité
                  </Typography>
                  <Select
                    name="contingencyFor3DSecure"
                    label={undefined}
                    fullWidth
                  >
                    <MenuItem value="required">3D Secure when required</MenuItem>
                    <MenuItem value="always">Always use 3D Secure</MenuItem>
                    <MenuItem value="never">Never use 3D Secure</MenuItem>
                  </Select>
                </Card>
              </Grid>
            </Grid>
          </Stack>
        </Card>
      </Grid>
    </>
  );

  const renderActions = (
    <>
      {mdUp && <Grid md={4} />}
      <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 2 }}>
        <LoadingButton
          type="submit"
          variant="contained"
          size="large"
          loading={isSubmitting}
          sx={{ ml: 2 }}
        >Enregistrer</LoadingButton>

      </Grid>
    </>
  );
  return (
    <FormProvider methods={methods} onSubmit={onSubmit}>
      <Grid container spacing={3}>
        {renderForm}
        {renderActions}
      </Grid>
    </FormProvider>
  );
}
