import Divider from '@mui/material/Divider';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import Switch from '@mui/material/Switch';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import { useBoolean } from '@/hooks';
import Iconify from '@/shared/components/iconify';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { ShippingMethod } from '@/contexts/types/Shipping';
import React, { useState } from 'react';
import { IPaymentMethod } from '@/shared/types/payment';


type Props = {
    row: IPaymentMethod;
    onViewRow: (name: string) => void;
};

export default function PaymentMethodTableRow({
    row,
    onViewRow,
}: Props) {
    const { id, name, active, description } = row;
    const popover = usePopover();
    const [isChecked, setIsChecked] = useState(active);

    const handleToggle = () => {
        setIsChecked(!isChecked);
        row.active = !row.active;
    };


    return (
        <>
            <TableRow hover sx={{ width: '100%' }}>
                <TableCell align='left' sx={{ width: '300px' }}>
                    <Typography variant="body2">
                        {name}
                    </Typography>
                </TableCell>

                <TableCell sx={{ width: '300px' }}>
                    <Switch
                        checked={isChecked}
                        onChange={handleToggle}
                        inputProps={{ 'aria-label': 'controlled' }}
                    />
                </TableCell>

                <TableCell sx={{ width: '520px' }}>{description}</TableCell>

                <TableCell align='center' sx={{ width: "300px" }}>
                    <IconButton color={popover.open ? 'inherit' : 'default'} onClick={() => {
                        onViewRow(id);
                    }}>
                        <Iconify icon="mdi:settings" />
                    </IconButton>
                </TableCell>

            </TableRow>
        </>
    );
}
