"use client";
import { useState } from "react";
import TextField from "@mui/material/TextField";
import Autocomplete from "@mui/material/Autocomplete";
import Button from "@mui/material/Button";
import DeleteIcon from "@mui/icons-material/Delete";
import Stack from "@mui/material/Stack";
import Typography from "@mui/material/Typography";
import Avatar from "@mui/material/Avatar";
import Card from "@mui/material/Card";

export default function ProductCategoryForm() {
  const [categoryImage, setCategoryImage] = useState<string | null>(null);
  const handleImageChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const file = event.target.files?.[0];
    if (file) {
      const reader = new FileReader();
      reader.onloadend = () => {
        setCategoryImage(reader.result as string);
      };
      reader.readAsDataURL(file);
    }
  };
  const typeAffichage = [
    "Valeur par défaut",
    "Produits",
    "Sous-Catégorie",
    "les deux (Produits et Sous-Catégorie)",
  ];

  const parentCategories = [
    { name: "Aucun" },
    { name: "Robes" },
    { name: "Vêtements" },
    { name: "Jeans" },
    { name: "Sacs, Accessoires et Bijoux" },
  ];

  return (
    <Card variant="outlined">
      <Stack spacing={1.5} sx={{ p: 3 }}>
        <Typography variant="subtitle2">Ajouter une Catégorie</Typography>

        <TextField name="nom" label="Nom" InputLabelProps={{ shrink: true }} />

        <TextField
          label="Slug"
          name="slug"
          InputLabelProps={{ shrink: true }}
        />
        <Autocomplete
          id="Pcategory"
          autoHighlight
          options={parentCategories.map((category) => category.name)}
          renderInput={(params) => (
            <TextField
              {...params}
              label="Catégorie parente"
              InputLabelProps={{ shrink: true }}
            />
          )}
        />
        <TextField
          name="Description"
          label="Description  "
          multiline
          rows={4}
          InputLabelProps={{ shrink: true }}
        />
        <Autocomplete
          id="type"
          autoHighlight
          options={typeAffichage.map((type) => type)}
          renderInput={(params) => (
            <TextField
              {...params}
              label="Type d'affichage"
              InputLabelProps={{ shrink: true }}
            />
          )}
        />
        <Stack spacing={1.5}>
          <Typography variant="subtitle2">Images</Typography>
          <input
            accept="image/*"
            style={{ display: "none" }}
            id="category-image-input"
            type="file"
            onChange={handleImageChange}
          />
          <label htmlFor="category-image-input">
            <Button variant="outlined" component="span">
              Choisir une image
            </Button>
          </label>
          {categoryImage && (
            <Stack direction="row" alignItems="center" spacing={1}>
              <Avatar
                alt="Catégorie Image"
                src={categoryImage}
                sx={{ width: 56, height: 56 }}
              />

              <Button
                variant="outlined"
                size="small"
                startIcon={<DeleteIcon />}
                onClick={() => setCategoryImage(null)}
              >
                Supprimer l'image
              </Button>
            </Stack>
          )}
        </Stack>
        <Button type="submit" variant="contained" color="primary">
          Ajouter
        </Button>
      </Stack>
    </Card>
  );
}
