"use client";

import { useState, useCallback } from "react";
import Container from "@mui/material/Container";
import Stack from "@mui/material/Stack";
import Grid from "@mui/material/Grid";
import Button from "@mui/material/Button";
import Iconify from "@/shared/components/iconify";
import { paths } from "@/routes/paths";
import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import Card from "@mui/material/Card";
import { useBoolean } from "@/hooks/use-boolean";
import ConfirmDialog from "@/shared/components/confirm-dialog";
import ProductCategoryForm from "./category-edit-form";
import { useRouter } from "@/hooks";

import {
  DataGrid,
  GridColDef,
  GridActionsCellItem,
  GridToolbarQuickFilter,
  GridToolbarExport,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarFilterButton,
} from "@mui/x-data-grid";
import { _categories } from "@/shared/_mock/_categories";
import { Avatar } from "@mui/material";

export default function ProductCategory() {
  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );
  const router = useRouter();
  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.product.editCategory(id));
    },
    [router]
  );
  const confirmRows = useBoolean();

  const handleDeleteRows = () => {};

  const columns: GridColDef[] = [
    {
      field: "image",
      headerName: "Image",
      flex: 1,
      renderCell: (params) => (
        <Avatar
          src={params.row.Preview}
          variant="rounded"
          sx={{ width: 64, height: 64, mr: 2 }}
        />
      ),
    },
    {
      field: "name",
      headerName: "Nom",
      flex: 1,
      editable: true,
    },
    {
      field: "slug",
      headerName: "Slug",
      flex: 1,
      editable: true,
    },
    {
      field: "description",
      headerName: "Description",
      flex: 1,
      editable: true,
    },
    {
      field: "total",
      headerName: "Total",
      flex: 1,
      editable: true,
    },
    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:pen-bold" />}
          label="Modification Rapide"
          //onClick={() => handleEditRow(params.row.id)}
        />,
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:pen-bold" />}
          label="modifier"
          onClick={() => handleEditRow(params.row.id)}
        />,

        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Supprimer"
          onClick={() => {
            //handleDeleteRow(params.row.id);
          }}
          sx={{ color: "error.main" }}
        />,
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Utiliser par défaut"
        />,
      ],
    },
  ];

  const rows = _categories.map((category) => ({
    id: category.id,
    Preview: category.image,
    name: category.name,
    slug: category.slug,

    total: category.total,
  }));

  return (
    <Container
      maxWidth="lg"
      sx={{
        flexGrow: 1,
        display: "flex",
        flexDirection: "column",
      }}
    >
      <CustomBreadcrumbs
        heading="Catégories"
        links={[
          { name: "Dashboard", href: paths.dashboard.root },
          {
            name: "Product",
            href: paths.dashboard.product.root,
          },
          { name: "Catégorie" },
        ]}
        sx={{
          mb: {
            xs: 3,
            md: 5,
          },
        }}
      />

      <Grid container spacing={3}>
        <Grid item xs={4}>
          <ProductCategoryForm />
        </Grid>

        <Grid item xs={8}>
          <Card variant="outlined">
            <DataGrid
              checkboxSelection
              autoHeight
              getRowHeight={() => "auto"}
              rows={rows}
              columns={columns}
              disableColumnSelector
              disableDensitySelector
              pageSizeOptions={[5, 10, 25]}
              initialState={{
                pagination: {
                  paginationModel: { pageSize: 10 },
                },
              }}
              onRowSelectionModelChange={(newSelectionModel) => {
                setSelectedRowIds(newSelectionModel);
              }}
              slots={{
                toolbar: () => (
                  <>
                    <GridToolbarContainer>
                      <GridToolbarFilterButton />
                      <GridToolbarExport />
                      <GridToolbarQuickFilter />
                      <Stack
                        spacing={1}
                        flexGrow={1}
                        direction="row"
                        alignItems="center"
                        justifyContent="flex-end"
                      >
                        {!!selectedRowIds.length && (
                          <Stack>
                            <Button
                              size="small"
                              color="error"
                              startIcon={
                                <Iconify icon="solar:trash-bin-trash-bold" />
                              }
                              onClick={confirmRows.onTrue}
                            >
                              Delete ({selectedRowIds.length})
                            </Button>
                            <Button
                              size="small"
                              variant="outlined"
                              color="primary"
                              startIcon={
                                <Iconify icon="heroicons-outline:pencil-alt" />
                              }
                              //onClick={() => handleModifyRows(selectedRowIds)}
                            >
                              Modifier ({selectedRowIds.length})
                            </Button>
                          </Stack>
                        )}
                      </Stack>
                    </GridToolbarContainer>
                  </>
                ),
              }}
              slotProps={{
                toolbar: {
                  showQuickFilter: true,
                },
              }}
            />
          </Card>
          <ConfirmDialog
            open={confirmRows.value}
            onClose={confirmRows.onFalse}
            title="Supprimer"
            content={
              <>
                Êtes-vous sûr de vouloir supprimer{" "}
                <strong> {selectedRowIds.length} </strong> items?
              </>
            }
            action={
              <Button
                variant="contained"
                color="error"
                onClick={() => {
                  handleDeleteRows();
                  confirmRows.onFalse();
                }}
              >
                Supprimer
              </Button>
            }
          />
        </Grid>
      </Grid>
    </Container>
  );
}
