"use client";

import { useState } from "react";
import Container from "@mui/material/Container";

import Stack from "@mui/material/Stack";

import Grid from "@mui/material/Grid";
import IconButton from "@mui/material/IconButton";
import Button from "@mui/material/Button";
import Iconify from "@/shared/components/iconify";
import { paths } from "@/routes/paths";
import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import Card from "@mui/material/Card";
import Tooltip from "@mui/material/Tooltip";
import { useBoolean } from "@/hooks/use-boolean";
import ConfirmDialog from "@/shared/components/confirm-dialog";
import ProductAttributForm from "./attribut-edit-form";
import { useRouter } from "@/hooks";
import { useCallback } from "react";
import SettingsIcon from "@mui/icons-material/Settings";

import {
  DataGrid,
  GridColDef,
  GridActionsCellItem,
  GridToolbarQuickFilter,
  GridToolbarExport,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarFilterButton,
} from "@mui/x-data-grid";

export default function ProductAttribut() {
  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );

  const router = useRouter();
  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.product.editTag(id));
    },
    [router]
  );
  const confirmRows = useBoolean();
  const InitialAttribut = [
    {
      id: 1,
      name: "Couleur",
      identifiant: "couleur",
      type: "Color",
      trie: "Tri personnalisé",
      terme: "bleu,noir,rouge ",
    },
    {
      id: 2,
      name: "image",
      identifiant: "image",
      type: "Image",
      trie: "Tri personnalisé",
      terme: " ",
    },
    {
      id: 3,
      name: "matière",
      identifiant: "matière",
      type: "Choix",
      trie: "Tri personnalisé",
      terme: "soie",
    },

    {
      id: 4,
      name: "Taille",
      identifiant: "Taille",
      type: "Label",
      trie: "Tri personnalisé",
      terme: "L, M, XL, S",
    },
  ];
  interface Attribut {
    id: number;
    name: string;
    identifiant: string;
    type: string;
    trie: string;
    terme: string;
  }

  const handleDeleteRows = () => {};
  const handleConfigureTerms = (type: string) => {
    switch (type) {
      case "Choix":
        router.push(paths.dashboard.product.termeChoix);
        break;
      case "Image":
        router.push(paths.dashboard.product.termeImage);
        break;
      case "Color":
        router.push(paths.dashboard.product.termeColor);
        break;
      case "Label":
        router.push(paths.dashboard.product.termeLabel);

      default:
        break;
    }
  };

  const columns: GridColDef[] = [
    {
      field: "name",
      headerName: "Nom",
      flex: 1,
      editable: true,
    },
    {
      field: "identifiant",
      headerName: "Identifiant",
      flex: 1,
      editable: true,
    },
    {
      field: "type",
      headerName: "Type",
      flex: 1,
      editable: true,
    },
    {
      field: "trie",
      headerName: "Trié par",
      flex: 1,
      editable: true,
      width: 280,
    },
    {
      field: "terme",
      headerName: "Termes",
      flex: 1,
      width: 60,
      align: "center",
      editable: true,
      renderCell: (params) => {
        return (
          <Tooltip title="Configurer les termes">
            <IconButton onClick={() => handleConfigureTerms(params.row.type)}>
              <SettingsIcon />
            </IconButton>
          </Tooltip>
        );
      },
    },
    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:pen-bold" />}
          label="modifier"
          onClick={() => handleEditRow(params.row.id)}
        />,

        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Supprimer"
          onClick={() => {
            //handleDeleteRow(params.row.id);
          }}
          sx={{ color: "error.main" }}
        />,
      ],
    },
  ];

  const rows = InitialAttribut.map((attribut) => ({
    id: attribut.id,

    name: attribut.name,
    identifiant: attribut.identifiant,
    type: attribut.type,
    trie: attribut.trie,
    terme: attribut.terme,
  }));

  return (
    <Container
      maxWidth="lg"
      sx={{
        flexGrow: 1,
        display: "flex",
        flexDirection: "column",
      }}
    >
      <CustomBreadcrumbs
        heading="Attributs"
        links={[
          { name: "Dashboard", href: paths.dashboard.root },
          {
            name: "Product",
            href: paths.dashboard.product.root,
          },
          { name: "Attributs" },
        ]}
        sx={{
          mb: {
            xs: 3,
            md: 5,
          },
        }}
      />

      <Grid container spacing={3}>
        <Grid item xs={4}>
          <ProductAttributForm />
        </Grid>

        <Grid item xs={8}>
          <Card variant="outlined">
            <DataGrid
              checkboxSelection
              autoHeight
              getRowHeight={() => "auto"}
              rows={rows}
              columns={columns}
              disableColumnSelector
              disableDensitySelector
              disableRowSelectionOnClick
              disableColumnFilter
              onRowSelectionModelChange={(newSelectionModel) => {
                setSelectedRowIds(newSelectionModel);
              }}
              slots={{
                toolbar: () => (
                  <>
                    <GridToolbarContainer>
                      <GridToolbarFilterButton />
                      <GridToolbarExport />
                      <GridToolbarQuickFilter />
                      <Stack
                        spacing={1}
                        flexGrow={1}
                        direction="row"
                        alignItems="center"
                        justifyContent="flex-end"
                      >
                        {!!selectedRowIds.length && (
                          <Stack>
                            <Button
                              size="small"
                              color="error"
                              startIcon={
                                <Iconify icon="solar:trash-bin-trash-bold" />
                              }
                              onClick={confirmRows.onTrue}
                            >
                              Supprimer ({selectedRowIds.length})
                            </Button>
                          </Stack>
                        )}
                      </Stack>
                    </GridToolbarContainer>
                  </>
                ),
              }}
              slotProps={{
                toolbar: {
                  showQuickFilter: true,
                },
              }}
            />
          </Card>
          <ConfirmDialog
            open={confirmRows.value}
            onClose={confirmRows.onFalse}
            title="Supprimer"
            content={
              <>
                Êtes-vous sûr de vouloir supprimer{" "}
                <strong> {selectedRowIds.length} </strong> items?
              </>
            }
            action={
              <Button
                variant="contained"
                color="error"
                onClick={() => {
                  handleDeleteRows();
                  confirmRows.onFalse();
                }}
              >
                Supprimer
              </Button>
            }
          />
        </Grid>
      </Grid>
    </Container>
  );
}
