"use client";

import { useState } from "react";
import Container from "@mui/material/Container";

import Stack from "@mui/material/Stack";

import Grid from "@mui/material/Grid";

import Button from "@mui/material/Button";
import Iconify from "@/shared/components/iconify";
import { paths } from "@/routes/paths";
import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import Card from "@mui/material/Card";

import { useBoolean } from "@/hooks/use-boolean";
import ConfirmDialog from "@/shared/components/confirm-dialog";
import AttributTermeForm from "./Choixterme-edit-form";
import { useRouter } from "@/hooks";
import { useCallback } from "react";
import {
  DataGrid,
  GridColDef,
  GridActionsCellItem,
  GridToolbarQuickFilter,
  GridToolbarExport,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarFilterButton,
} from "@mui/x-data-grid";

export default function ChoixTerme() {
  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );
  const router = useRouter();
  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.product.editTag(id));
    },
    [router]
  );
  const confirmRows = useBoolean();

  const handleDeleteRows = () => {};

  const columns: GridColDef[] = [
    {
      field: "name",
      headerName: "Nom",
      flex: 1,
      editable: true,
    },
    {
      field: "slug",
      headerName: "Slug",
      flex: 1,
      editable: true,
    },
    {
      field: "description",
      headerName: "Description",
      flex: 1,
      editable: true,
    },
    {
      field: "total",
      headerName: "Total",
      flex: 1,
      editable: true,
    },
    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:pen-bold" />}
          label="modifier"
          onClick={() => handleEditRow(params.row.id)}
        />,

        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          label="Supprimer"
          onClick={() => {
            //handleDeleteRow(params.row.id);
          }}
          sx={{ color: "error.main" }}
        />,
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="bi:eye" />}
          label="voir"
        />,
      ],
    },
  ];

  const rows: any [] = [];
  return (
    <Container
      maxWidth="lg"
      sx={{
        flexGrow: 1,
        display: "flex",
        flexDirection: "column",
      }}
    >
      <CustomBreadcrumbs
        heading="Attribut"
        links={[
          { name: "Dashboard", href: paths.dashboard.root },
          {
            name: "Product",
            href: paths.dashboard.product.root,
          },
          { name: "Attribut" },
        ]}
        sx={{
          mb: {
            xs: 3,
            md: 5,
          },
        }}
      />

      <Grid container spacing={3}>
        <Grid item xs={4}>
          <AttributTermeForm />
        </Grid>

        <Grid item xs={8}>
          <Card variant="outlined">
            <DataGrid
              checkboxSelection
              autoHeight
              getRowHeight={() => "auto"}
              rows={rows}
              columns={columns}
              disableColumnSelector
              disableDensitySelector
              onRowSelectionModelChange={(newSelectionModel) => {
                setSelectedRowIds(newSelectionModel);
              }}
              slots={{
                toolbar: () => (
                  <GridToolbarContainer>
                    <GridToolbarFilterButton />
                    <GridToolbarExport />
                    <GridToolbarQuickFilter />
                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >
                      {!!selectedRowIds.length && (
                        <Stack>
                          <Button
                            size="small"
                            color="error"
                            startIcon={
                              <Iconify icon="solar:trash-bin-trash-bold" />
                            }
                            onClick={confirmRows.onTrue}
                          >
                            Delete ({selectedRowIds.length})
                          </Button>
                        </Stack>
                      )}
                    </Stack>
                  </GridToolbarContainer>
                ),
              }}
              slotProps={{
                toolbar: {
                  showQuickFilter: true,
                },
              }}
            />
          </Card>
          <ConfirmDialog
            open={confirmRows.value}
            onClose={confirmRows.onFalse}
            title="Supprimer"
            content={
              <>
                Êtes-vous sûr de vouloir supprimer{" "}
                <strong> {selectedRowIds.length} </strong> items?
              </>
            }
            action={
              <Button
                variant="contained"
                color="error"
                onClick={() => {
                  handleDeleteRows();
                  confirmRows.onFalse();
                }}
              >
                Supprimer
              </Button>
            }
          />
        </Grid>
      </Grid>
    </Container>
  );
}
