"use client";

import isEqual from "lodash/isEqual";
import { useState, useEffect, useCallback } from "react";
import Stack from "@mui/material/Stack";
import Card from "@mui/material/Card";
import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarExport,
  GridActionsCellItem,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
GridToolbarColumnsButton,
  GridColumnVisibilityModel,
  
} from "@mui/x-data-grid";

import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";
import { useBoolean } from "@/hooks/use-boolean";

import { fDate, fTime, isAfter, isBetween } from '@/utils/format-time';
import Iconify from "@/shared/components/iconify";
import { useSnackbar } from "@/shared/components/snackbar";
import EmptyContent from "@/shared/components/empty-content";
import { useSettingsContext } from "@/shared/components/settings";
import  { SelectChangeEvent } from "@mui/material/Select";
import { Category, IPromocodeFilter, IPromocodeFilterValue, Promocode, PromocodeType } from "@/contexts/types/promo";
import {  RenderCellCommande, RenderCellExpirationDate, RenderCellUsageLimit } from "./Codepromo-table-row";
import PromoCodeToolbar from "./Codepromo-toolbar";
import CodePromoResult from "./Codepromo-filters-result";
import mockPromocodes from "@/shared/_mock/_promo";
import RouterLink from '@/routes/router-link';
import React  from 'react';
import { useGetPromoCodes } from "@/shared/api/promo";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Button } from "@mui/material";





// ----------------------------------------------------------------------



const Typecode_OPTIONS = [
  { value: PromocodeType.Remisepanier, label: "Remise sur panier" },
  { value: PromocodeType.RemiseProduit, label: "Remise sur Produit" },
  { value: PromocodeType.RemisePourcentage, label: "Remise en Pourcentage" },
];

const Category_OPTIONS = [
  { value: Category.tous, label: "Tous" },
  { value: Category.vetements, label: "Vetements" },
  { value: Category.chaussures, label: "Chaussures" },
  { value: Category.accessoires, label: "Accessoires" },
  { value: Category.bijoux, label: "Bijoux" },
];

const defaultFilters: IPromocodeFilter = {
 
  typecode: [],
 
 
  
  Category: [],
  startDate: null,
  endDate: null,
};

const HIDE_COLUMNS = {
  category: false,
};

const HIDE_COLUMNS_TOGGLABLE = ["category", "actions"];

// ----------------------------------------------------------------------

export default function CodepromoListView() {
  const { enqueueSnackbar } = useSnackbar();

  const confirmRows = useBoolean();

  const router = useRouter();

  const settings = useSettingsContext();

const {promoCodes, promoCodesLoading} = useGetPromoCodes();

  const [tableData, setTableData] = useState<Promocode[]>(mockPromocodes);

  const [filters, setFilters] = useState(defaultFilters);

  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );

  const [columnVisibilityModel, setColumnVisibilityModel] =
    useState<GridColumnVisibilityModel>(HIDE_COLUMNS);

  useEffect(() => {
    if (promoCodes.length) {
      setTableData(promoCodes);
    }
  }, [promoCodes]);

  console.log(mockPromocodes);

  const dateError = isAfter(filters.startDate, filters.endDate);

  const dataFiltered = applyFilter({
    inputData: tableData,
    filters,
    dateError,
  });

  const canReset = !isEqual(defaultFilters, filters);

  const handleFilters = useCallback(
    (name: string, value: IPromocodeFilterValue) => {
      setFilters((prevState) => ({
        ...prevState,
        [name]: value,
      }));
    },
    []
  );

  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);

  const handleViewRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.product.details(id));
    },
    [router]
  );
  const handleDelete = (id: number) => {
    const isConfirmed = window.confirm("Êtes-vous sûr de vouloir supprimer ce code promo ?");
    if (isConfirmed) {
      const updatedRows = tableData.filter(row => row.id !== id.toString());
      setTableData(updatedRows);
    }
  };

  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.promo.edit(id));
    },
    [router]
  );

  const handleDuplicate = useCallback(
    (id: string) => {
      const duplicatedRow = tableData.find(row => row.id === id.toString());
      router.push(paths.promo.Duplicatepromo(id));
    
      if (duplicatedRow) {
        setTableData([...tableData, duplicatedRow]);
      }
    },
    [router]
  );
  
  
  // const handleDuplicate = (id: number) => {
  //   const duplicatedRow = tableData.find(row => row.id === id.toString());
  //   if (duplicatedRow) {

  //     setTableData([...tableData, duplicatedRow]);
  //   }
  // };

  const columns: GridColDef[] = [
   
    {
      field: "code",
      headerName: "Code",
      flex: 1,
      minWidth: 100,
    },
    {
      field: "typecode",
      headerName: "Typecode",
      flex: 1,
      minWidth: 150,
    },
    {
      field: "valuecode",
      headerName: "Valuecode",
      flex: 1,
      minWidth: 150,
    },
  
    {
      field: "Usage",
      headerName: "Usage/Limit",
      flex: 1,
      minWidth: 150,
      renderCell: (params) => <RenderCellUsageLimit params={params} />,
    },
  
    {
      field: "Description",
      headerName: "Description",
      flex: 1,
      minWidth: 150,
    },
    {
      field: "IDproduct",
      headerName: "IDproduct",
      flex: 1,
      minWidth: 150,
    },
    {
      field: "Commande",
      headerName: " Voir commande",
      flex: 1,
      minWidth: 150,
      renderCell: (params) => <RenderCellCommande params={params} />,
    },
    {
      field: "expirationDate",
      headerName: "ExpirationDate",
      flex: 1,
      minWidth: 150,
      renderCell: (params) => <RenderCellExpirationDate params={params} />,
        
     
    },
    {
      field: "Category",
      headerName: "Category",
      flex: 1,
      minWidth: 150,
    },
  

    {
      type: "actions",
      field: "actions",
      headerName: " ",
      align: "right",
      headerAlign: "right",
      width: 60,
      sortable: false,
      filterable: false,
      disableColumnMenu: true,
      getActions: (params) => [
      
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:pen-bold" />}
          label="Modifier"
          onClick={() => handleEditRow(params.row.id)}
        />,
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="ion:copy" />}
          label="Dupliquer"
          onClick={() => handleDuplicate(params.row.id as string)}
        />,
        <GridActionsCellItem
          showInMenu
          icon={<Iconify icon="solar:trash-bin-trash-bold" />}
          color="error"
          label="Supprimer"
          onClick={() => handleDelete(params.row.id as number)}
          sx={{ color: "error.main" }}
        />,
      ],
      
    },
  ];
    
    
  

  const getTogglableColumns = () =>
    columns
      .filter((column) => !HIDE_COLUMNS_TOGGLABLE.includes(column.field))
      .map((column) => column.field);

  const [selectedAction, setSelectedAction] = useState("");

  const handleActionChange = (event: SelectChangeEvent<string>) => {
    setSelectedAction(event.target.value);
  };

  const handleButtonClick = () => {
    // Logique à exécuter lorsqu'on clique sur le bouton
    console.log("Bouton cliqué !");
  };
  const [anchorEl, setAnchorEl] = useState<HTMLElement | null>(null);

  const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  return (
    <>
    
    <CustomBreadcrumbs
    heading="Liste des codes promo"
        links={[
           {
            name: 'dashboard',
            href: paths.dashboard.root,
          },
         
          {
            name: 'Liste des codes promo',
           
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />
      
      <Box>
          <Button variant="contained" component={RouterLink}
                  href={paths.promo.new} color="primary" style={{ marginRight: '10px' , marginBottom:'10px' }}>Ajouter un code promo</Button>
        </Box>
      <Card>
     

        <Box
          sx={{
            height: 700,
            width: "100%",
            flexGrow: { md: 1 },
            display: { md: "flex" },
            flexDirection: { md: "column" },
          }}
        >
          <DataGrid
            checkboxSelection
            disableRowSelectionOnClick
            rows={dataFiltered}
            columns={columns}
            getRowHeight={() => "auto"}
            pageSizeOptions={[5, 10, 25]}
            initialState={{
              pagination: {
                paginationModel: { pageSize: 10 },
              },
            }}
            onRowSelectionModelChange={(newSelectionModel) => {
              setSelectedRowIds(newSelectionModel);
            }}
            columnVisibilityModel={columnVisibilityModel}
            onColumnVisibilityModelChange={(newModel) =>
              setColumnVisibilityModel(newModel)
            }
            slots={{
              toolbar: () => (
                <>
                  <GridToolbarContainer>
                    <PromoCodeToolbar
                      filters={filters}
                      onFilters={handleFilters}
                      
                      typecodeOptions={Typecode_OPTIONS}
                      CategoryOptions={Category_OPTIONS}
                      

                      dateError={dateError}
                    />

                    <GridToolbarQuickFilter />

                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >

                      <GridToolbarColumnsButton />
                      <GridToolbarExport />
                    </Stack>
                  </GridToolbarContainer>

                  {canReset && (
                    <CodePromoResult
                      filters={filters}
                      onFilters={handleFilters}
                      onResetFilters={handleResetFilters}
                      results={dataFiltered.length}
                      sx={{ p: 2.5, pt: 0 }}
                    />
                  )}
                </>
              ),
              noRowsOverlay: () => <EmptyContent title="No Data" />,
              noResultsOverlay: () => <EmptyContent title="No results found" />,
            }}
            slotProps={{
              columnsPanel: {
                getTogglableColumns,
              },
            }}
          />
        </Box>
      </Card>
    </>
  );
}

// ----------------------------------------------------------------------

function applyFilter({
  inputData,
  filters,
  dateError,

}: {
  inputData: Promocode[];
  filters: IPromocodeFilter;
  dateError: boolean;
}) {
  const { typecode , Category ,startDate, endDate } = filters;

 

  if (typecode.length) {
    inputData = inputData.filter((codepromo) =>
      typecode.includes(codepromo.typecode)
    );
  }

 

  if (Category.length) {
    inputData = inputData.filter((codepromo) =>
      Category.includes(codepromo.Category)
    );
  }

  if (!dateError) {
    if (startDate && endDate) {
      inputData = inputData.filter((codepromo) => isBetween(codepromo.expirationDate , startDate, endDate));
    }
  }

  return inputData;
}
