'use client';
import React, { useState } from 'react';
import { Card, CardActionArea, CardContent, Typography, Button } from '@mui/material';
import EmailPurchaseForm from '@/shared/sections/purchase/purshaseorderemail';
import RouterLink from '@/routes/router-link';
import { paths } from '@/routes/paths';


export interface PurchaseOrderDesign {
  id: number;
  name: string;
  description: string;
  image: string;
}

const designs: PurchaseOrderDesign[] = [
  {
    id: 1,
    name: 'Happy birthday',
    description: 'Wish your loved ones a happy birthday with this beautiful card.',
    image: 'https://img.freepik.com/free-photo/happy-birthday-card-with-flowers-assortment_23-2149077343.jpg'
  },
  {
    id: 2,
    name: 'Thank you',
    description: ' joyeux noel chart',
    image: 'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQKggK58XBSE3ybpv7I-o-bpgDPOlWEtXcqXQ&usqp=CAU'
  },
  {
    id: 3,
    name: 'Congratulations',
    description: 'Congratulate someone on their special day with this beautiful card.',
    image: 'https://www.lesbrodeusesparisiennes.com/3518-large_default/-joyeux-noel-chart.jpg'
  }
];

const defaultDesign: PurchaseOrderDesign = {
  id: 0,
  name: 'Default Design',
  description: 'This is the default design',
  image: 'https://via.placeholder.com/150'
};

const PurchaseOrderForm = () => {
  const [email, setEmail] = useState('');
  const [selectedDesign, setSelectedDesign] = useState<PurchaseOrderDesign | null>(null);
  const [legend, setLegend] = useState(selectedDesign ? selectedDesign.name : defaultDesign ? defaultDesign.name : 'Happy birthday');
  const [description, setDescription] = useState('');
  const [amount, setAmount] = useState('');

  const [showEmailForm, setShowEmailForm] = useState(false);

  const handleDesignSelect = (design: PurchaseOrderDesign) => {
    setSelectedDesign(design);
  };


  const handleSubmit = (event: React.FormEvent<HTMLFormElement>) => {
    event.preventDefault();
    if (selectedDesign) {
      setSelectedDesign(selectedDesign);
    }
    else {
      setSelectedDesign(defaultDesign);
    }
  };





  return (
    <div>
      <Button variant="contained" component={RouterLink}
        href={paths.purchase.new} color="primary" style={{ marginRight: '10px', marginBottom: '30px' }}>Ajouter un nouveau modéle</Button>
      <Typography variant="h5" component="div">
        Choisissez un modèle de carte
      </Typography>

      <form onSubmit={handleSubmit} >
        <div style={{ display: 'flex', flexWrap: 'wrap' }}>
          {designs.map((design) => (
            <Card
              key={design.id}
              style={{
                width: 320,
                margin: 10,
                cursor: 'pointer',
                border: selectedDesign && selectedDesign.id === design.id ? '2px solid blue' : 'none'
              }}
            >
              <CardActionArea onClick={() => handleDesignSelect(design)}>
                {/* Affichez l'image et les informations du modèle */}
                <CardContent>
                  <Typography variant="h5" component="div">
                    {design.name}
                  </Typography>
                  <Typography variant="body2" color="textSecondary" component="p">
                    {design.description}
                  </Typography>
                  <img src={design.image} alt={design.name} style={{ width: '100%' }} />
                </CardContent>
              </CardActionArea>
            </Card>
          ))}
        </div>
        <Button type="submit" variant="contained" color="primary"  >
          Soumettre
        </Button>
      </form>
      {showEmailForm && selectedDesign && (
        <EmailPurchaseForm selectedDesign={selectedDesign || defaultDesign} defaultDesign={null} />
      )}
    </div>
  );
};

export default PurchaseOrderForm;



