'use client';
import React from 'react';
import AppBar from '@mui/material/AppBar';
import Box from '@mui/material/Box';
import Toolbar from '@mui/material/Toolbar';
import Typography from '@mui/material/Typography';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import Container from '@mui/material/Container';
import Button from '@mui/material/Button';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs/custom-breadcrumbs';
import { paths } from '@/routes/paths';

import PurchaseOrderForm from './purshase';
import EmailPurchaseForm from './purshaseorderemail';


const pages: string[] = ["bon d'achat d'email", 'Conception de model de bon'];

function ResponsiveAppBar() {
  const [anchorElNav, setAnchorElNav] = React.useState<null | HTMLElement>(null);
  const [currentPage, setCurrentPage] = React.useState("bon d'achat d'email");


  const handleCloseNavMenu = () => {
    setAnchorElNav(null);
  };




  const handlePageChange = (page: string) => {
    setCurrentPage(page);

    handleCloseNavMenu(); // Fermer le menu après avoir changé de page
  };

  // Contenu pour chaque page
  const pageContents: { [key: string]: JSX.Element } = {
    "bon d'achat d'email": (
      
        <EmailPurchaseForm selectedDesign={null} defaultDesign={null} />
      
    ),
    // Autres pages ici

    'Conception de model de bon': (

      
        <PurchaseOrderForm />
      
    ),

  };

  return (
    <AppBar position="static">
      <Container maxWidth="xl">
        <Toolbar disableGutters>
          <Box sx={{ flexGrow: 1, display: { xs: 'flex', md: 'none' } }}>
            <Menu
              id="menu-appbar"
              anchorEl={anchorElNav}
              anchorOrigin={{
                vertical: 'bottom',
                horizontal: 'left',
              }}
              keepMounted
              transformOrigin={{
                vertical: 'top',
                horizontal: 'left',
              }}
              open={Boolean(anchorElNav)}
              onClose={handleCloseNavMenu}
              sx={{
                display: { xs: 'block', md: 'none' },
              }}
            >
              {pages.map((page) => (
                <MenuItem key={page} onClick={() => handlePageChange(page)}>
                  <Typography textAlign="center">{page}</Typography>
                </MenuItem>
              ))}
            </Menu>
          </Box>
          <Box sx={{ display: 'flex', alignItems: 'center' }}>
            <CustomBreadcrumbs
              links={[
                {
                  name: 'Dashboard',
                  href: paths.dashboard.root,
                },
                {
                  name: 'les bons d\'achats ',
                },
              ]}
              sx={{
                mb: { xs: 3, md: 19 },
              }}
            />
            {pages.map((page, index) => (
              <React.Fragment key={page}>
                <Button
                  onClick={() => handlePageChange(page)}
                  sx={{ my: 2, color: currentPage === page ? 'primary' : 'inherit', backgroundColor: currentPage === page ? '#f0f0fa' : 'inherit' }}
                >
                  {page}
                </Button>
                {index !== pages.length - 1 && <Box width={50} />}
              </React.Fragment>
            ))}
          </Box>
        </Toolbar>
      </Container>
      <Box mt={4}>
        {/* Affichage du contenu de la page actuelle */}
        {pageContents[currentPage]}
      </Box>
    </AppBar>
  );
}

export default ResponsiveAppBar;
