"use client";


import { useState, useEffect, useCallback } from "react";

import Stack from "@mui/material/Stack";

import Card from "@mui/material/Card";

import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarExport,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
  GridToolbarColumnsButton,

} from "@mui/x-data-grid";

import { useRouter } from "@/hooks";
import { Typography } from '@mui/material';
import { useBoolean } from "@/hooks/use-boolean";
import Iconify from "@/shared/components/iconify";
import { useSnackbar } from "@/shared/components/snackbar";
import { useSettingsContext } from "@/shared/components/settings";
import MenuItem from "@mui/material/MenuItem";
import CustomPopover, { usePopover } from "@/shared/components/custom-popover";
import { ListReferral } from "@/contexts/types/Referral";
import mockReferrerList from "@/shared/_mock/_listreferrer";
import { RenderCellgain } from "./Listreferrer-table-row";

// ----------------------------------------------------------------------




export default function ListreferrerView() {
  const { enqueueSnackbar } = useSnackbar();

  const confirmRows = useBoolean();
  const popover = usePopover();

  const router = useRouter();


  const [ListReferral, setListReferral] = useState<ListReferral[]>(mockReferrerList);

  const [tableData, setTableData] = useState<ListReferral[]>(mockReferrerList);


  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );




  useEffect(() => {
    if (ListReferral.length) {

      setTableData(ListReferral);
    }

  }, [ListReferral]);


  const columns: GridColDef[] = [


    { field: "name", headerName: "Nom", flex: 1 },
    { field: "email", headerName: "Email", flex: 1 },
    { field: "code", headerName: "Code de parrainage", flex: 1 },
    { field: "total", headerName: "Total de parrainage", flex: 1 },
    {field: "GAINS DE PARRAINAGE", headerName: "GAINS DE PARRAINAGE", flex: 1 ,
    renderCell: (params) => <RenderCellgain params={params} />
    }




  ];


  return (
    <>

      <Typography variant="h6" gutterBottom sx={{ marginTop: '70px' }}>
        List des parrains

      </Typography>


      <Card sx={{ marginTop: '30px' }}>
        <Box
          sx={{
            height: 430,
            width: "100%",
            flexGrow: { md: 1 },
            display: { md: "flex" },
            flexDirection: { md: "column" },
          }}
        >
          <DataGrid
            checkboxSelection
            disableRowSelectionOnClick
            rows={tableData}
            columns={columns}
            getRowHeight={() => "auto"}
            pageSizeOptions={[5, 10, 25]}
            initialState={{
              pagination: {
                paginationModel: { pageSize: 10 },
              },
            }}
            onRowSelectionModelChange={(newSelectionModel) => {
              setSelectedRowIds(newSelectionModel);
            }}

            slots={{
              toolbar: () => (
                <>
                  <GridToolbarContainer>


                    <GridToolbarQuickFilter />

                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >

                      <GridToolbarColumnsButton />
                      <GridToolbarExport />
                    </Stack>
                  </GridToolbarContainer>





                </>
              ),
            }}

          />
        </Box>
        <CustomPopover
          open={popover.open}
          onClose={popover.onClose}
          arrow="right-top"
          sx={{ width: 140 }}
        >
          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:printer-minimalistic-bold" />
            Imprimer
          </MenuItem>

          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:import-bold" />
            Importer
          </MenuItem>

          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:export-bold" />
            Exporter
          </MenuItem>

        </CustomPopover>
      </Card>

    </>
  );
}




