import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import Switch from '@mui/material/Switch';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider from '@/components/hook-form';

import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';
import React from 'react';
import TextField from '@mui/material/TextField';
import LoadingButton from '@mui/lab/LoadingButton';
import { PromocodeType } from '@/contexts/types/promo';
import MenuItem from '@mui/material/MenuItem';
import { Checkbox } from '@mui/material';


export default function Referral() {
    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();
    const [enableReferralProgram, setEnableReferralProgram] = React.useState(false);

    const NewReferralRulesSchema = Yup.object().shape({
        rewardType: Yup.string().oneOf(['discount', 'freeProduct']).required('Reward type is required'),
        // Add more validation rules as needed
    });

    const methods = useForm({
        resolver: yupResolver(NewReferralRulesSchema),
    });

    const [showDiscountGrid, setShowDiscountGrid] = React.useState(false);

    const handleDiscountProgramToggle = () => {
        setShowDiscountGrid(!showDiscountGrid); // Inverser l'état de showDiscountGrid
    };

    const [showGeneretedcouponGrid, setshowGeneretedcouponGridGrid] = React.useState(false);

    const handleGeneretedcouponToggle = () => {
        setshowGeneretedcouponGridGrid(!showGeneretedcouponGrid); // Inverser l'état de showDiscountGrid
    };




    const handleReferralProgramToggle = () => {
        setEnableReferralProgram(!enableReferralProgram);

    };
    const {
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            enqueueSnackbar('Referral rules saved successfully!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed to save referral rules.', { variant: 'error' });
        }
    });

    const renderBasic = (
        <>
            {mdUp && (
                <Grid md={4} sx={{ marginTop: '70px' }}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Parrainage
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Configuration des règles de parrainage pour récompenser les parrains et les parrainés
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8} sx={{ marginTop: '70px' }}>
                <Card>
                    {!mdUp && <CardHeader title="Nouvelle règle de parrainage" />}

                    <Stack spacing={2} sx={{ p: 3 }}>
                        <FormLabel id="referral-switch-label">Activation du programme de parrainage</FormLabel>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch checked={enableReferralProgram} onChange={handleReferralProgramToggle} inputProps={{ 'aria-label': 'controlled' }} />
                            <label>Activer le programme de parrainage</label>
                        </div>
                        {enableReferralProgram && (
                            <FormControl>
                                <CardHeader title="paramètres généraux" style={{ marginBottom: '20px' }} />
                                <FormLabel id="reward-type-label" style={{ marginBottom: '20px' }}> Verification IP contre les fraudes </FormLabel>
                                <div style={{ display: 'flex', alignItems: 'center', marginBottom: '20px' }}>
                                    <Switch name='enableIPCheck' inputProps={{ 'aria-label': 'controlled' }} /> <label>Activer la vérification IP pour éviter les fraudes </label>
                                </div>
                                <FormLabel id="reward-Email" style={{ marginBottom: '20px' }}>Envoyer un email aprés une commande réussie </FormLabel>
                                <div style={{ display: 'flex', alignItems: 'center' }}>
                                    <Switch name='enableEmail' inputProps={{ 'aria-label': 'controlled' }} /> <label>Activer l'envoi d'email au parrain aprés une commande réussie </label>
                                </div>
                                <div style={{ display: 'flex', alignItems: 'center', marginBottom: '20px' }}>
                                    <Switch name='enableEmail' inputProps={{ 'aria-label': 'controlled' }} /> <label>Activer l'envoi d'email au parrainé aprés une commande réussie </label>
                                </div>
                                <FormLabel id="reward-type-label" style={{ marginBottom: '20px' }}>type de récompense pour les parrains </FormLabel>
                                <div style={{ display: 'flex', alignItems: 'center' }}>
                                    <Switch name='enableDiscount' inputProps={{ 'aria-label': 'controlled' }} /> <label>Récompense basée sur la commande</label>
                                </div>

                                <div style={{ display: 'flex', alignItems: 'center', marginBottom: '20px' }}>
                                    <Switch name='enableCoupon' inputProps={{ 'aria-label': 'controlled' }} /> <label>Récompense basée sur l'inscription</label>
                                </div>

                                <FormLabel id="reward-type-label" style={{ marginBottom: '20px' }}>type de récompense pour les parrainés </FormLabel>
                                <div style={{ display: 'flex', flexDirection: 'column' }}>
                                    <div style={{ display: 'flex', alignItems: 'center' }}>
                                        <Switch name='enableDiscount' inputProps={{ 'aria-label': 'controlled' }} onChange={handleDiscountProgramToggle} />
                                        <label style={{ marginLeft: '10px' }}>Remise sur le premier achat</label>
                                    </div>
                                    <p style={{ marginLeft: '30px', fontSize: '0.9em', color: '#332' }}>
                                        cette option pour émettre un coupon au client après l'achèvement réussi de sa première commande.
                                    </p>
                                </div>

                                <div style={{ display: 'flex', flexDirection: 'column' }}>
                                    <div style={{ display: 'flex', alignItems: 'center' }}>
                                        <Switch name='enableCoupon' inputProps={{ 'aria-label': 'controlled' }} onChange={handleGeneretedcouponToggle} />
                                        <label style={{ marginLeft: '10px' }}>Coupon après le premier achat</label>
                                    </div>
                                    <p style={{ marginLeft: '30px', fontSize: '0.9em', color: '#332' }}>
                                        cette option pour émettre un coupon au client après l'achèvement réussi de sa première commande.
                                    </p>
                                </div>


                            </FormControl>
                        )}
                    </Stack>
                </Card>

            </Grid>

            {showDiscountGrid && (
                <Grid xs={12} md={10} sx={{ width: '80%' }}>
                    <Card>


                        <Stack spacing={2} sx={{ p: 3 }}>

                            <FormControl>
                                <CardHeader title="Remise sur le premier achat" style={{ marginBottom: '20px' }} />

                                <p style={{ marginBottom: '20px', fontSize: '0.9em', color: '#332' }}>Page des coupons et créer manuellement un coupon, choisissez les options que vous souhaitez et assurez-vous qu'il n'y a pas de limite ou de restriction par e-mail. Ensuite, placez le code du coupon dans la zone de texte ci-dessous et enregistrez-le</p>
                                <TextField
                                    label="enter coupon code"
                                    id="filled-size-normal"
                                    defaultValue="Normal"
                                    variant="filled"
                                    InputLabelProps={{
                                        shrink: true,
                                    }}
                                    style={{ width: '40%' }}
                                />

                                <p style={{ marginBottom: '20px', fontSize: '0.9em', color: '#332' }}>Voici le message qui sera affiché sur la page du panier lorsque le coupon est automatiquement appliqué   </p>
                                <TextField
                                    id="outlined-multiline-flexible"
                                    label="Message"
                                    multiline
                                    maxRows={4}
                                    InputLabelProps={{
                                        shrink: true,
                                    }}
                                    style={{ width: '40%' }}
                                />
                               


                            </FormControl>

                        </Stack>
                    </Card>

                </Grid>
            )}
            {showGeneretedcouponGrid && (
                <Grid xs={12} md={10} sx={{ width: '80%' }}>
                    <Card>


                        <Stack spacing={2} sx={{ p: 3 }}>

                            <FormControl defaultValue="" >
                                <CardHeader title="Coupon après le premier achat" style={{ marginBottom: '20px' }} />

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-nom-code"
                                        label="nom du code promo"
                                        type="search"
                                        placeholder='entrer le nom du code promo'
                                        variant="outlined"
                                        style={{ flex: '1 1 45%' }}
                                        required
                                    />
                                    <TextField
                                        id="outlined-type-code"
                                        select
                                        label="Type de promo"
                                        variant="outlined"
                                        style={{ flex: '1 1 45%' }}
                                        required
                                    >
                                        {Object.values(PromocodeType).map((option) => (
                                            <MenuItem key={option} value={option}>
                                                {option}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </div>

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-valeur-code"
                                        label="valeur code promo"
                                        type="search"
                                        placeholder='0'
                                        variant="outlined"
                                        style={{ flex: '1 1 45%' }}
                                        required
                                    />
                                    <div style={{ flex: '1 1 45%', display: 'flex', alignItems: 'center' }}>
                                        <Checkbox defaultChecked size="small" />
                                        <span>Cocher cette case si le code promo inclut l’expédition gratuite.</span>
                                    </div>
                                </div>

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-usage-restriction"
                                        label="Dépense minimale"
                                        variant="outlined"
                                        placeholder="0"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}
                                        required
                                        style={{ flex: '1 1 45%' }}
                                    />
                                    <div style={{ flex: '1 1 45%', display: 'flex', alignItems: 'center' }}>
                                        <Checkbox defaultChecked size="small" />
                                        <span style={{ marginLeft: '10px' }}>Cochez cette case si le code promo ne peut être utilisé conjointement avec d’autres codes promo.</span>
                                    </div>
                                </div>

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-produit-restriction"
                                        label="Réduction par produit"
                                        variant="outlined"
                                        placeholder="ID produit"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}

                                        style={{ flex: '1 1 45%' }}
                                    />
                                    <TextField
                                        id="outlined-prod-restriction"
                                        label="Exclure un produit"
                                        variant="outlined"
                                        placeholder="ID produit"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}

                                        style={{ flex: '1 1 45%' }}
                                    />
                                </div>

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-category-restriction"
                                        label="Réduction par catégorie"
                                        variant="outlined"
                                        placeholder="catégorie"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}
                                        style={{ flex: '1 1 45%' }}
                                    />
                                    <TextField
                                        id="outlined-categ-restriction"
                                        label="Exclure une catégorie"
                                        variant="outlined"
                                        placeholder="catégorie"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}
                                        style={{ flex: '1 1 45%' }}
                                    />
                                </div>

                                <div style={{ display: 'flex', flexWrap: 'wrap', gap: '20px', marginBottom: '40px' }}>
                                    <TextField
                                        id="outlined-categ-restriction"
                                        label="durée de validité du code promo"
                                        variant="outlined"
                                        placeholder="10"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}
                                        required
                                        style={{ flex: '1 1 45%' }}
                                    />
                                    <TextField
                                        id="outlined-categ-restriction"
                                        label="Limite l'utilisation à X articles"
                                        variant="outlined"
                                        placeholder="0"
                                        InputLabelProps={{
                                            shrink: true,
                                        }}
                                        style={{ flex: '1 1 45%' }}
                                        required
                                    />
                                </div>
                            </FormControl>

                        </Stack>
                    </Card>

                </Grid>
            )}
        </>
    );
    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );


    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderBasic}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
