"use client";

import isEqual from "lodash/isEqual";
import { useState, useEffect, useCallback } from "react";
import Stack from "@mui/material/Stack";
import Card from "@mui/material/Card";
import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarExport,
  GridActionsCellItem,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
  GridToolbarFilterButton,
  GridToolbarColumnsButton,
  GridColumnVisibilityModel,
  GridFilterAltIcon,
} from "@mui/x-data-grid";
import { RHFAutocomplete, } from '@/components/hook-form';
import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";
import { Toolbar, IconButton, Menu, Typography } from '@mui/material';
import MenuIcon from '@mui/icons-material/Menu';
import RouterLink from "@/routes/router-link";
import { useBoolean } from "@/hooks/use-boolean";
import { useGetProducts } from "@/shared/api/product";
import { PRODUCT_STOCK_OPTIONS } from "@/shared/_mock";
import { isAfter, isBetween } from '@/utils/format-time';
import Iconify from "@/shared/components/iconify";
import { useSnackbar } from "@/shared/components/snackbar";
import EmptyContent from "@/shared/components/empty-content";
import { useSettingsContext } from "@/shared/components/settings";
import MenuItem from "@mui/material/MenuItem";
import CustomPopover, { usePopover } from "@/shared/components/custom-popover";
import { IReferralFilter, IReferralOrderFilterValue, ReferralOrder, Referralstatus } from "@/contexts/types/Referral";
import mockReferralOrders from "@/shared/_mock/_referral";
import ReferralTableToolbar from "./ReferralOrder-table-toolbar";
import ReferralOrderTableFiltersResult from "./ReferralOrder-table-filters-result";
import { RenderCellDatecommande, RenderCellStatus, RenderCellprix } from "./ReferralOrder-table-row";

// ----------------------------------------------------------------------

const Status_OPTIONS = [
  { value: Referralstatus.Pending, label: "En attente" },
  { value: Referralstatus.InProgress, label: "En cours" },
  { value: Referralstatus.Validated, label: "Validé" },
];

const HIDE_COLUMNS = {
  category: false,
};

const HIDE_COLUMNS_TOGGLABLE = ["category", "actions"];


export default function ReferralOrderView() {
  const { enqueueSnackbar } = useSnackbar();


  const confirmRows = useBoolean();
  const popover = usePopover();

  const router = useRouter();

  const settings = useSettingsContext();

  const [ReferralOrder, setReferralOrder] = useState<ReferralOrder[]>(mockReferralOrders);

  const [tableData, setTableData] = useState<ReferralOrder[]>(mockReferralOrders);

  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>([]);

  const getTogglableColumns = () =>
    columns
      .filter((column) => !HIDE_COLUMNS_TOGGLABLE.includes(column.field))
      .map((column) => column.field);

  const defaultFilters: IReferralFilter = {
    status: [],
    startDate: null,
    endDate: null,
  };

  const [filters, setFilters] = useState(defaultFilters);

  const [columnVisibilityModel, setColumnVisibilityModel] =
    useState<GridColumnVisibilityModel>(HIDE_COLUMNS);

  const dateError = isAfter(filters.startDate, filters.endDate);

  useEffect(() => {
    if (ReferralOrder.length) {
      setTableData(ReferralOrder);
    }
  }, [ReferralOrder]);


  const dataFiltered = applyFilter({
    inputData: tableData,
    filters,
    dateError,
  });

  const canReset = !isEqual(defaultFilters, filters);

  const columns: GridColDef[] = [
    {
      field: "Status",
      headerName: "Statut",
      flex: 1,
      renderCell: (params) => <RenderCellStatus params={params} />,
    },
    {
      field: "Numcommande",
      headerName: "Numéro de commande",
      flex: 1,
    },
    {
      field: "parrain",
      headerName: "Parrain",
      flex: 1,
    },
    {
      field: "parraine",
      headerName: "Parrainé",
      flex: 1,
    },
    {
      field: "Datecommande",
      headerName: "Date de commande",
      flex: 1,
      renderCell: (params) => <RenderCellDatecommande params={params} />,
    },
    {
      field: "prix",
      headerName: "Prix",
      flex: 1,
      renderCell: (params) => <RenderCellprix params={params} />,
    },
 
  ];

  const handleFilters = useCallback(
    (name: string, value: IReferralOrderFilterValue) => {
      setFilters((prevState) => ({
        ...prevState,
        [name]: value,
      }));
    },
    []
  );

  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);

  const handleButtonClick = () => {
    // Logique à exécuter lorsqu'on clique sur le bouton
    console.log("Bouton cliqué !");
  };
  const [anchorEl, setAnchorEl] = useState<HTMLElement | null>(null);

  const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };


  return (
    <>
      <Typography variant="h6" gutterBottom sx={{ marginTop: '40px' }}>
        List des commande de parrainage

      </Typography>
      <Typography variant="subtitle2" gutterBottom style={{ marginBottom: '10px' }} >

        Voici la liste de toutes les commandes de parrainage effectuées sur votre boutique.
      </Typography>


      <Card sx={{ marginTop: '30px' }}>
        <Box
          sx={{
            height: 500,
            width: "100%",
            flexGrow: { md: 1 },
            display: { md: "flex" },
            flexDirection: { md: "column" },
          }}
        >

          {/* +++++++++++++++++ */}


          <DataGrid
            checkboxSelection
            disableRowSelectionOnClick
            rows={dataFiltered}
            columns={columns}
            getRowHeight={() => "auto"}
            pageSizeOptions={[5, 10, 25]}
            initialState={{
              pagination: {
                paginationModel: { pageSize: 10 },
              },
            }}
            onRowSelectionModelChange={(newSelectionModel) => {
              setSelectedRowIds(newSelectionModel);
            }}
            columnVisibilityModel={columnVisibilityModel}
            onColumnVisibilityModelChange={(newModel) =>
              setColumnVisibilityModel(newModel)
            }
            slots={{
              toolbar: () => (
                <>
                  <GridToolbarContainer>
                    <ReferralTableToolbar
                      filters={filters}
                      onFilters={handleFilters}
                      statusOptions={Status_OPTIONS}
                      dateError={dateError}
                    />

                    <GridToolbarQuickFilter />

                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >

                      <GridToolbarColumnsButton />
                      <GridToolbarExport />
                    </Stack>
                  </GridToolbarContainer>

                  {canReset && (
                    <ReferralOrderTableFiltersResult
                      filters={filters}
                      onFilters={handleFilters}
                      onResetFilters={handleResetFilters}
                      results={dataFiltered.length}
                      sx={{ p: 2.5, pt: 0 }}
                    />
                  )}
                </>
              ),
              noRowsOverlay: () => <EmptyContent title="No Data" />,
              noResultsOverlay: () => <EmptyContent title="No results found" />,
            }}
            slotProps={{
              columnsPanel: {
                getTogglableColumns,
              },
            }}
          />
        </Box>
        <CustomPopover
          open={popover.open}
          onClose={popover.onClose}
          arrow="right-top"
          sx={{ width: 140 }}
        >
          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:printer-minimalistic-bold" />
            Imprimer
          </MenuItem>

          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:import-bold" />
            Importer
          </MenuItem>

          <MenuItem
            onClick={() => {
              popover.onClose();
            }}
          >
            <Iconify icon="solar:export-bold" />
            Exporter
          </MenuItem>

        </CustomPopover>
      </Card>

    </>
  );
}



// ----------------------------------------------------------------------

function applyFilter({
  inputData,
  filters,
  dateError,

}: {
  inputData: ReferralOrder[];
  filters: IReferralFilter;
  dateError: boolean;
}) {
  const { status, startDate, endDate } = filters;

  if (status.length) {
    inputData = inputData.filter((order) =>
      status.includes(order.Status)
    );
  }

  if (!dateError) {
    if (startDate && endDate) {
      inputData = inputData.filter((order) => isBetween(order.Datecommande, startDate, endDate));
    }
  }

  return inputData;
}


