'use client';
import React from 'react';
import AppBar from '@mui/material/AppBar';
import Box from '@mui/material/Box';
import Toolbar from '@mui/material/Toolbar';
import Typography from '@mui/material/Typography';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import Container from '@mui/material/Container';
import Button from '@mui/material/Button';
import AdbIcon from '@mui/icons-material/Adb';
import ReferralOrderView from './ReferralOrder/RefferalOrderListView';
import ListreferrerView from './Listreferrer/ListreferrerListView';
import RewardBox from './Rewardbox';
import Referral from './Referral';


const pages: string[] = ['Commandes de parrainage', 'liste des parrains', 'paramètre de parrainage', 'Affichage de boite de recompense'];

function ResponsiveAppBar() {
  const [anchorElNav, setAnchorElNav] = React.useState<null | HTMLElement>(null);
  const [currentPage, setCurrentPage] = React.useState(pages[0]);

  const handleCloseNavMenu = () => {
    setAnchorElNav(null);
  };

  const handlePageChange = (page: string) => {
    setCurrentPage(page);
    handleCloseNavMenu();
  };



  // Contenu pour chaque page
  const pageContents: { [key: string]: JSX.Element } = {
    'Commandes de parrainage': (

      <ReferralOrderView />






    ),
    'liste des parrains': (

      <ListreferrerView />
    ),
    'paramètre de parrainage': (

      <Referral />
    ),
    'Affichage de boite de recompense': (
      <RewardBox />
    ),
  };

  return (
    <AppBar position="static">
      <Container maxWidth="xl">
        <Toolbar disableGutters>


          <Box sx={{ flexGrow: 1, display: { xs: 'flex', md: 'none' } }}>
            <Menu
              id="menu-appbar"
              anchorEl={anchorElNav}
              anchorOrigin={{
                vertical: 'bottom',
                horizontal: 'left',
              }}
              keepMounted
              transformOrigin={{
                vertical: 'top',
                horizontal: 'left',
              }}
              open={Boolean(anchorElNav)}
              onClose={handleCloseNavMenu}
              sx={{
                display: { xs: 'block', md: 'none' },
              }}
            >
              {pages.map((page) => (
                <MenuItem key={page} onClick={() => handlePageChange(page)}>
                  <Typography textAlign="center">{page}</Typography>
                </MenuItem>
              ))}
            </Menu>
          </Box>
          <AdbIcon sx={{ display: { xs: 'flex', md: 'none' }, mr: 1 }} />

          <Box sx={{ display: 'flex', alignItems: 'center' }}>
            {pages.map((page, index) => (
              <React.Fragment key={page}>
                <Button
                  onClick={() => handlePageChange(page)}
                  sx={{ my: 2, color: currentPage === page ? 'primary' : 'inherit', backgroundColor: currentPage === page ? '#f0f0fa' : 'inherit' }}

                >
                  {page}
                </Button>
                {index !== pages.length - 1 && <Box width={50} />}
              </React.Fragment>
            ))}
          </Box>
        </Toolbar>
      </Container>
      <Box mt={4}>
        {/* Affichage du contenu de la page actuelle */}
        {pageContents[currentPage]}
      </Box>
    </AppBar>
  );
}

export default ResponsiveAppBar;
