'use client'

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import Switch from '@mui/material/Switch';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';

import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';
import TextField from '@mui/material/TextField';
import { useState } from 'react';


export default function RewardBox() {

    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const NewReferralRulesSchema = Yup.object().shape({

        // Add more validation rules as needed
    });
    const [showRewardBox, setShowRewardBox] = useState(false);

    const methods = useForm({
        resolver: yupResolver(NewReferralRulesSchema),
    });





    const {
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            enqueueSnackbar('Referral rules saved successfully!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed to save referral rules.', { variant: 'error' });
        }
    });

    const renderBasic = (
        <>
            {mdUp && (
                <Grid md={4} sx={{ marginTop: '70px' }}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>

                        Boîte de récompense

                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Paramètres pour afficher les récompenses sous forme de coupons.
                    </Typography>
                </Grid>
            )}


            <Grid xs={12} md={8} sx={{ marginTop: '70px' }}>
                <Card>
                    {!mdUp && <CardHeader title="remise" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormLabel id="referral-switch-label">Afficher la boîte de récompense</FormLabel>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch name='enablediscount' inputProps={{ 'aria-label': 'controlled' }}
                                checked={showRewardBox}
                                onChange={() => setShowRewardBox(!showRewardBox)} /> <label>Afficher la boîte de récompense</label>
                        </div>
                        <FormLabel id="referral-switch-label">partager</FormLabel>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch name='enablediscount' inputProps={{ 'aria-label': 'controlled' }} /> <label>Share via Facebook</label>
                        </div>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch name='enablediscount' inputProps={{ 'aria-label': 'controlled' }} /> <label>Share via Twitter</label>
                        </div>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch name='enablediscount' inputProps={{ 'aria-label': 'controlled' }} /> <label>Share via  Messenger</label>
                        </div>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch name='enablediscount' inputProps={{ 'aria-label': 'controlled' }} /> <label>Share via WhatsApp</label>
                        </div>




                    </Stack>
                </Card>
            </Grid>
            <Grid xs={12} md={12}>
                <Card>


                    <Stack spacing={2} sx={{ p: 3 }}>
                        {showRewardBox && (
                            <FormControl>
                                <CardHeader title="Boite de recompense" style={{ marginBottom: '20px' }} />

                                <FormLabel id="reward-type-label" style={{ marginBottom: '5px' }}> vous recevrez un texte </FormLabel>
                                <TextField

                                    id="filled-size-normal"
                                    defaultValue="vous recevrez"


                                />
                                <FormLabel id="reward-type-label" style={{ marginBottom: '5px' }}> vous recevrez une recompense </FormLabel>
                                <TextField

                                    id="filled-size-normal"
                                    defaultValue="20%"
                                />

                                <FormLabel id="reward-type-label" style={{ marginBottom: '5px' }}> vos amis vont recevoir </FormLabel>
                                <TextField

                                    id="filled-size-normal"
                                    defaultValue="vos amis vont recevoir "
                                />
                                <FormLabel id="reward-type-label" style={{ marginBottom: '5px' }}> vos amis vont recevoir </FormLabel>
                                <TextField

                                    id="filled-size-normal"
                                    defaultValue="20% "
                                />





                            </FormControl>
                        )}
                    </Stack>
                </Card>

            </Grid>

        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );

    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderBasic}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}


