import React, { useCallback, useState } from "react";
import Stack from "@mui/material/Stack";
import MenuItem from "@mui/material/MenuItem";
import TextField from "@mui/material/TextField";
import IconButton from "@mui/material/IconButton";
import InputAdornment from "@mui/material/InputAdornment";
import Iconify from "../../../components/iconify";
import CustomPopover, { usePopover } from "../../../components/custom-popover";
import {
  IReviewTableFilters,
  IReviewTableFilterValue,
} from "../../../types/review";
import { Autocomplete, Button, Dialog, DialogActions, DialogContent, Grid } from "@mui/material";
import FilterView from "../filter-view";
import ColumnView from "../column-view";

// ----------------------------------------------------------------------

interface Entry {
  colonnes: string;
}

type Props = {
  filters: IReviewTableFilters;
  onFilters: (name: string, value: IReviewTableFilterValue) => void;
  dateError: boolean;
};

export default function ReviewTableToolbar({
  filters,
  onFilters,
}: Props) {
  const popover = usePopover();
  const [entries, setEntries] = useState<Entry[]>([{ colonnes: "" }]);

  const handleFilterName = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("name", event.target.value as IReviewTableFilterValue);
    },
    [onFilters]
  );

  const [open, setOpen] = useState(false);
  const [openColumn, setOpenColumn] = useState(false);

  const handleClickOpen = () => setOpen(true);
  const handleClose = () => setOpen(false);

  const handleClickOpenColumn = () => setOpenColumn(true);
  const handleCloseColumn = () => setOpenColumn(false);

  return (
    <>
      <Stack
        spacing={2}
        alignItems={{ xs: "flex-end", md: "center" }}
        direction={{ xs: "column", md: "row" }}
        sx={{ p: 2.5, pr: { xs: 2.5, md: 1 } }}
      >
        <Stack
          direction="row"
          alignItems="center"
          spacing={2}
          flexGrow={1}
          sx={{ width: 0.6 }}
        >
          <TextField
            fullWidth
            value={filters.name as string}
            onChange={handleFilterName}
            placeholder="Rechercher un client ou un produit..."
            InputProps={{
              startAdornment: (
                <InputAdornment position="start">
                  <Iconify icon="eva:search-fill" sx={{ color: "text.disabled" }} />
                </InputAdornment>
              ),
            }}
          />

          <Grid item xs={3} sx={{width:0.4}}>
            <Autocomplete
              value={entries[0].colonnes}
              onChange={(_, newValue) => {
                setEntries([{ colonnes: newValue ?? "" }]);
              }}
              options={["Approuvé"," Indésirable "," Mis à la corbeille "  ]}
              fullWidth
              renderInput={(params) => <TextField {...params} label="Actions groupées" />}
            />
          </Grid>

          <Button variant="contained" onClick={handleClickOpen}  sx={{width:0.1}}>
          Appliquer
          </Button>
         

          

        </Stack>
      </Stack>

    
    </>
  );
}
