"use client";

import { useState } from "react";
import Container from "@mui/material/Container";
import { Typography, Checkbox, Table, TableBody, TableCell, TableContainer, TableHead, TableRow, Paper, Switch } from '@mui/material';
import { paths } from "../../../../routes/paths";
import { useSettingsContext } from "../../../components/settings";
import CustomBreadcrumbs from "../../../../components/custom-breadcrumbs";

// ----------------------------------------------------------------------

export default function ReviewListView() {
  const settings = useSettingsContext();

  const [preferences, setPreferences] = useState({
    paypal: true,
    card: true,
    bank: true,
  });

  const handlePreferenceChange = (event: { target: { name: any; checked: any; }; }) => {
    const { name, checked } = event.target;
    setPreferences(prevPreferences => ({
      ...prevPreferences,
      [name]: checked,
    }));
  };



  return (
    <Container maxWidth={settings.themeStretch ? false : "lg"}>
      <CustomBreadcrumbs
        heading="Configuration"
        links={[
          {
            name: "dashboard",
            href: paths.dashboard.root,
          },
          {
            name: "Commentaires",
            href: paths.dashboard.order.all_orders,
          },
          {
            name: "Configuration",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />
      
      <TableContainer component={Paper}>
        <Table>
          <TableHead>
            <TableRow>
              <TableCell>Nom</TableCell>
              <TableCell align="center">Activé</TableCell>
              <TableCell>Description</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow key="PayPal">
              <TableCell>Autoriser les commentaires sur le site</TableCell>
              <TableCell align="center">
                <Switch
                  checked={preferences.paypal}
                  onChange={handlePreferenceChange}
                  name="paypal"
                  color="primary"
                />
              </TableCell>
              <TableCell> Cette option permet d'activer ou de désactiver la fonctionnalité de commentaires sur le site. Lorsqu'elle est activée, les visiteurs peuvent laisser des commentaires sur les articles. Si elle est désactivée, cette fonctionnalité sera masquée pour les utilisateurs.</TableCell>
            </TableRow>
            {preferences.paypal && (
              <>
                <TableRow key="Carte Bancaire">
                  <TableCell>Autoriser les notifications pour admin </TableCell>
                  <TableCell align="center">
                    <Switch
                      checked={preferences.card}
                      onChange={handlePreferenceChange}
                      name="card"
                      color="primary"
                    />
                  </TableCell>
                  <TableCell> Cette option permet d'activer ou de désactiver les notifications pour les administrateurs. Lorsqu'elle est activée, les administrateurs recevront des notifications pour de nouveaux commentaires. Si elle est désactivée, les administrateurs ne recevront pas ces notifications.</TableCell>
                </TableRow>
                <TableRow key="Virement Bancaire">
                  <TableCell>Approuver les commentaires automatiquement</TableCell>
                  <TableCell align="center">
                    <Switch
                      checked={preferences.bank}
                      onChange={handlePreferenceChange}
                      name="bank"
                      color="primary"
                    />
                  </TableCell>
                  <TableCell> Si cette option est activée, tous les commentaires laissés par les utilisateurs seront automatiquement approuvés et publiés sur le site sans nécessiter une intervention manuelle de l'administrateur. Cela permet d'accélérer le processus de publication des commentaires. </TableCell>
                </TableRow>
              </>
            )}
          </TableBody>
        </Table>
      </TableContainer>
    </Container>
  );
}
