import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import Checkbox from '@mui/material/Checkbox';
import Typography from '@mui/material/Typography';
import ListItemText from '@mui/material/ListItemText';
import { IColisColissimoItem } from '@/contexts/types/Shipping';


type Props = {
  row: IColisColissimoItem;
  selected: boolean;
  selectedShippingArea: IColisColissimoItem | null;
  onSelectRow: VoidFunction;
  onViewRow: VoidFunction;
};

export default function ColisColissimoTableRow({
  row,
  selected,
  onSelectRow,
  onViewRow,
}: Props) {
  const { id, trackingNumber, etiquetteCreatedAt, orderCreatedAt, country, shippingMethod } = row;

  return (
    <>
      <TableRow hover selected={selected} onClick={() => { onViewRow(); }}>
        <TableCell padding="checkbox">
          <Checkbox checked={selected} onClick={onSelectRow} />
        </TableCell>
        <TableCell sx={{ display: 'flex', alignItems: 'center' }}>
          <ListItemText
            disableTypography
            primary={
              <Typography variant="body2">
                {id}
              </Typography>
            }
          />
        </TableCell>
        <TableCell>{trackingNumber}</TableCell>
        <TableCell>{etiquetteCreatedAt.toLocaleDateString()}</TableCell>
        <TableCell>{orderCreatedAt.toLocaleDateString()}</TableCell>
        <TableCell>{country}</TableCell>
        <TableCell>{shippingMethod}</TableCell>
      </TableRow>
    </>
  );
}
