'use client';

import { useState, useCallback } from 'react';
import Card from '@mui/material/Card';
import Table from '@mui/material/Table';
import Button from '@mui/material/Button';
import Grid from '@mui/material/Grid';
import Container from '@mui/material/Container';
import TableBody from '@mui/material/TableBody';
import { useTheme } from '@mui/material/styles';
import TableContainer from '@mui/material/TableContainer';
import LocalizationProvider from '@/shared/locales/localization-provider';
import { paths } from '@/routes/paths';
import { TableHeadCustom } from '@/shared/components/table';
import { useRouter } from '@/hooks';
import { useBoolean } from '@/hooks';
import { colisColissimoList, shippingAreaList } from '@/shared/_mock/_shipping';
import Scrollbar from '@/shared/components/scrollbar';
import { useSnackbar } from '@/components/snackbar';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { useTable, emptyRows, TableNoData, TableSelectedAction, TablePaginationCustom, TableEmptyRows, } from '@/shared/components/table';
import { IColisColissimoItem } from '@/contexts/types/Shipping';
import ColisColissimoTableRow from './ColisColissimoTableRow';


const TABLE_HEAD = [
  { id: "id", label: "ID", width: 116 },
  { id: "trackingNumber", label: "Numéro de suivi", with: 100 },
  { id: "etiquetteCreatedAt", label: "Date création de l'étiquette", width: 250, align: "left" },
  { id: "orderCreatedAt", label: "Date création de la commande", width: 250, align: "left" },
  { id: "country", label: "Pays", width: 120 },
  { id: "shippingMethod", label: "Méthodes de livraison", width: 150 },
];



export default function ColisColissimoTableView() {
  const { enqueueSnackbar } = useSnackbar();

  const theme = useTheme();

  const settings = useSettingsContext();
  const router = useRouter();
  const table = useTable({ defaultOrderBy: 'id' });
  const confirm = useBoolean();
  const [tableData, setTableData] = useState<IColisColissimoItem[]>(colisColissimoList);


  const dataInPage = tableData.slice(
    table.page * table.rowsPerPage,
    table.page * table.rowsPerPage + table.rowsPerPage
  );

  const denseHeight = table.dense ? 56 : 56 + 20;


  const notFound = (!tableData.length) || !tableData.length;


  //----------------view details--------------

  const [selectedColis, setSelectedColis] = useState<IColisColissimoItem | null>(null);
  const handelSelectedColis = (colis: any) => {
    setSelectedColis(colis);
  };
  const handleViewRow = useCallback(
    (id: string) => {
      const colis = tableData.find((a) => a.id === id);
      handelSelectedColis(colis)
    },
    [tableData]
  );

  /////////////////////////////

  return (
    <>
      <LocalizationProvider >
        <Container maxWidth={settings.themeStretch ? false : 'lg'}>
          <Grid container alignItems="center" justifyContent="space-between">
            <CustomBreadcrumbs
              heading="Liste des colis"
              links={[
                { name: 'Dashboard', href: paths.dashboard.root, },
                { name: 'Livraison', href: paths.dashboard.shipping.general.root, },
                { name: "Colissimo", }
              ]}
              sx={{
                mb: { xs: 3, md: 5 },
              }}
            />
          </Grid>

          <Grid container justifyContent="flex-end" sx={{ marginBottom: '10px' }}>
            <Button variant="outlined" color='success'>Générer avec les colis sélectionnés</Button>
            <Button variant="outlined" color='success' sx={{ marginLeft: '5px' }}>Générer le bordereau de fin de période</Button>
          </Grid>

          <Card>
            <TableContainer sx={{ position: 'relative', overflow: 'auto' }}>
              <TableSelectedAction
                dense={table.dense}
                numSelected={table.selected.length}
                rowCount={tableData.length}
                onSelectAllRows={(checked) => {
                  table.onSelectAllRows(
                    checked,
                    tableData.map((row) => row.id)
                  );
                }}
              />

              <Scrollbar>
                <Table size={table.dense ? 'small' : 'medium'} sx={{ minWidth: 800 }}>
                  <TableHeadCustom
                    order={table.order}
                    orderBy={table.orderBy}
                    headLabel={TABLE_HEAD}
                    rowCount={tableData.length}
                    numSelected={table.selected.length}
                    onSort={table.onSort}
                    onSelectAllRows={(checked) =>
                      table.onSelectAllRows(
                        checked,
                        tableData.map((row) => row.id)
                      )
                    }
                  />
                  <TableBody>
                    {tableData
                      .slice(
                        table.page * table.rowsPerPage,
                        table.page * table.rowsPerPage + table.rowsPerPage
                      )
                      .map((row, index) => (
                        <ColisColissimoTableRow
                          key={row.id}
                          row={row}
                          selected={table.selected.includes(row.id)}
                          onSelectRow={() => table.onSelectRow(row.id)}
                          onViewRow={() => handleViewRow(row.id)}
                          selectedShippingArea={selectedColis}
                        />
                      ))}

                    <TableEmptyRows
                      height={denseHeight}
                      emptyRows={emptyRows(table.page, table.rowsPerPage, tableData.length)}
                    />

                    <TableNoData notFound={notFound} />
                  </TableBody>
                </Table>
              </Scrollbar>
            </TableContainer>

            <TablePaginationCustom
              count={tableData.length}
              page={table.page}
              rowsPerPage={table.rowsPerPage}
              onPageChange={table.onChangePage}
              onRowsPerPageChange={table.onChangeRowsPerPage}
              dense={table.dense}
              onChangeDense={table.onChangeDense}
            />
          </Card>
        </Container>
      </LocalizationProvider >
    </>
  );
}
