import Button from '@mui/material/Button';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import ListItemText from '@mui/material/ListItemText';
import DownloadIcon from '@mui/icons-material/Download';
import PrintIcon from '@mui/icons-material/Print';
import { useBoolean } from '@/hooks';
import Iconify from '@/shared/components/iconify';
import ConfirmDialog from '@/shared/components/confirm-dialog';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { IHistoricBordereauColissimoItem } from '@/contexts/types/Shipping';


type Props = {
  row: IHistoricBordereauColissimoItem;
  selected: boolean;
  selectedHistoricItem: IHistoricBordereauColissimoItem | null;
  onSelectRow: VoidFunction;
  onViewRow: VoidFunction;
};

export default function HistoricBordereauColissimoTableRow({
  row,
  selected,
}: Props) {
  const { id, colisNumber, orderIds, trackingNumber, createdAt } = row;
  const popover = usePopover();
  const confirm = useBoolean();

  return (
    <>
      <TableRow hover selected={selected}>
        <TableCell sx={{ display: 'flex', alignItems: 'center' }}>
          <ListItemText
            disableTypography
            primary={
              <Typography variant="body2">
                {id}
              </Typography>
            }
          />
        </TableCell>

        <TableCell>{colisNumber}</TableCell>
        <TableCell>{orderIds}</TableCell>
        <TableCell>{trackingNumber}</TableCell>
        <TableCell>{createdAt.toLocaleDateString()}</TableCell>

        <TableCell sx={{ display: 'flex', justifyContent: 'flex-end', alignItems: 'center', px: 1 }}>
          <IconButton color={popover.open ? 'inherit' : 'default'} onClick={popover.onOpen}>
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>


      </TableRow>

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        arrow="right-top"
        sx={{ width: 160 }}
      >
        <MenuItem
          onClick={() => {
            popover.onClose();
          }}
        >
          <Iconify icon=""></Iconify>
          <DownloadIcon /> Télécharger
        </MenuItem>
        <MenuItem
          onClick={() => {
            popover.onClose();
          }}
        >
          <PrintIcon /> Imprimer
        </MenuItem>
        <MenuItem
          sx={{ color: "error.main" }}
          onClick={() => {
            popover.onClose();
            confirm.onTrue();
          }}
        >
          <Iconify icon="solar:pen-bold" />Supprimer
        </MenuItem>
      </CustomPopover>

      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Delete"
        content="Are you sure want to delete?"
        action={
          <Button variant="contained" color="error" onClick={confirm.onFalse}>
            Delete
          </Button>
        }
      />
    </>
  );
}
