import { GridCellParams } from "@mui/x-data-grid";
import ListItemText from "@mui/material/ListItemText";
import { fTime, fDate } from "@/utils/format-time";
import Label from "@/shared/components/label";
import { Button } from "@mui/material";
import { IOrderColissimoStatus } from "@/shared/types/shipping";

// ----------------------------------------------------------------------

type ParamsProps = {
  params: GridCellParams;
};

export function RenderCellID({ params }: ParamsProps) {
  return <>{params.row.id}</>;
}

export function RenderCellCreatedAt({ params }: ParamsProps) {
  return (
    <ListItemText
      primary={fDate(params.row.createdAt)}
      secondary={fTime(params.row.createdAt)}
      primaryTypographyProps={{ typography: "body2", noWrap: true }}
      secondaryTypographyProps={{
        mt: 0.5,
        component: "span",
        typography: "caption",
      }}
    />
  );
}

export function RenderCellCustomer({ params }: ParamsProps) {
  return <>{params.row.customer}</>;
}

export function RenderCellAdress({ params }: ParamsProps) {
  return <>{params.row.adress}</>;
}

export function RenderCellCountry({ params }: ParamsProps) {
  return <>{params.row.country}</>;
}

export function RenderCellShippingMethod({ params }: ParamsProps) {
  return <>{params.row.shippingMethod}</>;
}

export function RenderCellStatus({ params }: ParamsProps) {
  return (
    <Label
      variant="soft"
      color={(params.row.status === IOrderColissimoStatus.Trach && "error") || (params.row.status === IOrderColissimoStatus.Canceled && "info") || (params.row.status === IOrderColissimoStatus.Completed && "success") || (params.row.status === IOrderColissimoStatus.Failed && "default") || (params.row.status === IOrderColissimoStatus.Pending && "secondary") || (params.row.status === IOrderColissimoStatus.PartiallyPaid && "primary") || (params.row.status === IOrderColissimoStatus.WaitingForPayment && "secondary") || (params.row.status === IOrderColissimoStatus.InProgress && "primary") || "default"}
    >
      {params.row.status}
    </Label>
  );
}

export function RenderCellEtiquette({ params }: ParamsProps) {
  return (
    <>
      <Button size="small" sx={{fontSize:'12px', color:'dimgray'}}>Générer l'étiquette Aller</Button>
    </>
  );
}
