'use client'

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import Switch from '@mui/material/Switch';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';
import Radio from '@mui/material/Radio';
import RadioGroup from '@mui/material/RadioGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import { paths } from '@/routes/paths';
import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs/custom-breadcrumbs';
import { useGetShippingRules, useUpdateShippingRules } from '@/shared/api/shipping';
import { useEffect, useState } from 'react';
import { ShippingDestinationType, ShippingRules } from '@/contexts/types/Shipping';

export default function DeliveryRulesView() {
    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const existingShippingRules = useGetShippingRules('1');
    const [shippingRules, setShippingRules] = useState<ShippingRules>();

    const NewDeliveryRulesSchema = Yup.object().shape({
        enableShippingCalculator: Yup.boolean(),
        hideShippingUntilAddress: Yup.boolean(),
        shippingDestination: Yup.string().oneOf([
            ShippingDestinationType.SHIPPING_ADRESS_DEFAULT,
            ShippingDestinationType.FACTURATION_ADRESS_DEFAULT,
            ShippingDestinationType.FACTURATION_ADRESS_FORCE,
        ]).required('Shipping destination is required'),
    });

    const methods = useForm({
        resolver: yupResolver(NewDeliveryRulesSchema),
    });

    const {
        handleSubmit,
        reset,
        formState: { isSubmitting },
    } = methods;

    useEffect(() => {
        if (existingShippingRules && existingShippingRules.shippingRulesData) {
            setShippingRules(existingShippingRules.shippingRulesData);
            reset({
                enableShippingCalculator: existingShippingRules.shippingRulesData.shippingCostCalculatorCartPage,
                hideShippingUntilAddress: existingShippingRules.shippingRulesData.hideShippingCostsUntilAnAddressIsProvided,
                shippingDestination: existingShippingRules.shippingRulesData.shippingDestinationType,
            });
        }
    }, [existingShippingRules, reset]);

    const onSubmit = handleSubmit(() => {
        try {
            if (shippingRules?.shippingDestinationType !== undefined) {
                console.log('data enable: ' + shippingRules?.shippingCostCalculatorCartPage)
                console.log('data hide: ' + shippingRules?.hideShippingCostsUntilAnAddressIsProvided)
                console.log('data destType: ' + shippingRules?.shippingDestinationType)
                useUpdateShippingRules('1', {
                    shippingCostCalculatorCartPage: shippingRules?.shippingCostCalculatorCartPage || false,
                    hideShippingCostsUntilAnAddressIsProvided: shippingRules?.hideShippingCostsUntilAnAddressIsProvided || false,
                    shippingDestinationType: shippingRules?.shippingDestinationType,
                });
                enqueueSnackbar('Configuration réussie!', { variant: 'success' });
            }
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Échec de la configuration.', { variant: 'error' });
        }
    });

    const renderBasic = (
        <>
            {mdUp && (
                <Grid md={4}>
                    <CustomBreadcrumbs
                        heading="Régles de livraison"
                        links={[
                            {
                                name: 'Dashboard',
                                href: paths.dashboard.root,
                            },
                            {
                                name: "Livraison",
                            }
                        ]}
                        sx={{
                            mb: { xs: 3, md: 5 },
                        }}
                    />
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Configuration des régles de livraison pour le calcul des frais d'expédition et la destination de l'expédition
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Nouvelle méthode de livraison" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormLabel id="demo-radio-buttons-group-label">Calculs</FormLabel>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch
                                name="active"
                                inputProps={{ 'aria-label': 'controlled' }}
                                checked={shippingRules?.shippingCostCalculatorCartPage || false}
                                onChange={(e) => {
                                    const newValue = e.target.checked;
                                    setShippingRules((prevRules) => ({
                                        ...prevRules,
                                        shippingCostCalculatorCartPage: newValue,
                                    }) as ShippingRules);
                                }}
                            />
                            <label>Activer le calculateur de frais d’expédition sur la page panier</label>
                        </div>
                        <div style={{ display: 'flex', alignItems: 'center' }}>
                            <Switch
                                name="active"
                                inputProps={{ 'aria-label': 'controlled' }}
                                checked={shippingRules?.hideShippingCostsUntilAnAddressIsProvided || false}
                                onChange={(e) => {
                                    const newValue = e.target.checked;
                                    setShippingRules((prevRules) => ({
                                        ...prevRules,
                                        hideShippingCostsUntilAnAddressIsProvided: newValue,
                                    }) as ShippingRules);
                                }}
                            />
                            <label>Masquer les frais d’expédition jusqu’à ce qu’une adresse soit renseignée</label>
                        </div>
                        <FormControl>
                            <FormLabel id="shipping-destination-label">Destination de l'expédition</FormLabel>
                            <RadioGroup
                                aria-labelledby="shipping-destination-label"
                                name="shipping-destination"
                                value={shippingRules?.shippingDestinationType || ''}
                                onChange={(event) => {
                                    const selectedValue = event.target.value;
                                    setShippingRules((prevRules) => ({
                                        ...prevRules,
                                        shippingDestinationType: selectedValue,
                                    }) as ShippingRules);
                                }}
                            >
                                <FormControlLabel
                                    value={ShippingDestinationType.SHIPPING_ADRESS_DEFAULT}
                                    control={<Radio />}
                                    label="Par défaut à l’adresse de livraison client"
                                />
                                <FormControlLabel
                                    value={ShippingDestinationType.FACTURATION_ADRESS_DEFAULT}
                                    control={<Radio />}
                                    label="Par défaut à l’adresse de facturation client"
                                />
                                <FormControlLabel
                                    value={ShippingDestinationType.FACTURATION_ADRESS_FORCE}
                                    control={<Radio />}
                                    label="Forcer la livraison à l’adresse de facturation client"
                                />
                            </RadioGroup>
                        </FormControl>
                    </Stack>
                </Card>
            </Grid>
        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >
                    Enregistrer
                </LoadingButton>
            </Grid>
        </>
    );

    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderBasic}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
