import Button from '@mui/material/Button';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import ListItemText from '@mui/material/ListItemText';
import { useBoolean } from '@/hooks';
import Iconify from '@/shared/components/iconify';
import ConfirmDialog from '@/shared/components/confirm-dialog';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { IShippingAreaItem } from '@/contexts/types/Shipping';


type Props = {
  row: IShippingAreaItem;
  selected: boolean;
  selectedShippingArea: IShippingAreaItem | null;
  onSelectRow: VoidFunction;
  onViewRow: VoidFunction;
  onEditRow: VoidFunction;
  onDeleteRow: VoidFunction;
};

export default function ShippingAreaTableRow({
  row,
  selected,
  onSelectRow,
  onViewRow,
  onEditRow,
  onDeleteRow,
}: Props) {
  const { name, region, shippingMethodList } = row;
  const confirm = useBoolean();
  const popover = usePopover();
  const openDetails = useBoolean();

  return (
    <>
      <TableRow hover selected={selected} onClick={() => { onViewRow(); }}>
        <TableCell sx={{ display: 'flex', alignItems: 'center', width: '290px' }}>
          <ListItemText
            disableTypography
            primary={
              <Typography variant="body2">
                {name}
              </Typography>
            }
          />
        </TableCell>

        <TableCell sx={{ width: '340px' }} >
          {region.map((item, index) => (<Button variant="outlined" size="small" key={index} sx={{ margin: '2px' }}>{item}</Button>))}
        </TableCell>

        <TableCell sx={{width:'400px'}}>
          {shippingMethodList.map((item, index) => (<Button variant="outlined" size="small" key={index} sx={{ margin: '2px' }}>{item.type}</Button>))}
        </TableCell>

        <TableCell sx={{ display: 'flex', justifyContent: 'flex-end', alignItems: 'center', px: 1 }}>
          <IconButton color={popover.open ? 'inherit' : 'default'} onClick={popover.onOpen}>
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>

      </TableRow>

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        arrow="right-top"
        sx={{ width: 160 }}
      >

        <MenuItem
          onClick={() => {
            onEditRow();
            popover.onClose();
          }}
          style={{ color: "green" }}
        >
          <Iconify icon="solar:pen-bold" />
          Edit
        </MenuItem>
        <MenuItem
          onClick={() => {
            confirm.onTrue();
            popover.onClose();
          }}
          sx={{ color: 'error.main' }}
        >
          <Iconify icon="solar:trash-bin-trash-bold" />
          Delete
        </MenuItem>

      </CustomPopover>


      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Delete"
        content="Are you sure want to delete?"
        action={
          <Button variant="contained" color="error" onClick={onDeleteRow}>
            Delete
          </Button>
        }
      />
    </>
  );
}
