"use client"

import { useState } from 'react';
import Chip from '@mui/material/Chip';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import { AutocompleteChangeReason } from '@mui/material/Autocomplete';
import { useResponsive } from '@/hooks/use-responsive';
import Box from '@mui/material/Box';
import InputAdornment from '@mui/material/InputAdornment';
import {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import { RequiresFreeShipping } from '@/contexts/types/Shipping'
import Checkbox from '@mui/material/Checkbox';


export default function DetailsFreeShipping() {
    const requiresFreeShipping = Object.values(RequiresFreeShipping);

    const mdUp = useResponsive('up', 'md');
    const [checked, setChecked] = useState(true);

    const handleChangeRule = (event: React.ChangeEvent<HTMLInputElement>) => {
        setChecked(event.target.checked);

    };

    const [selectedRequis, setSelectedRequis] = useState<string | null>(null);

    const handleChangeRequis = (
        event: React.SyntheticEvent,
        value: string | string[],
        reason: AutocompleteChangeReason
    ) => {
        const newValue = Array.isArray(value) ? value[0] : value;
        setSelectedRequis(newValue);
    };


    const renderRequisComponents = (
        <>
            <RHFTextField
                name="minimumOrderAmount"
                label="Montant minimum de commande"
                placeholder="0.00"
                type="number"
                InputLabelProps={{ shrink: true }}
                InputProps={{
                    startAdornment: (
                        <InputAdornment position="start">
                            <Box component="span" sx={{ color: 'text.disabled' }}>
                                €
                            </Box>
                        </InputAdornment>
                    ),
                }}
            />
            <Grid container alignItems="center" spacing={1}>
                <Grid>
                    <Checkbox
                        name='applyMinOrderRuleBeforePromoCodeDiscount'
                        checked={checked}
                        onChange={handleChangeRule}
                        color='success'
                        inputProps={{ 'aria-label': 'primary checkbox' }}
                    />
                </Grid>
                <Grid>
                    <Typography>Appliquer la règle de commande minimale avant la remise avec code promo</Typography>
                </Grid>
            </Grid>
        </>
    );


    const renderDetails = () => {
        switch (true) {
            case selectedRequis == 'Aucun prérequis':
                return null;
            case selectedRequis == 'Un code promo d’expédition gratuite valide':
                return null;
            case selectedRequis == 'Montant minimum de commande':
                return <>{renderRequisComponents}</>;
            case selectedRequis == 'Montant minimum de commande ou un code promo':
                return <>{renderRequisComponents}</>;
            case selectedRequis == 'Montant minimum de commande et un code promo':
                return <>{renderRequisComponents}</>;
            default:
                return null;
        }
    };

    return (
        <>
            {mdUp && (
                <Grid md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Détails
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Saisissez les informations du méthode de livraison de type Livraison gratuite
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Détails" />}
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <RHFAutocomplete
                            name="requis"
                            label="La livraison gratuite requiert"
                            placeholder="+ La livraison gratuite requiert"
                            disableClearable
                            options={requiresFreeShipping}
                            defaultValue={requiresFreeShipping[0]}
                            onChange={handleChangeRequis}
                            getOptionLabel={(option) => option}
                            renderOption={(props, option) => (
                                <li {...props} key={option}>
                                    {option}
                                </li>
                            )}
                            renderTags={(selected, getTagProps) =>
                                selected.map((option, index) => (
                                    <Chip
                                        {...getTagProps({ index })}
                                        key={option}
                                        label={option}
                                        size="small"
                                        color="info"
                                        variant="soft"
                                    />
                                ))
                            }
                        />
                        <>{renderDetails()}</>
                    </Stack>
                </Card>
            </Grid>
        </>
    );
}
