'use client'

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, { RHFAutocomplete, RHFTextField } from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';
import FormLabel from '@mui/material/FormLabel';
import { Chip } from '@mui/material';


const INSURANCE_OPTIONS = [
    { value: "sans_assurance", label: "Sans assurance" },
    { value: "assurance_complémentaire_N1", label: "Assurance complémentaire N1" },
    { value: "assurance_complémentaire_N2", label: "Assurance complémentaire N2" },
    { value: "assurance_complémentaire_N3", label: "Assurance complémentaire N3" },
    { value: "assurance_complémentaire_N4", label: "Assurance complémentaire N4" },
    { value: "assurance_complémentaire_N5", label: "Assurance complémentaire N5" },
];

export default function ConfigCompteModialRelay() {

    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const ConfigurationSchema = Yup.object().shape({
        enseigneCode: Yup.string().required('Ce champ est requis'),
        markKey: Yup.string().required('Ce champ est requis'),
        privateKey: Yup.string().required('Ce champ est requis'),
        insurance: Yup.array().min(1, 'Veuillez sélectionner au moins une assurance'),
        numberRelayPoints: Yup.number().typeError('Veuillez entrer un nombre').required('Ce champ est requis').positive('Le nombre doit être positif').integer('Le nombre doit être un entier'),
    });

    const methods = useForm({
        resolver: yupResolver(ConfigurationSchema),
    });

    const {
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            enqueueSnackbar('Success config!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed config.', { variant: 'error' });
        }
    });

    const renderBasic = (
        <>
            {mdUp && (
                <Grid md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Compte Mondial Relay - InPost
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Configuration du compte Mondial Relay, la livraison et les points relais
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Nouvelle méthode de livraison" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormLabel>Configuration du compte Mondial Relay - InPost</FormLabel>
                        <RHFTextField name="enseigneCode" label="Enseigne de production ou Code Enseigne pour l’offre START" />
                        <RHFTextField name="markKey" label="Code Marque" />
                        <RHFTextField name="privateKey" label="Clé privée" />
                    </Stack>
                </Card>
                <Card sx={{mt: 2}}>
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormLabel>Configuration de la livraison Mondial Relay - InPost</FormLabel>
                        <RHFAutocomplete
                            name="insurance"
                            label="Assurance"
                            placeholder="+ Assurance"
                            defaultValue={INSURANCE_OPTIONS[0].label}
                            freeSolo
                            disableCloseOnSelect
                            options={INSURANCE_OPTIONS.map(country => country.label)}
                            getOptionLabel={(option) => option}
                            renderOption={(props, option) => (
                                <li {...props} key={option}>
                                    {option}
                                </li>
                            )}
                            renderTags={(selected, getTagProps) =>
                                selected.map((option, index) => (
                                    <Chip
                                        {...getTagProps({ index })}
                                        key={option}
                                        label={option}
                                        size="small"
                                        color="success"
                                        variant="soft"
                                    />
                                ))
                            }
                        />
                    </Stack>
                </Card>
                <Card sx={{mt: 2}}>
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormLabel>Configuration de la recherche de points relais et Lockers</FormLabel>
                        <RHFTextField name="numberRelayPoints" label="Nombre de Point Relais® et lockers à renvoyer" type="number" />
                    </Stack>
                </Card>
            </Grid>
        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );

    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderBasic}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
