"use client";

import isEqual from "lodash/isEqual";
import { useState, useEffect, useCallback } from "react";
import Stack from "@mui/material/Stack";
import Card from "@mui/material/Card";
import Box from "@mui/material/Box";
import {
  DataGrid,
  GridColDef,
  GridToolbarContainer,
  GridRowSelectionModel,
  GridToolbarQuickFilter,
  GridToolbarColumnsButton,
  GridColumnVisibilityModel,
} from "@mui/x-data-grid";
import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";
import { Button } from '@mui/material';
import { useBoolean } from "@/hooks/use-boolean";
import { useSnackbar } from "@/shared/components/snackbar";
import EmptyContent from "@/shared/components/empty-content";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import { SelectChangeEvent } from "@mui/material/Select";
import {
  RenderCellOrderNumber,
  RenderCellStatus,
  RenderCellShippingMode,
  RenderCellDateCreation,
  RenderCellExpedition,
  RenderCellAdress,
  RenderCellWeight,
  RenderCellExpeditionNumber,
} from "./MondialRelayOrder-table-row";
import { IOrderMondialRelayItem, IOrderMondialRelayStatus, IOrderMondialRelayTableFilters, IOrderMondialRelayTableFilterValue, MondialRelayMode } from "@/contexts/types/Shipping";
import { orderMondialRelayList } from "@/shared/_mock/_shipping";
import OrderMondialRelayTableToolbar from "./MondialRelayOrder-table-toolbar";
import OrderMondialRelayTableFiltersResult from "./MondialRelayOrder-table-filters-result";

// ----------------------------------------------------------------------


const ShippingMode_OPTIONS = [
  { value: MondialRelayMode.MED, label: "24R/MED - livraison en Point Relais®" },
  { value: MondialRelayMode.APM, label: "24R/APM - livraison en Lockers" },
  { value: MondialRelayMode.HOM, label: "HOM - livraison domicile HOME" },
  { value: MondialRelayMode.PRL, label: "(obsolète) 24R - livraison en Point Relais® et lockers" },
  { value: MondialRelayMode.HOC, label: "HOC - livraison HOC (indisponible avec l’offre Start)" },
  { value: MondialRelayMode.HOD, label: "HOD - livraison HOD (indisponible avec l’offre Start)" },
  { value: MondialRelayMode.OMR, label: "Livraison hors Mondial Relay - InPost" }
];

const Status_OPTIONS = [
  { value: IOrderMondialRelayStatus.WaitingForPayment, label: "Attente paiement" },
  { value: IOrderMondialRelayStatus.Pending, label: "En attente" },
  { value: IOrderMondialRelayStatus.InProgress, label: "En cours" },
];

const defaultFilters: IOrderMondialRelayTableFilters = {
  shippingMode: [],
  status: [],
  dateCreation: null,
};

const HIDE_COLUMNS = {
  category: false,
};

const HIDE_COLUMNS_TOGGLABLE = ["category", "actions"];


type CustomEditRowModelProps = {
  weight: number;
};

// ----------------------------------------------------------------------

export default function MondialRelayOrderListView() {
  const { enqueueSnackbar } = useSnackbar();

  const confirmRows = useBoolean();

  const router = useRouter();

  const settings = useSettingsContext();

  const [orders, setOrders] = useState<IOrderMondialRelayItem[]>(orderMondialRelayList);

  const [tableData, setTableData] = useState<IOrderMondialRelayItem[]>(orderMondialRelayList);

  const [filters, setFilters] = useState(defaultFilters);

  const [selectedRowIds, setSelectedRowIds] = useState<GridRowSelectionModel>(
    []
  );

  const [columnVisibilityModel, setColumnVisibilityModel] =
    useState<GridColumnVisibilityModel>(HIDE_COLUMNS);

  useEffect(() => {
    if (orders.length) {
      setTableData(orders);
    }
    console.log(orderMondialRelayList)
    console.log(orders)
    console.log(tableData)
    console.log(dataFiltered)
  }, [orders]);

  const dataFiltered = applyFilter({
    inputData: tableData,
    filters,
  });

  const canReset = !isEqual(defaultFilters, filters);

  const handleFilters = useCallback(
    (name: string, value: IOrderMondialRelayTableFilterValue) => {
      setFilters((prevState) => ({
        ...prevState,
        [name]: value,
      }));
    },
    []
  );

  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);

  const columns: GridColDef[] = [
    {
      field: "id",
      headerName: "Commande",
      flex: 1,
      width: 100,
      filterable: true,
      hideable: false,
      renderCell: (params) => <RenderCellOrderNumber params={params} />,
    },
    {
      field: "status",
      headerName: "Status",
      width: 130,
      hideable: false,
      renderCell: (params) => <RenderCellStatus params={params} />,
    },
    {
      field: "shippingMode",
      headerName: "Mode d'expédition",
      minWidth: 140,
      renderCell: (params) => <RenderCellShippingMode params={params} />,
    },
    {
      field: "dateCreation",
      headerName: "Date",
      minWidth: 160,
      renderCell: (params) => <RenderCellDateCreation params={params} />,
    },
    {
      field: "expedition",
      headerName: "Expédition",
      minWidth: 100,
      renderCell: (params) => <RenderCellExpedition params={params} />,
    },
    {
      field: "address",
      headerName: "Livrée à",
      minWidth: 170,
      renderCell: (params) => <RenderCellAdress params={params} />,
    },
    {
      field: "weight",
      headerName: "Poids (Kg)",
      minWidth: 170,
      editable: true,
      headerAlign: "left",
      align: "left",
      type: 'number',
      renderCell: (params) => <RenderCellWeight params={params} />,
    },
    {
      field: "expeditionNumber",
      headerName: "Numéro d'expédition",
      minWidth: 170,
      renderCell: (params) => <RenderCellExpeditionNumber params={params} />,
    },
  ];

  const getTogglableColumns = () =>
    columns
      .filter((column) => !HIDE_COLUMNS_TOGGLABLE.includes(column.field))
      .map((column) => column.field);

  const [selectedAction, setSelectedAction] = useState("");

  const handleActionChange = (event: SelectChangeEvent<string>) => {
    setSelectedAction(event.target.value);
  };

  const handleButtonClick = () => {
    // Logique à exécuter lorsqu'on clique sur le bouton
    console.log("Bouton cliqué !");
  };
  const [anchorEl, setAnchorEl] = useState<HTMLElement | null>(null);

  const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  return (
    <>
      <CustomBreadcrumbs
        heading="Liste des commandes"
        links={[
          { name: 'Dashboard', href: paths.dashboard.root, },
          { name: 'Livraison', href: paths.dashboard.shipping.general.root, },
          { name: "Mondial Relay - InPost" },
        ]}
        sx={{
          mb: {
            xs: 3,
            md: 5,
          },
        }}
      />
      <Box sx={{ display: 'flex', flexDirection: 'column', alignItems: 'flex-end' }}>
        <Button variant="outlined" color="primary" size="small" sx={{ mb: 1, width: 280 }}>CRÉATION DES EXPÉDITIONS EN MASSE</Button>
      </Box>
      <Card>
        <Box
          sx={{
            width: "100%",
            flexGrow: { md: 1 },
            display: { md: "flex" },
            flexDirection: { md: "column" },
          }}
        >
          <DataGrid
            checkboxSelection
            disableRowSelectionOnClick
            rows={dataFiltered}
            columns={columns}
            getRowHeight={() => "auto"}
            pageSizeOptions={[5, 10, 25]}
            initialState={{
              pagination: {
                paginationModel: { pageSize: 10 },
              },
            }}
            onRowSelectionModelChange={(newSelectionModel) => {
              setSelectedRowIds(newSelectionModel);
            }}
            columnVisibilityModel={columnVisibilityModel}
            onColumnVisibilityModelChange={(newModel) =>
              setColumnVisibilityModel(newModel)
            }
            slots={{
              toolbar: () => (
                <>
                  <GridToolbarContainer>
                    <OrderMondialRelayTableToolbar
                      filters={filters}
                      onFilters={handleFilters}
                      shippingModeOptions={ShippingMode_OPTIONS}
                      statusOptions={Status_OPTIONS}
                    />

                    <GridToolbarQuickFilter />

                    <Stack
                      spacing={1}
                      flexGrow={1}
                      direction="row"
                      alignItems="center"
                      justifyContent="flex-end"
                    >

                      <GridToolbarColumnsButton />
                    </Stack>
                  </GridToolbarContainer>

                  {canReset && (
                    <OrderMondialRelayTableFiltersResult
                      filters={filters}
                      onFilters={handleFilters}
                      onResetFilters={handleResetFilters}
                      results={dataFiltered.length}
                      sx={{ p: 2.5, pt: 0 }}
                    />
                  )}
                </>
              ),
              noRowsOverlay: () => <EmptyContent title="No Data" />,
              noResultsOverlay: () => <EmptyContent title="No results found" />,
            }}
            slotProps={{
              columnsPanel: {
                getTogglableColumns,
              },
            }}
          />
        </Box>
      </Card>
    </>
  );
}

// ----------------------------------------------------------------------

function applyFilter({
  inputData,
  filters,
}: {
  inputData: IOrderMondialRelayItem[];
  filters: IOrderMondialRelayTableFilters;
}) {
  const { shippingMode, status, dateCreation } = filters;

  if (shippingMode.length) {
    inputData = inputData.filter((order) =>
      shippingMode.includes(order.shippingMode)
    );
  }

  if (status.length) {
    inputData = inputData.filter((order) =>
      status.includes(order.status)
    );
  }

  if (dateCreation) {
    inputData = inputData.filter((order) => order.dateCreation === dateCreation);
  }

  return inputData;
}
