"use client"

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Chip from '@mui/material/Chip';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';
import { Box, FormControl, InputLabel, MenuItem, Select, Typography } from '@mui/material';


const countriesMondialRelay = [
    { label: "France", value: "FR" },
    { label: "Belgique", value: "BE" },
    { label: "Luxembourg", value: "LU" },
    { label: "Espagne", value: "ES" },
    { label: "Portugal", value: "PT" },
    { label: "Allemagne", value: "DE" },
    { label: "Italie", value: "IT" },
    { label: "Pays-Bas", value: "NL" },
    { label: "Royaume-Uni", value: "GB" },
    { label: "Irlande", value: "IE" },
    { label: "Autriche", value: "AT" },
    { label: "Suisse", value: "CH" },
    { label: "Suède", value: "SE" },
    { label: "Danemark", value: "DK" },
    { label: "Finlande", value: "FI" },
    { label: "Norvège", value: "NO" },
    { label: "Guyane", value: "GF" },
    { label: "Saint Martin", value: "MF" },
    { label: "Martinique", value: "MQ" },
    { label: "Mayotte", value: "YT" },
    { label: "Monaco", value: "MC" },
    { label: "Hongrie", value: "HU" },
    { label: "Slovaquie", value: "SK" },
    { label: "République Tchèque", value: "CZ" },
    { label: "Liechtenstein", value: "LI" },
    { label: "Pologne", value: "PL" },
    { label: "Roumanie", value: "RO" },
    { label: "Grèce", value: "GR" },
];

const deviseMondialRelay = [
    { label: "Euro", value: "EUR" },
];

const languagesMondialRelay = [
    { label: "Français", value: "FR" },
    { label: "Anglais", value: "EN" },
    { label: "Espagnol", value: "ES" },
    { label: "Néerlandais", value: "NL" },
];

export default function ConfigVendorMRView() {

    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const NewShippingMethodSchema = Yup.object().shape({
        expediteur: Yup.string().required('Ce champ est requis'),
        adress: Yup.string().required('Ce champ est requis'),
        codePostal: Yup.string().required('Ce champ est requis'),
        ville: Yup.string().required('Ce champ est requis'),
        country: Yup.string().required('Ce champ est requis'),
        phone1: Yup.string().required('Ce champ est requis'),
        phone2: Yup.string(),
        mail: Yup.string().email('Veuillez saisir une adresse e-mail valide').required('Ce champ est requis'),
    });

    const methods = useForm({
        resolver: yupResolver(NewShippingMethodSchema),
    });

    const {
        reset,
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            reset();
            enqueueSnackbar('Config success!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed to configure vendeur.', { variant: 'error' });
        }
    });

    const renderDetails = (
        <>
            <Grid xs={12} md={12}>
                <Typography variant="h6" sx={{ mb: 0.5 }}>
                    Coordonnées du vendeur
                </Typography>
            </Grid>
            <Grid xs={12} md={12}>
                <Card>
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Box display="flex" flexDirection="column" alignItems="flex-start">
                            <Box display="flex" width="100%" marginBottom={2}>
                                <Box flex={1} marginRight={2}>
                                    <RHFTextField name="Expe_Ad1" label="Nom de l'expéditeur" />
                                </Box>
                                <Box flex={1} marginLeft={2}>
                                    <RHFTextField name="Expe_Ad3" label="Rue" />
                                </Box>
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <Box flex={1} marginRight={2}>
                                    <RHFTextField name="Expe_Ad2" label="Adresse 1 (Complémentaire)" />
                                </Box>
                                <Box flex={1} marginLeft={2}>
                                    <RHFTextField name="Expe_Ad4" label="Adresse 2 (Complémentaire)" />
                                </Box>
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <Box sx={{ width: '15%' }}>
                                    <RHFTextField name="Expe_CP" label="Code Postal" sx={{ width: '100%' }} />
                                </Box>
                                <Box flex={1} marginLeft={2} sx={{ width: '50%' }}>
                                    <RHFTextField name="Expe_Ville" label="Ville" sx={{ width: '100%' }} />
                                </Box>
                                <Box marginLeft={2} sx={{ width: '25%' }}>
                                    <FormControl sx={{ width: '100%' }}>
                                        <InputLabel id="country-label">Pays</InputLabel>
                                        <Select
                                            labelId="country-label"
                                            name="country"
                                            label="Country"
                                            defaultValue="FR"
                                        >
                                            {countriesMondialRelay.map((country) => (
                                                <MenuItem key={country.value} value={country.value}>
                                                    {country.label}
                                                </MenuItem>
                                            ))}
                                        </Select>
                                    </FormControl>
                                </Box>
                                <Box flex={1} marginLeft={2} sx={{ width: "10%" }}>
                                    <FormControl sx={{ width: '100%' }}>
                                        <InputLabel id="devise-label">Devise</InputLabel>
                                        <Select
                                            labelId="devise-label"
                                            name="devise"
                                            label="Devise"
                                            defaultValue="EUR"
                                        >
                                            {deviseMondialRelay.map((devise) => (
                                                <MenuItem key={devise.value} value={devise.value}>
                                                    {devise.label}
                                                </MenuItem>
                                            ))}
                                        </Select>
                                    </FormControl>
                                </Box>
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <Box flex={1} marginRight={2}>
                                    <RHFTextField name="Expe_Tel1" label="Téléphone 1" type='tel' />
                                </Box>
                                <Box flex={1} marginLeft={2}>
                                    <RHFTextField name="Expe_Tel2" label="Téléphone 2" type='tel' />
                                </Box>
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <Box flex={1} marginRight={2} sx={{ width: "60%" }}>
                                    <RHFTextField name="Expe_Mail" label="Adresse E-mail" type='email' />
                                </Box>
                                <Box flex={1} marginLeft={2} sx={{ width: "40%" }}>
                                    <FormControl sx={{ width: '100%' }}>
                                        <InputLabel id="langage-label">Langue de l'Expéditeur</InputLabel>
                                        <Select
                                            labelId="langage-label"
                                            name="Expe_Langage"
                                            label="Langue de l'Expéditeur"
                                            defaultValue="FR"
                                        >
                                            {languagesMondialRelay.map((langage) => (
                                                <MenuItem key={langage.value} value={langage.value}>
                                                    {langage.label}
                                                </MenuItem>
                                            ))}
                                        </Select>
                                    </FormControl>
                                </Box>
                            </Box>
                        </Box>
                    </Stack>
                </Card>
            </Grid>
        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );


    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderDetails}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
