import { useFormContext } from "react-hook-form";

import Stack from "@mui/material/Stack";
import Button from "@mui/material/Button";
import Divider from "@mui/material/Divider";
import IconButton from "@mui/material/IconButton";
import Typography from "@mui/material/Typography";

import { useBoolean } from "@/hooks/use-boolean";
import { useResponsive } from "@/hooks/use-responsive";

import { _addressBooks } from "@/shared/_mock";

import Iconify from "@/components/iconify";

import { AddressListDialog } from "./address";
import { useCallback } from "react";
import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";

// ----------------------------------------------------------------------

export default function OrderNewEditAddress() {
  const {
    watch,
    setValue,
    formState: { errors },
  } = useFormContext();
  const router = useRouter();
  const mdUp = useResponsive("up", "md");

  const values = watch();

  const { invoiceFrom, invoiceTo } = values;

  const from = useBoolean();

  const to = useBoolean();

  const handelAddSupplier = useCallback(() => {
    router.push(paths.dashboard.supplier.new);
  }, [router]);

  return (
    <>
      <Stack
        spacing={{ xs: 3, md: 5 }}
        direction={{ xs: "column", md: "row" }}
        divider={
          <Divider
            flexItem
            orientation={mdUp ? "vertical" : "horizontal"}
            sx={{ borderStyle: "dashed" }}
          />
        }
        sx={{ p: 3 }}
      >
        <Stack sx={{ width: 1 }}>
          <Stack direction="row" alignItems="center" sx={{ mb: 1 }}>
            <Typography
              variant="h6"
              sx={{ color: "text.disabled", flexGrow: 1 }}
            >
              Fournisseur:
            </Typography>

            <IconButton onClick={from.onTrue}>
              <Iconify icon="solar:pen-bold" />
            </IconButton>
          </Stack>

          <Stack spacing={1}>
            <Typography variant="subtitle2" sx={{ color: "primary.main" }}>
              {invoiceFrom.supplier}
            </Typography>
            <Typography variant="body2">{invoiceFrom.fullAddress}</Typography>
            <Typography variant="body2"> {invoiceFrom.phoneNumber}</Typography>
            <Typography variant="body2">
              {" "}
              Secteur: {invoiceFrom.sector}
            </Typography>
            <Typography variant="body2"> Zone :{invoiceFrom.zone}</Typography>
          </Stack>
        </Stack>

        <Stack sx={{ width: 1 }}>
          <Stack direction="row" alignItems="center" sx={{ mb: 1 }}>
            <Typography
              variant="h6"
              sx={{ color: "text.disabled", flexGrow: 1 }}
            >
              Chauffeur
            </Typography>

            <IconButton onClick={to.onTrue}>
              <Iconify
                icon={invoiceTo ? "solar:pen-bold" : "mingcute:add-line"}
              />
            </IconButton>
          </Stack>

          {invoiceTo ? (
            <Stack spacing={1}>
              <Typography variant="subtitle2">{invoiceTo.name}</Typography>
              <Typography variant="body2"> {invoiceTo.phoneNumber}</Typography>
            </Stack>
          ) : (
            <Typography typography="caption" sx={{ color: "error.main" }}>
              {(errors.invoiceTo as any)?.message}
            </Typography>
          )}
        </Stack>
      </Stack>

      <AddressListDialog
        title="Fournisseurs"
        open={from.value}
        onClose={from.onFalse}
        selected={(selectedId: string) => invoiceFrom?.id === selectedId}
        onSelect={(address) => setValue("invoiceFrom", address)}
        list={_addressBooks}
        action={
          <Button
            size="small"
            startIcon={<Iconify icon="mingcute:add-line" />}
            sx={{ alignSelf: "flex-end" }}
            onClick={handelAddSupplier}
          >
            New
          </Button>
        }
      />

      <AddressListDialog
        title="Chauffeurs"
        open={to.value}
        onClose={to.onFalse}
        selected={(selectedId: string) => invoiceTo?.id === selectedId}
        onSelect={(address) => setValue("invoiceTo", address)}
        list={_addressBooks}
        action={
          <Button
            size="small"
            startIcon={<Iconify icon="mingcute:add-line" />}
            sx={{ alignSelf: "flex-end" }}
            onClick={handelAddSupplier} // don't forget ==> after creating the interface add the function
          >
            New
          </Button>
        }
      />
    </>
  );
}
