import React, { useState, useEffect } from 'react';
import { Button, Dialog, DialogActions, DialogContent, DialogTitle, FormControlLabel, TextField } from '@mui/material';
import Autocomplete from '@mui/material/Autocomplete';
import Checkbox from '@mui/material/Checkbox';
import { permission } from '@/shared/_mock';

type Props = {
  open: boolean;
  handleClose: () => void;
};

const DeletePermissionDialog: React.FC<Props> = ({ open, handleClose }) => {
  const [selectedPermissions, setSelectedPermissions] = useState<string[]>([]);
  useEffect(() => {
    if (!open) {
      setSelectedPermissions([]);
    }
  }, [open]);

  const handlePermissionChange = (event: React.ChangeEvent<HTMLInputElement>, checked: boolean) => {
    const permissionName = event.target.value;
    if (checked) {
      setSelectedPermissions((prevSelected) => [...prevSelected, permissionName]);
    } else {
      setSelectedPermissions((prevSelected) => prevSelected.filter((name) => name !== permissionName));
    }
  };

  return (
    <Dialog
      open={open}
      onClose={handleClose}
      PaperProps={{
        component: 'form',
        onSubmit: (event: React.FormEvent<HTMLFormElement>) => {
          event.preventDefault();
          handleClose();
        },
      }}
    >
      <DialogTitle>Selectionner les permissions</DialogTitle>
      <DialogContent>
        <Autocomplete
          id="combo-box-demo"
          options={permission}
          multiple
          disableCloseOnSelect
          value={selectedPermissions}
          onChange={(_event, newValue) => setSelectedPermissions(newValue)}
          sx={{ width: 300, marginTop: 2 }}
          renderOption={(props, option) => (
            <li {...props}>
              <FormControlLabel
                control={
                  <Checkbox
                    checked={selectedPermissions.includes(option)}
                    onChange={handlePermissionChange}
                    value={option}
                  />
                }
                label={option}
              />
            </li>
          )}
          renderInput={(params) => <TextField {...params} label="Permissions" />}
        />
      </DialogContent>
      <DialogActions>
        <Button onClick={handleClose}>Supprimer</Button>
        <Button onClick={handleClose}>Annuler</Button>
      </DialogActions>
    </Dialog>
  );
};

export default DeletePermissionDialog;
