import React from "react";
import {
  Button,
  Dialog,
  DialogActions,
  DialogContent,
  InputLabel,
  FormControl,
  DialogTitle,
  MenuItem,
  Select,
} from "@mui/material";

type Props = {
  open: boolean;
  handleClose: () => void;
  roleOptions: string[];
};

const DeleteRoleDialog: React.FC<Props> = ({
  open,
  handleClose,
  roleOptions,
}) => {
  return (
    <Dialog
      open={open}
      onClose={handleClose}
      PaperProps={{
        component: "form",
        onSubmit: (event: React.FormEvent<HTMLFormElement>) => {
          event.preventDefault();
          handleClose();
        },
      }}
    >
      <DialogTitle>Selectionner un role</DialogTitle>
      <DialogContent>
        <FormControl sx={{ width: "100%" , mt: 2}}>
          <InputLabel id="select-label">role</InputLabel>
          <Select
            label="role"
            labelId="select-label"
            MenuProps={{
              PaperProps: {
                sx: { maxHeight: 540 },
              },
            }}
            sx={{ width: "100%" }}
          >
            {roleOptions.map((option) => (
              <MenuItem key={option} value={option}>
                {option}
              </MenuItem>
            ))}
          </Select>
        </FormControl>
      </DialogContent>
      <DialogActions>
        <Button onClick={handleClose}>Supprimer</Button>
        <Button onClick={handleClose}>Annuler</Button>
      </DialogActions>
    </Dialog>
  );
};

export default DeleteRoleDialog;
