import MenuItem from "@mui/material/MenuItem";
import {
  Button,
  Card,
  CardContent,
  CardHeader,
  Checkbox,
  FormControl,
  Grid,
  InputLabel,
  List,
  ListItem,
  ListItemText,
  Select,
} from "@mui/material";
import { _roles, permission } from "@/shared/_mock";
import DeleteIcon from "@mui/icons-material/Delete";
import Add from "@mui/icons-material/Add";
import DriveFileRenameOutlineIcon from "@mui/icons-material/DriveFileRenameOutline";
import React, { useState } from "react";
import AddRoleDialog from "./popUp/AddRoleDialog";
import DeletePermissionDialog from "./popUp/DeletePermissionDialog";
import AddPermissionDialog from "./popUp/AddPermissionDialog";
import RenameRoleDialog from "./popUp/RenameRoleDialog";
import DeleteRoleDialog from "./popUp/DeleteRoleDialog";

// ----------------------------------------------------------------------

type Props = {
  roleOptions: string[];
};

export default function UserRoleEditor({ roleOptions }: Props) {
  const halfLength = Math.ceil(permission.length / 2);
  const firstHalf = permission.slice(0, halfLength);
  const secondHalf = permission.slice(halfLength);

  const [openAddRoleDialog, setOpenAddRoleDialog] = useState(false);
  const [openDeleteRoleDialog, setOpenDeleteRoleDialog] = useState(false);
  const [openRenameRoleDialog, setOpenRenameRoleDialog] = useState(false);
  const [openDeletePermissionDialog, setOpenDeletePermissionDialog] =
    useState(false);
  const [openAddPermissionDialog, setOpenAddPermissionDialog] = useState(false);

  const handleOpenAddRoleDialog = () => {
    setOpenAddRoleDialog(true);
  };

  const handleCloseAddRoleDialog = () => {
    setOpenAddRoleDialog(false);
  };
  const handleOpenDeleteRoleDialog = () => {
    setOpenDeleteRoleDialog(true);
  };

  const handleCloseDeleteRoleDialog = () => {
    setOpenDeleteRoleDialog(false);
  };
  const handleOpenRenameRoleDialog = () => {
    setOpenRenameRoleDialog(true);
  };

  const handleCloseRenameRoleDialog = () => {
    setOpenRenameRoleDialog(false);
  };
  const handleOpenAddPermissionDialog = () => {
    setOpenAddPermissionDialog(true);
  };

  const handleCloseAddPermissionDialog = () => {
    setOpenAddPermissionDialog(false);
  };
  const handleOpenDeletePermissionDialog = () => {
    setOpenDeletePermissionDialog(true);
  };

  const handleCloseDeletePermissionDialog = () => {
    setOpenDeletePermissionDialog(false);
  };

  return (
    <Grid container spacing={2}>
      <Grid item xs={12} sm={8}>
        <Card>
          <CardHeader title={`Select a role and change its permissions`} />

          <CardContent>
            <Grid container spacing={1}>
              <Grid item xs={12} sm={6}>
                <FormControl fullWidth>
                  <InputLabel id="select-label">Role</InputLabel>
                  <Select
                    label="Role"
                    labelId="select-label"
                    MenuProps={{
                      PaperProps: {
                        sx: { maxHeight: 240 },
                      },
                    }}
                  >
                    {roleOptions &&
                      roleOptions.map((option) => (
                        <MenuItem key={option} value={option}>
                          {option}
                        </MenuItem>
                      ))}
                  </Select>
                </FormControl>
              </Grid>
            </Grid>
            <Grid
              container
              spacing={2}
              sx={{ overflow: "auto", maxHeight: 500, marginTop: 2 }}
            >
              <Grid item xs={12} sm={6}>
                <List>
                  {firstHalf.map((item, index) => (
                    <ListItem key={index} dense button>
                      <Checkbox edge="start" tabIndex={-1} disableRipple />
                      <ListItemText primary={item} />
                    </ListItem>
                  ))}
                </List>
              </Grid>
              <Grid item xs={12} sm={6}>
                <List>
                  {secondHalf.map((item, index) => (
                    <ListItem key={index + halfLength} dense>
                      <Checkbox edge="start" tabIndex={-1} disableRipple />
                      <ListItemText primary={item} />
                    </ListItem>
                  ))}
                </List>
              </Grid>
            </Grid>
          </CardContent>
        </Card>
      </Grid>
      <Grid item xs={12} sm={4}>
        <Card>
          <CardHeader title={`Actions`} />
          <CardContent>
            <Grid container direction="column" spacing={1}>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  onClick={handleOpenAddRoleDialog}
                  startIcon={<Add />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                >
                  Add Role
                </Button>
                <AddRoleDialog
                  open={openAddRoleDialog}
                  handleClose={handleCloseAddRoleDialog}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  onClick={handleOpenRenameRoleDialog}
                  variant="contained"
                  startIcon={<DriveFileRenameOutlineIcon />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                >
                  Rename Role
                </Button>
                <RenameRoleDialog
                  open={openRenameRoleDialog}
                  handleClose={handleCloseRenameRoleDialog}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  startIcon={<DeleteIcon />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                  onClick={handleOpenDeleteRoleDialog}
                >
                  Delete Role
                </Button>
                <DeleteRoleDialog
                  open={openDeleteRoleDialog}
                  handleClose={handleCloseDeleteRoleDialog}
                  roleOptions={_roles}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  startIcon={<Add />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                  onClick={handleOpenAddPermissionDialog}
                >
                  Add Permission
                </Button>
                <AddPermissionDialog
                  open={openAddPermissionDialog}
                  handleClose={handleCloseAddPermissionDialog}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  startIcon={<DeleteIcon />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                  onClick={handleOpenDeletePermissionDialog}
                >
                  Delete Permission
                </Button>
                <DeletePermissionDialog
                  open={openDeletePermissionDialog}
                  handleClose={handleCloseDeletePermissionDialog}
                />
              </Grid>
            </Grid>
          </CardContent>
        </Card>
      </Grid>
    </Grid>
  );
}
