import axios, { AxiosRequestConfig } from 'axios';

import { HOST_API } from '../config-global';



const axiosInstance = axios.create({ baseURL: HOST_API });

axiosInstance.interceptors.response.use(
  (res) => res,
  (error) => Promise.reject((error.response && error.response.data) || 'Something went wrong')
);

export default axiosInstance;


export const fetcher = async (args: string | [string, AxiosRequestConfig]) => {
  const [url, config] = Array.isArray(args) ? args : [args];

  const res = await axiosInstance.get(url, { ...config });

  return res.data;
};

// ----------------------------------------------------------------------

export const endpoints = {
  chat: '/api/chat',
  kanban: '/api/kanban',
  calendar: '/api/calendar',
  auth: {
    me: '/api/auth/me',
    login: '/api/auth/login',
    register: '/api/auth/register',
  },
  mail: {
    list: '/api/mail/list',
    details: '/api/mail/details',
    labels: '/api/mail/labels',
  },
  post: {
    list: '/api/post/list',
    details: '/api/post/details',
    latest: '/api/post/latest',
    search: '/api/post/search',
  },
  product: {
    list: '/api/product/list',
    details: '/api/product/details',
    search: '/api/product/search',
  },
  order: {
    list: '/api/order/list',
    details: '/api/order/details',
    search: '/api/order/search',
  },
  shipping: {
    shippingClass: {
      list: '/api/shippingClass/list',
      details: '/api/shippingClass/details',
      search: '/api/shippingClass/search',
    }
  },
  promo: {
    list: '/api/promo/list',
    details: '/api/promo/details',
    search: '/api/promo/search',
  },
  giftcard: {
    list: '/api/giftcard/list',
    giftcardactivity: 'api/giftcard/list/:id/activities',
    details: '/api/giftcard/details',
    search: '/api/giftcard/search',
  }
  
};
